#!/usr/bin/env VERSIONER_PYTHON_PREFER_32_BIT=yes pythonw
# coding: utf-8

# Pod Clock 1.4.1
# Copyright (c) 2007-2010 Christian Walther <cwalther@gmx.ch>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

# $Id: podclock.py 41 2010-04-12 20:09:26Z cwalther $


from __future__ import division

import time, calendar, math, os, cStringIO, base64, bisect
import wx


podNumToName = ["Negilahn", "Dereno", "Payiferen", "Tetsonot"]
podNameToNum = dict(zip(podNumToName, range(4)))


def readCalibrationFromFile(path):
	try:
		f = open(path, "r")
	except IOError:
		return []
	data = []
	for l in f:
		l = l.split('#', 1)[0] # strip comments
		l = l.split("\t")
		if len(l) == 2:
			try:
				d = l[0].split(".", 1)
				if len(d) == 2:
					t = float("0." + d[1])
				else:
					t = 0.0
				t += calendar.timegm(time.strptime(d[0], "%Y-%m-%d %H:%M:%S"))
			except ValueError:
				continue
			p = l[1].strip()
			if p not in podNameToNum:
				continue
			data.append((t, podNameToNum[p]))
	f.close()
	return data


class ClockApp(wx.App):
	def OnInit(self):
		self.RestoreStdio()
		frame = ClockFrame()
		self.SetTopWindow(frame)
		frame.Show()
		return True


class ClockFrame(wx.Frame):
	def __init__(self):
		wx.Frame.__init__(self, None, wx.ID_ANY, u"Pod Clock")
		
		self.predictor = Predictor()
		
		self.calibrationFilePath = wx.ConfigBase_Get().Read("calibrationFile", "")
		self.alarmOffset = wx.ConfigBase_Get().ReadFloat("alarmOffset", 15*60)
		self.unsavedFile = False
		
		self.calibrationFrame = None
		self.aboutFrame = None
		
		panel = wx.Panel(self)
		self.scale = Scale(panel, self.predictor)
		self.scale.showErrors = wx.ConfigBase_Get().ReadBool("showErrors", False)
		self.scale.SetTwelveHourClock(wx.ConfigBase_Get().ReadBool("twelveHourClock", False))
		
		menu = wx.Menu()
		menu.Append(wx.ID_ABOUT, u"About Pod Clock")
		menu.AppendSeparator()
		menu.AppendCheckItem(wx.ID_HIGHEST + 1, u"Show error estimates")
		menu.Check(wx.ID_HIGHEST + 1, self.scale.showErrors)
		menu.AppendCheckItem(wx.ID_HIGHEST + 2, u"Use 12-hour notation")
		menu.Check(wx.ID_HIGHEST + 2, self.scale.twelveHourClock)
		menu.AppendSeparator()
		menu.Append(wx.ID_EXIT, u"Quit Pod Clock")
		menubar = wx.MenuBar()
		menubar.Append(menu, u"Pod Clock")
		self.SetMenuBar(menubar)
		self.Bind(wx.EVT_MENU, self.OnMenuAbout, id = wx.ID_ABOUT)
		self.Bind(wx.EVT_MENU, self.OnMenuShowErrors, id = wx.ID_HIGHEST + 1)
		self.Bind(wx.EVT_MENU, self.OnMenu12hourClock, id = wx.ID_HIGHEST + 2)
		self.Bind(wx.EVT_MENU, self.OnClose, id = wx.ID_EXIT)
		
		self.calibrationText = wx.StaticText(panel, wx.ID_ANY)
		if "__WXMAC__" in wx.PlatformInfo:
			self.calibrationText.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
		self.alarmCheckBox = wx.CheckBox(panel, wx.ID_ANY, u"Notify me")
		self.alarmSpinCtrl = wx.SpinCtrl(panel, wx.ID_ANY, unicode(int(self.alarmOffset/60)), size = (58, -1), style = wx.TE_RIGHT, min = 0, max = 600, initial = int(self.alarmOffset/60))
		
		sizer = wx.BoxSizer(wx.VERTICAL)
		sizer.Add(self.scale, 0, wx.EXPAND, 0)
		innerSizer = wx.BoxSizer(wx.HORIZONTAL)
		innerSizer.Add(self.alarmCheckBox, 0, wx.ALIGN_CENTER | wx.LEFT, 4)
		innerSizer.Add(self.alarmSpinCtrl, 0, wx.ALIGN_CENTER | wx.LEFT, 4)
		innerSizer.Add(wx.StaticText(panel, wx.ID_ANY, u"minutes before a portal opening"), 0, wx.ALIGN_CENTER | wx.LEFT, 4)
		sizer.Add(innerSizer, 0, wx.EXPAND | wx.ALL, 10)
		innerSizer = wx.BoxSizer(wx.HORIZONTAL)
		innerSizer.Add(self.calibrationText, 1, wx.ALIGN_CENTER | wx.RIGHT, 14)
		innerSizer.Add(wx.Button(panel, wx.ID_ANY, u"Calibrate…"), 0, wx.ALIGN_CENTER, 0)
		sizer.Add(innerSizer, 0, wx.EXPAND | wx.LEFT | wx.RIGHT | wx.BOTTOM, 14)
		panel.SetSizer(sizer)
		sizer.SetSizeHints(self)
		panel.Fit()
		self.SetSize((550, -1))
		self.SetMaxSize((-1, self.GetSize().GetHeight()))
		
		self.Bind(wx.EVT_BUTTON, self.OnButtonCalibrate)
		self.Bind(wx.EVT_CHECKBOX, self.OnCheckboxAlarm)
		self.Bind(wx.EVT_SPINCTRL, self.OnSpinAlarm)
		self.Bind(wx.EVT_CLOSE, self.OnClose)
		
		self.alarmTimer = wx.Timer(self)
		self.Bind(wx.EVT_TIMER, self.OnAlarmTimer, self.alarmTimer)
		
		self.predictor.setCalibrationData(readCalibrationFromFile(self.calibrationFilePath))
		self.UpdateCalibrationText()
		
		self.alarmCheckBox.SetValue(wx.ConfigBase_Get().ReadBool("alarmOn", False))
		self.SetAlarmTimer()
	
	def UpdateCalibrationText(self):
		text = u"Using "
		count = self.predictor.getGroupCounts()
		if max(count) == 0:
			text += u"built-in estimates"
		else:
			if max(count) < 2 or min(count) < 1:
				text += u"built-in estimates and "
			if self.calibrationFilePath == "":
				text += u"unsaved calibration data"
			else:
				text += u"calibration data from “%s”" % os.path.basename(self.calibrationFilePath)
			if self.unsavedFile:
				text += u" •"
		self.calibrationText.SetLabel(text)
	
	def CheckUnsavedFile(self):
		if not self.unsavedFile:
			return True
		else:
			message = u"Your changes to the calibration data will be lost if you don’t save them. "
			if self.calibrationFilePath == "":
				message += u"Save calibration data to a file?"
			else:
				message += u"Save calibration data in file “%s”?" % os.path.basename(self.calibrationFilePath)
			res = wx.MessageBox(message, u"Save calibration changes?", style = wx.YES_NO | wx.CANCEL)
			if res == wx.YES:
				self.SaveCalibration()
			return res != wx.CANCEL
	
	def SaveCalibration(self):
		if self.calibrationFilePath == "":
			self.calibrationFilePath = wx.FileSelector(u"Save calibration data", "", "Calibration.txt", wildcard = "*.txt", flags = wx.SAVE | wx.OVERWRITE_PROMPT)
		if self.calibrationFilePath == "":
			return False
		try:
			f = open(self.calibrationFilePath, "w")
		except IOError, e:
			wx.MessageBox(str(e), "Can't save file")
			return False
		data = self.predictor.getCalibrationData()
		data.sort(lambda x, y: cmp(x[0], y[0]))
		for d in data:
			t = math.floor(d[0])
			f.write(time.strftime("%Y-%m-%d %H:%M:%S", time.gmtime(t)))
			t = d[0] - t
			if t != 0.0:
				f.write(("%.1f" % t).lstrip("0"))
			f.write("\t")
			f.write(podNumToName[d[1]])
			f.write("\n")
		f.close()
		wx.ConfigBase_Get().Write("calibrationFile", self.calibrationFilePath)
		self.SetCalibrationModified(False)
		return True
	
	def LoadNewCalibration(self):
		if not self.CheckUnsavedFile():
			return False # canceled
		path = wx.FileSelector(u"Load calibration data", flags = wx.OPEN | wx.FILE_MUST_EXIST)
		if path == "":
			return False
		else:
			self.calibrationFilePath = path
			self.predictor.setCalibrationData(readCalibrationFromFile(self.calibrationFilePath))
			wx.ConfigBase_Get().Write("calibrationFile", self.calibrationFilePath)
			self.SetCalibrationModified(False)
			return True
	
	def SetCalibrationModified(self, modified):
		ret = (modified != self.unsavedFile)
		self.unsavedFile = modified
		self.UpdateCalibrationText()
		return ret
	
	def SetAlarmTimer(self):
		if self.alarmCheckBox.GetValue():
			t = time.time() + self.alarmOffset
			self.alarmTime, self.alarmPod, dummy = self.predictor.predict(t + 1, t + self.predictor.getPeriod())[0]
			self.alarmTime -= self.alarmOffset
			self.alarmTimer.Start(2015)
		else:
			self.alarmTimer.Stop()
	
	def OnAlarmTimer(self, event):
		t = time.time()
		if t > self.alarmTime - 1.007: # subtract half a timer period to minimize error
			self.alarmTimer.Stop()
			if t <= self.alarmTime + self.alarmOffset: # no point in notifying when we already missed the event
				wx.Bell()
				if not wx.GetApp().IsActive():
					self.RequestUserAttention()
				wx.MessageBox(u"%s portal will appear in %.0f minutes!" % (podNumToName[self.alarmPod], round((self.alarmTime + self.alarmOffset - t)/60)), u"Pod Clock Alarm", wx.OK, self)
			self.SetAlarmTimer()
	
	def OnCheckboxAlarm(self, event):
		wx.ConfigBase_Get().WriteBool("alarmOn", self.alarmCheckBox.GetValue())
		self.SetAlarmTimer()
	
	def OnSpinAlarm(self, event):
		self.alarmOffset = 60*self.alarmSpinCtrl.GetValue()
		wx.ConfigBase_Get().WriteFloat("alarmOffset", self.alarmOffset)
		self.SetAlarmTimer()
		
	def OnButtonCalibrate(self, event):
		#self.calibrationText.SetLabel(self.alarmTimer.IsRunning() and (u"timer running, alarm for pod %d at %.1f (in %.1f s)" % (self.alarmPod, self.alarmTime, self.alarmTime - time.time())) or u"timer not running") # debug
		if self.calibrationFrame == None:
			self.calibrationFrame = CalibrationFrame(self)
		self.calibrationFrame.Show()
		self.calibrationFrame.Raise()
	
	def OnClose(self, event):
		if self.CheckUnsavedFile():
			self.Destroy()
	
	def OnMenuAbout(self, event):
		if self.aboutFrame == None:
			self.aboutFrame = AboutFrame(self)
		try:
			self.aboutFrame.Show()
		except wx.PyDeadObjectError:
			self.aboutFrame = AboutFrame(self)
			self.aboutFrame.Show()
		self.aboutFrame.Raise()
	
	def OnMenuShowErrors(self, event):
		self.scale.showErrors = event.IsChecked()
		wx.ConfigBase_Get().WriteBool("showErrors", event.IsChecked())
	
	def OnMenu12hourClock(self, event):
		self.scale.SetTwelveHourClock(event.IsChecked())
		wx.ConfigBase_Get().WriteBool("twelveHourClock", event.IsChecked())


class CalibrationFrame(wx.Frame):

	podNames = [u"Negilahn", u"Dereno", u"Payiferen", u"Tetsonot"]
	podNamesEq = [n + (9 - len(n)) * " " for n in podNames]

	def __init__(self, parent):
		wx.Frame.__init__(self, parent, wx.ID_ANY, u"Pod Clock Calibration")
		
		# on Mac OS X, we can separate the "columns" in the listbox using tabs - Windows displays them as boxes
		if "__WXMAC__" in wx.PlatformInfo:
			self.listboxSeparator = "\t"
		else:
			self.listboxSeparator = "      "
		
		self.listSelection = -2
		
		panel = wx.Panel(self)
		
		self.fileText = wx.StaticText(panel, wx.ID_ANY)
		self.loadButton = wx.Button(panel, wx.ID_ANY, u"Load…")
		self.saveButton = wx.Button(panel, wx.ID_ANY, u"Save…")
		self.sortChoice = wx.Choice(panel, wx.ID_ANY, choices = [u"Sort by Time", u"Sort by Pod"])
		if "__WXMAC__" in wx.PlatformInfo:
			self.sortChoice.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
		self.sortChoice.SetSelection(0)
		self.addButton = wx.Button(panel, wx.ID_ANY, u"Add")
		self.removeButton = wx.Button(panel, wx.ID_ANY, u"Remove")
		self.list = wx.ListBox(panel, wx.ID_ANY, size = (440, 200))
		self.podChoice = wx.Choice(panel, wx.ID_ANY, choices = self.podNames)
		self.podChoice.SetSelection(0)
		self.dateText = wx.TextCtrl(panel, wx.ID_ANY, style = wx.TE_PROCESS_ENTER)
		
		panelSizer = wx.BoxSizer()
		outerSizer = wx.BoxSizer(wx.VERTICAL)
		
		innerSizer = wx.BoxSizer(wx.HORIZONTAL)
		innerSizer.Add(self.fileText, 0, wx.ALIGN_CENTER | wx.RIGHT, 6)
		innerSizer.Add((0, 0), 1, 0, 0)
		innerSizer.Add(self.loadButton, 0, wx.ALIGN_CENTER | wx.RIGHT, 18)
		innerSizer.Add(self.saveButton, 0, wx.ALIGN_CENTER, 0)
		outerSizer.Add(innerSizer, 0, wx.EXPAND | wx.BOTTOM, 14)
		
		outerSizer.Add(wx.StaticLine(panel, style = wx.LI_HORIZONTAL), 0, wx.EXPAND | wx.BOTTOM, 14)
		
		outerSizer.Add(wx.StaticText(panel, wx.ID_ANY, u"Enter your portal observations here to calibrate the clock."), 0, wx.EXPAND | wx.BOTTOM, 14)
		
		innerSizer = wx.BoxSizer(wx.HORIZONTAL)
		innerSizer.Add(self.sortChoice, 0, wx.ALIGN_CENTER, 0)
		innerSizer.Add((0, 0), 1, 0, 0)
		innerSizer.Add(self.addButton, 0, wx.ALIGN_CENTER | wx.RIGHT, 18)
		innerSizer.Add(self.removeButton, 0, wx.ALIGN_CENTER, 0)
		outerSizer.Add(innerSizer, 0, wx.EXPAND | wx.BOTTOM, 10)
		
		outerSizer.Add(self.list, 1, wx.EXPAND | wx.BOTTOM, 10)
		
		innerSizer = wx.BoxSizer(wx.HORIZONTAL)
		innerSizer.Add(self.dateText, 1, wx.ALIGN_CENTER | wx.RIGHT, 18)
		innerSizer.Add(self.podChoice, 0, wx.ALIGN_CENTER, 0)
		outerSizer.Add(innerSizer, 0, wx.EXPAND | wx.BOTTOM, 0)
		
		panelSizer.Add(outerSizer, 1, wx.EXPAND | wx.ALL, 18)
		panel.SetSizer(panelSizer)
		panelSizer.SetSizeHints(self)
		panel.Fit()
		
		self.UpdateCalibrationData()
		self.UpdateFileText();
		
		self.Bind(wx.EVT_CLOSE, self.OnClose)
		self.Bind(wx.EVT_LISTBOX_DCLICK, self.OnListDClick)
		self.Bind(wx.EVT_IDLE, self.OnIdle)
		self.Bind(wx.EVT_CHOICE, self.OnChoiceSort, self.sortChoice)
		self.Bind(wx.EVT_BUTTON, self.OnButtonAdd, self.addButton)
		self.Bind(wx.EVT_BUTTON, self.OnButtonRemove, self.removeButton)
		self.Bind(wx.EVT_CHOICE, self.OnChoicePod, self.podChoice)
		self.Bind(wx.EVT_TEXT, self.OnTextChangedDate, self.dateText)
		self.Bind(wx.EVT_TEXT_ENTER, self.OnTextChangedDate, self.dateText)
		self.Bind(wx.EVT_BUTTON, self.OnButtonLoad, self.loadButton)
		self.Bind(wx.EVT_BUTTON, self.OnButtonSave, self.saveButton)
	
	def UpdateCalibrationData(self):
		self.calibrationData = self.GetParent().predictor.getCalibrationData()
		self.OnChoiceSort(None)
	
	def UpdateList(self):
		self.list.Clear()
		self.list.AppendItems(["%s%s%s%s%.1f s %s prediction" % (time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(d[0])), self.listboxSeparator, self.podNamesEq[d[1]], self.listboxSeparator, abs(d[2]), d[2] >= 0 and "after" or "before") for d in self.calibrationData])
		
	def UpdateFileText(self):
		p = self.GetParent().calibrationFilePath
		if p != "":
			if self.GetParent().unsavedFile:
				self.fileText.SetLabel(u"File: %s (unsaved)" % os.path.basename(p))
				self.saveButton.SetLabel(u"Save")
				self.saveButton.Enable(True)
			else:
				self.fileText.SetLabel(u"File: %s" % os.path.basename(p))
				self.saveButton.SetLabel(u"Save")
				self.saveButton.Enable(False)
		else:
			self.fileText.SetLabel(u"Unsaved file")
			self.saveButton.SetLabel(u"Save…")
			self.saveButton.Enable(True)
	
	def OnClose(self, event):
		if event.CanVeto():
			self.Hide()
			event.Veto()
		else:
			self.Destroy()
	
	def OnListDClick(self, event):
		self.dateText.SetSelection(-1, -1)
		self.dateText.SetFocus()
	
	# the wxListCtrl doesn't seem to send deselection events in wx 2.5.3 that comes with Mac OS X 10.4, so do this in the idle handler
	def OnIdle(self, event):
		s = self.list.GetSelection()
		if s == -1:
			if self.listSelection != -1:
				self.listSelection = -1
				self.removeButton.Enable(False)
				self.dateText.Enable(False)
				self.podChoice.Enable(False)
				self.dateText.SetValue("")
		else:
			if self.listSelection != 4*self.calibrationData[s][3] + self.calibrationData[s][1]:
				self.listSelection = 4*self.calibrationData[s][3] + self.calibrationData[s][1]
				self.removeButton.Enable(True)
				self.dateText.Enable(True)
				self.podChoice.Enable(True)
				self.dateText.SetValue(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(self.calibrationData[s][0])))
				self.podChoice.SetSelection(self.calibrationData[s][1])
	
	def OnChoiceSort(self, event):
		self.calibrationData.sort([
			lambda x, y: cmp(x[0], y[0]), # by time (can't use x[0]-y[0] because they are floats)
			lambda x, y: x[1] - y[1] or cmp(x[0], y[0]) # by pod, then time
		][self.sortChoice.GetSelection()])
		self.UpdateList()
	
	def OnButtonAdd(self, event):
		predictor = self.GetParent().predictor
		t = time.time()
		t, p, dummy = predictor.predict(t-predictor.getPeriod(), t)[-1]
		idx = predictor.addCalibrationPoint(t, p)
		self.UpdateCalibrationData()
		self.list.SetSelection([d[3] for d in self.calibrationData].index(idx))
		if self.GetParent().SetCalibrationModified(True):
			self.UpdateFileText()
	
	def OnButtonRemove(self, event):
		s = self.list.GetSelection()
		assert s >= 0
		self.GetParent().predictor.removeCalibrationPoint(self.calibrationData[s][1], self.calibrationData[s][3])
		self.UpdateCalibrationData()
		if len(self.calibrationData) > 0:
			self.list.SetSelection(max(0, min(s-1, len(self.calibrationData)-1)))
		if self.GetParent().SetCalibrationModified(True):
			self.UpdateFileText()
	
	def OnChoicePod(self, event):
		d = self.calibrationData[self.list.GetSelection()]
		pod = self.podChoice.GetSelection()
		idx = self.GetParent().predictor.updateCalibrationPoint(d[1], d[3], None, pod)
		self.UpdateCalibrationData()
		self.list.SetSelection([(e[1], e[3]) for e in self.calibrationData].index((pod, idx)))
		if self.GetParent().SetCalibrationModified(True):
			self.UpdateFileText()
	
	def OnTextChangedDate(self, event):
		try:
			tm = time.strptime(event.GetString(), "%Y-%m-%d %H:%M:%S")
		except ValueError:
			return
		else:
			t = time.mktime(tm)
			d = self.calibrationData[self.list.GetSelection()]
			if (t != d[0]):
				idx = self.GetParent().predictor.updateCalibrationPoint(d[1], d[3], t)
				self.UpdateCalibrationData()
				self.list.SetSelection([(e[1], e[3]) for e in self.calibrationData].index((d[1], idx)))
				if self.GetParent().SetCalibrationModified(True):
					self.UpdateFileText()
	
	def OnButtonLoad(self, event):
		if self.GetParent().LoadNewCalibration():
			self.UpdateCalibrationData()
			self.UpdateFileText();
	
	def OnButtonSave(self, event):
		self.GetParent().SaveCalibration()
		self.UpdateFileText()


class AboutFrame(wx.Frame):
	
	def __init__(self, parent):
		wx.Frame.__init__(self, parent, style = wx.SYSTEM_MENU | wx.CAPTION | wx.CLOSE_BOX | wx.CLIP_CHILDREN | wx.FRAME_NO_TASKBAR)
		
		panel = wx.Panel(self)
		title = wx.StaticText(panel, wx.ID_ANY, u"Pod Clock")
		font = title.GetFont()
		font.SetWeight(wx.FONTWEIGHT_BOLD)
		font.SetPointSize(14)
		title.SetFont(font)
		version = wx.StaticText(panel, wx.ID_ANY, u"Version 1.4.1 (%s)" % "$Rev: 41 $"[6:-2])
		copyright = wx.StaticText(panel, wx.ID_ANY, u"Copyright © 2007–2010 Christian Walther")
		email = wx.StaticText(panel, wx.ID_ANY, u"‹cwalther@gmx.ch›")
		web = wx.StaticText(panel, wx.ID_ANY, u"http://cw.kolleegium.ch/podclock/")
		if "__WXMAC__" in wx.PlatformInfo:
			version.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
			copyright.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
			email.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
			web.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
		sizer = wx.BoxSizer(wx.VERTICAL)
		sizer.Add(title, 0, wx.CENTER | wx.ALL, 10)
		sizer.Add(version, 0, wx.CENTER | wx.LEFT | wx.RIGHT | wx.BOTTOM, 8)
		sizer.Add(copyright, 0, wx.CENTER | wx.LEFT | wx.RIGHT, 16)
		sizer.Add(email, 0, wx.CENTER | wx.LEFT | wx.RIGHT | wx.BOTTOM, 8)
		sizer.Add(web, 0, wx.CENTER | wx.LEFT | wx.RIGHT | wx.BOTTOM, 16)
		panel.SetSizer(sizer)
		sizer.SetSizeHints(self)
		self.Fit()
		self.CenterOnParent()


class Predictor:

	def __init__(self):
		self.defaultPeriod = 56584.8
		self.defaultOffsets = [1175889407.0, 1175893930.0, 1175895900.0, 1175905838.0] # these numbers are intentionally randomized by a few minutes to encourage people to do their own calibration
		self.period = self.defaultPeriod
		self.offsets = self.defaultOffsets[:]
		self.dperiod = None
		self.doffsets = [None, None, None, None]
		self.avgseq = [None, None, None, None]
		self.avgtime = [None, None, None, None]
		self.intdata = [[], [], [], []] # intdata[group][index] = [time, sequence number, error]
	
	def getPeriod(self):
		return self.period
	
	def getGroupCounts(self):
		return [len(gd) for gd in self.intdata]
	
	def getCalibrationData(self):
		# [[time, group, error, index], ...]
		ret = []
		for g in range(4):
			ret += [[p[0], g, p[2], i] for i, p in enumerate(self.intdata[g])]
		return ret
	
	def setCalibrationData(self, data):
		# [(time, group), ...]
		self.intdata = [[], [], [], []]
		for p in data:
			self.intdata[p[1]].append([p[0], 0, 0.0])
		self.update()
	
	def addCalibrationPoint(self, time, group):
		self.intdata[group].append([time, 0, 0.0])
		self.update()
		return len(self.intdata[group]) - 1
	
	def updateCalibrationPoint(self, group, index, newtime = None, newgroup = None):
		if newtime != None:
			self.intdata[group][index][0] = newtime
		if newgroup != None and newgroup != group:
			self.intdata[newgroup].append(self.intdata[group][index])
			del self.intdata[group][index]
			newidx = len(self.intdata[newgroup]) - 1
		else:
			newidx = index
		self.update()
		return newidx
	
	def removeCalibrationPoint(self, group, index):
		del self.intdata[group][index]
		self.update()

	#-----------------------------------------------------------
	# Calculate parameters from data
	def update(self):
		iteration = 0
		while True: # iterate until the sequence numbers stop changing
			
			# calculate sequence numbers
			changed = False
			for group in range(4):
				for d in self.intdata[group]:
					seq = round((d[0] - self.offsets[group])/self.period)
					if d[1] != seq:
						changed = True
						d[1] = seq
			
			if iteration > 0 and not changed: break
			
			# update fit parameters
			for group in range(4):
				groupdata = self.intdata[group]
				if groupdata != []:
					self.avgseq[group] = reduce(lambda a, t: a + t[1], groupdata, 0)/len(groupdata) # sum(s)/n
					self.avgtime[group] = reduce(lambda a, t: a + t[0], groupdata, 0)/len(groupdata) # sum(t)/n
				else:
					self.avgseq[group] = None
					self.avgtime[group] = None
			kst = 0
			kss = 0
			ktt = 0
			for group in range(4):
				groupdata = self.intdata[group]
				if groupdata != []:
					# shifting data points to average zero improves precision, simplifies the expressions, and does not influence the period calculation
					shiftedseq = [d[1] - self.avgseq[group] for d in groupdata]
					shiftedtime = [d[0] - self.avgtime[group] for d in groupdata]
					# Subtract a preliminary model equation using the default period to bring the times (millions of seconds) into the same range as their variation from the model (seconds). This improves numerical precision, in particular of the error estimate, where a subtraction with high potential for cancellation takes place. The linear regression then yields the difference of the actual period to the default period, the error estimate remains unchanged.
					for i in range(len(shiftedtime)):
						shiftedtime[i] -= shiftedseq[i]*self.defaultPeriod
					kst += sum(map(lambda s, t: s*t, shiftedseq, shiftedtime)) # sum(s*t) - sum(s)*sum(t)/n, second term is zero due to shift
					kss += reduce(lambda a, s: a + s**2, shiftedseq, 0) # sum(s^2) - sum(s)^2/n, second term is zero due to shift
					ktt += reduce(lambda a, t: a + t**2, shiftedtime, 0) # sum(t^2) - sum(t)^2/n, second term is zero due to shift
					
			if kss != 0:
				self.period = self.defaultPeriod + kst/kss
				self.dperiod = math.sqrt(ktt/kss - (kst/kss)**2);
			else:
				self.period = self.defaultPeriod
				self.dperiod = None
			offsetok = [True, True, True, True]
			for group in range(4):
				if self.intdata[group] != []:
					self.offsets[group] = self.avgtime[group] - self.period * self.avgseq[group]
				else:
					self.offsets[group] = self.defaultOffsets[group]
					offsetok[group] = False
			
			# adjust the offsets to lie within the same period
			for group in range(4):
				self.offsets[group] -= math.floor((self.offsets[group] - self.defaultOffsets[group])/self.period + 0.5)*self.period
			
			# for those offsets we don't have enough data to estimate, compute the average deviation from the default of those we can and apply it to their default
			noffsetok = sum(offsetok)
			if noffsetok != 0 and noffsetok != 4:
				avgoffsetdev = sum([o - d for o, d in zip(self.offsets, self.defaultOffsets)])/noffsetok
				for group in range(4):
					if not offsetok[group]:
						self.offsets[group] += avgoffsetdev
		
			iteration += 1
		
		# calculate errors
		for group in range(4):
			sqsum = 0
			for d in self.intdata[group]:
				d[2] = d[0] - (d[1]*self.period + self.offsets[group])
				sqsum += d[2]**2
			if len(self.intdata[group]) > 0:
				self.doffsets[group] = math.sqrt(sqsum/len(self.intdata[group]))
			else:
				self.doffsets[group] = None
	
	#-----------------------------------------------------------
	# Predict
	def predict(self, lower, upper, groups = range(4)):
		ret = []
		seq = math.floor((lower - self.offsets[0])/self.period)
		while True:
			for g in groups:
				t = seq*self.period + self.offsets[g]
				if t >= upper: return ret
				if t >= lower:
					if self.dperiod == None or self.doffsets[g] == None:
						err = None
					else:
						err = math.sqrt(((seq - self.avgseq[g])*self.dperiod)**2 + self.doffsets[g]**2)
					ret.append((t, g, err))
			seq += 1





def timespan2str(secs):
	secs = math.ceil(secs)
	neg = secs < 0
	if neg:
		secs = -secs
	d, secs = divmod(secs, 86400)
	h, secs = divmod(secs, 3600)
	m, secs = divmod(secs, 60)
	if d > 0:
		return "%s%dd %d:%02d:%02d" % (neg and "-" or "", d, h, m, secs)
	elif h > 0:
		return "%s%d:%02d:%02d" % (neg and "-" or "", h, m, secs)
	else:
		return "%s%d:%02d" % (neg and "-" or "", m, secs)

# Functions for each of the time zones (local, UTC, KI) that take a point in time (seconds since epoch) and round it down to the next full hour in the respective time zone. Return a tuple (t, h) of when that full hour is (t, seconds since epoch) and what hour it is (h = 0..23).

def getHourLocal(secs):
	tm = time.localtime(secs)
	return (time.mktime((tm.tm_year, tm.tm_mon, tm.tm_mday, tm.tm_hour, 0, 0, tm.tm_wday, tm.tm_yday, tm.tm_isdst)), tm.tm_hour)

def getHourUTC(secs):
	tm = time.gmtime(secs)
	return (calendar.timegm((tm.tm_year, tm.tm_mon, tm.tm_mday, tm.tm_hour, 0, 0, tm.tm_wday, tm.tm_yday, tm.tm_isdst)), tm.tm_hour)

# For KI time (US/Mountain) the following tables were generated from pytz 2005k (http://pytz.sourceforge.net/) using the following code, in order to avoid having to ship all of pytz with Pod Clock, and to keep calculations in seconds-since-epoch rather than introducing datetime/timedelta arithmetic. Using pytz 2005k is important because from version 2005m on, pytz contains the new US DST rules that have not been followed by the KI up to now.
#
# import time, calendar, pytz
# from datetime import datetime, timedelta
# 
# mt = pytz.timezone("US/Mountain")
# getHourKiTransitions = []
# getHourKiOffsets = []
# # replace the first entry, which is (1,1,1,0,0,0) and would cause an OverflowError
# for utdt in [mt._utc_transition_times[1] - timedelta(days=1)] +  mt._utc_transition_times[1:]:
# 	loctdt = mt.fromutc(utdt)
# 	getHourKiTransitions.append(calendar.timegm(utdt.utctimetuple()))
# 	getHourKiOffsets.append((loctdt.hour*3600 - calendar.timegm(loctdt.replace(minute=0, second = 0, microsecond = 0).utctimetuple()))%86400)
# 
# del getHourKiTransitions[0]

getHourKiTransitions = [-1633273200, -1615132800, -1601823600, -1583683200, -1570374000, -1551628800, -1538924400, -1534089600, -880210800, -769395600, -765388800, -147884400, -131558400, -116434800, -100108800, -84380400, -68659200, -52930800, -37209600, -21481200, -5760000, 9968400, 25689600, 41418000, 57744000, 73472400, 89193600, 104922000, 120643200, 126694800, 152092800, 162378000, 183542400, 199270800, 215596800, 230720400, 247046400, 262774800, 278496000, 294224400, 309945600, 325674000, 341395200, 357123600, 372844800, 388573200, 404899200, 420022800, 436348800, 452077200, 467798400, 483526800, 499248000, 514976400, 530697600, 544611600, 562147200, 576061200, 594201600, 607510800, 625651200, 638960400, 657100800, 671014800, 688550400, 702464400, 720000000, 733914000, 752054400, 765363600, 783504000, 796813200, 814953600, 828867600, 846403200, 860317200, 877852800, 891766800, 909302400, 923216400, 941356800, 954666000, 972806400, 986115600, 1004256000, 1018170000, 1035705600, 1049619600, 1067155200, 1081069200, 1099209600, 1112518800, 1130659200, 1143968400, 1162108800, 1175418000, 1193558400, 1207472400, 1225008000, 1238922000, 1256457600, 1270371600, 1288512000, 1301821200, 1319961600, 1333270800, 1351411200, 1365325200, 1382860800, 1396774800, 1414310400, 1428224400, 1445760000, 1459674000, 1477814400, 1491123600, 1509264000, 1522573200, 1540713600, 1554627600, 1572163200, 1586077200, 1603612800, 1617526800, 1635667200, 1648976400, 1667116800, 1680426000, 1698566400, 1712480400, 1730016000, 1743930000, 1761465600, 1775379600, 1792915200, 1806829200, 1824969600, 1838278800, 1856419200, 1869728400, 1887868800, 1901782800, 1919318400, 1933232400, 1950768000, 1964682000, 1982822400, 1996131600, 2014272000, 2027581200, 2045721600, 2059030800, 2077171200, 2091085200, 2108620800, 2122534800, 2140070400]
getHourKiOffsets = [61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200, 64800, 61200]

def getHourKI(secs):
	d, m = divmod(secs + getHourKiOffsets[bisect.bisect_right(getHourKiTransitions, secs)], 3600)
	return (secs - m, int(d) % 24)

def timeToTmKI(secs):
	return time.gmtime(secs - 86400 + getHourKiOffsets[bisect.bisect_right(getHourKiTransitions, secs)])


class Scale(wx.Control):
	def __init__(self, parent, predictor):
		wx.Control.__init__(self, parent, size=(550, 250), style=wx.NO_BORDER)
		self.Bind(wx.EVT_PAINT, self.OnPaint)
		self.Bind(wx.EVT_ERASE_BACKGROUND, self.OnEraseBackground)
		self.Bind(wx.EVT_LEFT_DOWN, self.OnLeftDown)
		self.SetMinSize((10, 250))
		self.scaleBitmap = wx.BitmapFromImage(image_scale)
		self.legendBitmap = wx.BitmapFromImage(image_legend)
		self.pxPerSec = self.scaleBitmap.GetWidth()/predictor.getPeriod()
		self.leftMargin = self.legendBitmap.GetWidth()
		self.originTimeOffset = 7200
		self.predictor = predictor
		self.timer = wx.Timer(self)
		self.Bind(wx.EVT_TIMER, self.OnTimer, self.timer)
		self.timer.Start(250)
		self.bufferBitmap = None
		self.showErrors = False
		self.twelveHourClock = False
	
	def SetTwelveHourClock(self, on):
		self.twelveHourClock = on
		if on:
			self.timeFormat = "%I:%M:%S %p"
			hourScaleBitmap = wx.BitmapFromImage(image_hourscale12)
		else:
			self.timeFormat = "%H:%M:%S"
			hourScaleBitmap = wx.BitmapFromImage(image_hourscale)
		self.hourScaleBitmaps = []
		for i in range(24):
			self.hourScaleBitmaps.append(hourScaleBitmap.GetSubBitmap((i*32, 0, 33, 30)))
		
	def OnPaint(self, event):
		w, h = self.GetClientSize()
		
		if "__WXMAC__" in wx.PlatformInfo:
			dc = wx.PaintDC(self)
		else:
			if self.bufferBitmap == None or not self.bufferBitmap.Ok() or self.bufferBitmap.GetWidth() != w or self.bufferBitmap.GetHeight() != h:
				self.bufferBitmap = wx.EmptyBitmap(w, h)
			dc = wx.BufferedPaintDC(self, self.bufferBitmap)
		
		dc.DrawBitmap(self.legendBitmap, 0, 0)
		dc.SetClippingRegion(self.leftMargin, 0, w - self.leftMargin, h)
		
		originTime = time.time() - self.originTimeOffset
		i = (self.predictor.predict(originTime - self.predictor.getPeriod(), originTime, [0])[0][0] - originTime)*self.pxPerSec + self.leftMargin
		while i < w:
			dc.DrawBitmap(self.scaleBitmap, round(i), 0)
			i += self.pxPerSec*self.predictor.getPeriod()
		dc.SetPen(wx.Pen((255, 255, 0), style=wx.DOT))
		x = round(self.originTimeOffset*self.pxPerSec) + self.leftMargin
		dc.DrawLine(x, 0, x, 160)
		
		font = dc.GetFont()
		font.SetPointSize(round(9*72.0/dc.GetPPI()[1])) # for a consistent pixel size
		dc.SetFont(font)
		dc.SetTextForeground((118, 105, 82))
		for tzi in range(3):
			t = originTime
			lastmidnight = t
			while True:
				hourstart, hourno = [getHourLocal, getHourUTC, getHourKI][tzi](t)
				x = self.leftMargin + (hourstart - originTime)*self.pxPerSec
				dc.DrawBitmap(self.hourScaleBitmaps[hourno], round(x) - 6, 160 + 30*tzi)
				if hourno == 0 or x >= w+6:
					x1 = (lastmidnight - originTime)*self.pxPerSec + self.leftMargin
					x2 = (hourstart - originTime)*self.pxPerSec + self.leftMargin
					text = time.strftime("%A, %d %B %Y", # %x seems to use American rather than local format here on Mac OS X, so hardcode a more or less universal format...
					[time.localtime, time.gmtime, timeToTmKI][tzi](lastmidnight))
					tw, th = dc.GetTextExtent(text)
					tx = (max(self.leftMargin, x1) + min(w, x2) - tw)/2
					tx = max(tx, x1 + 16)
					if x2 <= w: tx = min(tx, x2 - 16 - tw)
					dc.DrawText(text, round(tx), 176 + 30*tzi)
					if x >= w+6: break
					lastmidnight = hourstart
				t += 3600
				
		dc.SetTextForeground(wx.WHITE)
		for t, g, err in self.predictor.predict(originTime - 7200, originTime + w/self.pxPerSec + 7200):
			x = (t - originTime)*self.pxPerSec + self.leftMargin
			# portal time
			text = time.strftime(self.timeFormat, time.localtime(t))
			if text[0] == '0': text = text[1:]
			if self.showErrors:
				if err == None:
					text += u" ± ?"
				elif err < 10:
					text += u" ± %.1fs" % err
				elif err < 59.5:
					text += u" ± %.0fs" % err
				else:
					text += u" ± " + timespan2str(err)
			tw, th = dc.GetTextExtent(text)
			dc.DrawText(text, round(x - tw/2), 16 + 40*g)
			# portal countdown
			text = timespan2str(t - time.time())
			tw, th = dc.GetTextExtent(text)
			dc.DrawText(text, round(x - tw/2), 26 + 40*g)
	
	def OnLeftDown(self, event):
		self.CaptureMouse()
		self.Bind(wx.EVT_MOTION, self.OnDragMotion)
		self.dragStartX = event.GetX()
		self.dragStartTime = event.GetX()/self.pxPerSec - self.originTimeOffset
		self.dragAcceleration = wx.GetKeyState(wx.WXK_SHIFT) and 10 or 1
		
	def OnDragMotion(self, event):
		if event.LeftIsDown():
			self.originTimeOffset = (self.dragStartX + self.dragAcceleration*(event.GetX() - self.dragStartX))/self.pxPerSec - self.dragStartTime
			self.Refresh()
		else:
			self.Bind(wx.EVT_MOTION, None)
			if self.HasCapture(): self.ReleaseMouse()
	
	def OnTimer(self, event):
		self.Refresh()
	
	def OnEraseBackground(self, event):
		pass


image_legend = wx.ImageFromStream(cStringIO.StringIO(base64.decodestring(
"""iVBORw0KGgoAAAANSUhEUgAAACAAAAD6CAIAAABPvdLqAAAQhElEQVR42u2c+VOTabbH+ROm7p25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""")))

image_scale = wx.ImageFromStream(cStringIO.StringIO(base64.decodestring(
"""iVBORw0KGgoAAAANSUhEUgAAAfcAAACgCAIAAACe67KLAADhLUlEQVR42uz9aaytaXYehq1nvd8+
59at6u6qnkc2yW6S3SRFypSowZpIStHAiIhswE4CWzbgAHEABwiSGEYQO4YdK0CCOIh/CEZsGE5k
JA6kCJEtUbFFDZxFqCkyUnPobrLZ81jVQ3VV3ap7zt7vWvmxxvfb+9x7m7Z+BOB1m7p17j57f/sb
1rveZz0Dvuvf+J8R6Kn7b5h6ur15jVQJAJiICACTEgAiZhIlImJgMNUfJgYRkQoBBBAYIIxBBALZ
+5D/v1BVAhGBoPECEBikACuIiMBQImCAhAgKIrIjsfewv5C/OTEhjjD+xd+QlJRIlIlIxf4TRCBS
mRD176lKqvFzYaj9ioodjkAJIBKFin9zVZBCoSpQgdpPiFRIhFRhx0o6AH9/ewdStgNXUpkMwD8a
pAK1IxQV9fchJVUmgBQEUiURgKAEIp2TQSCAiEH2KyrKIHtnImWyj1AiVdFh3wtEIvZzET8kkMqU
ATDinCiB1E4L4idEdsBqR8tQEvIvJHbGYRdCCaoK2OlRERXxuwkEAk0RIogIwW8uIhIhUVElUVVV
shMIEKBTJ4l9gkp8jp0V9VfZB4vIVFUlVVElAlTtNykPUInmFHu934pKQiQy1U6AvYgg9i4AKQmp
ipKSqmrccPV/Ve1N/F/jS2n80M8UKZGdy3qlUvxA7HV2glWF1H7u95So2uvtt+0f4l9JVVWUiKD9
ajDn6bInrj2A/igBTID/IuypAsGeX3u07bcR5wzwdyPYs29nibkeUGb/OYPQnlB/Zz9me/N8R20H
hv5KEBETKZgp7iSvMICVrrr7mEnVDgBkFcWeBj/2PBl5xxI4jjPLEing34yU2B84ta9MpKT+Rsxx
AvN82lliPw9VC6EqGIPAXjbtHzi/j2bNjH9imtNfk+c5vhSYCexHaSfscNDTVBVigtJ27+1vI1z9
ru/7fb/+sQ+P0wMltcNCfBO7LBgDSsREBBr2feyuBTM0q/gAEWOwfze7ReK8xvHlNY4zAoYqMdsn
KwmBwQMUjwUYbCsEExRxFtXfyq43I29ZMFRBYpWGrSqokBCDmFSmQCSqvHipVVURthqqqlOIlO1L
W1ETgd02SlCxJ579F0/25lAlFSs8DPJVRJRBJEr2elshRAbDFgkQSCeisKoITQERVGwdIxX2RWsy
mERARHG0KjrYjzkr/gDIbkERtpMtMkBysnVCSQSkKmqfO9iquVdwEOkUBg1A5rQlYYBVhFQHCKoy
xcs9+Ro0vVpr1FZlZvvRFJGp09dU8GBRVSKZSrAVglTpNKfGG4ooEYnfPnyaorbagUTUHrMpKlH4
/NZSW+xUlETFlhYiTJnq9UNFiYA5raDbDaRKNEVVVKx6esGFvVtUXiElUZIozFltrYnpZVd6lc/q
rVGdfTGNd85VIJYmEbVvqm3ZANn656dX/BNzUal3JvgDSvGU+GWK4qnwykr5HLEdCSGeqaiw9hf/
Bf9+zARbG/xf7NGLsksM9hJpHxiVLovqUgqYQFYl7VtqrCvwem3/mb1gqyFgJvYq72W0F8oxoGqv
8XKkvgb4d4/lRwlgfwsvR1a4GTrFqny8rYIHMXuVtwVgjCjkXkdVlYgxsFR5+7gxAJZ5orgKiAVG
rYWB31Fg7mfAfurLdqxMdhX8P0m3w723v/1bPve5TxCm/YifeeYd73znt5+OJ7/UsdD1FoWqD0It
Mcy+hvclOm7sdhdX843lD/nd60uTvTaapGyE8kGxKxRPtOZRxcFZl6X1iYiHVXOhiQrU390rvLZX
xoPR19S4/PWd8oGWODOgLHLxzOWjS9YWgJnZ/m4nEW11ouw2oynJAxBRVcn313p/LwIiYv/HiqP9
E/wj/fTOKe2M+ivzsbMnW0Tb29ZXiEtWp3F/IVUBYgYzxuAxeDD6+ae2rNuvyfSWvTpZVdsxxmdV
t8l5BJR1XNvJJhGdIkoq1Vf4+V3uAGRH0L6O95D+W4iPQ+sw60S0jrY/HLs3RB1/+7fdT/KCUntS
sv7GI9Nf2X+vbs22Y25nOu905O/7M7u+bf5KvDx+V9vv5olUpf7t8haPR57WrxFvFRehnSbNe7if
vnjD+sulU5Y/r8eNlkcYdjtWQdsXgt11Qf+71db8Wf49TqA9ciT+7PcXqEhdKUc6lj1XvSzuKNo9
bO2l/rJ4ZSuSscdaKyQRnU6nd73r/c89962EDUSMwzPf/T0/8MlPfY7oVB/mv5NPMtsKb19M51QR
IlWrB9ZsUF2PKNx+0ol21RPLt/A6LL1kRNltdVy1rQLt8luTTn0pacU1zkLd+bmzgO9v+1m357ev
E+t/5jvrUvCVqp2JpSUbWorecv0quddEf6TbI+M3T7Rk+U/YV4f1GegnrZeA8w8q0I0BsK0BtpCo
Wh9dbY39LdYPEpFcDKy4r4eU+ysmeMnOGp2rvyMQRCKiolNERJmZOYG8et8p0tazOhEgDOZAColb
YTHoRtq1pLN7Ow/aQJ7ejvjiWo08nS34ASZUTa2FmpbS167c7s3qGC5cmv6J5wtDLUBn1SGeFtLW
PdH+9qG28KGaShQepb2kOqIYD1m9ry49Opb37W++HMm+Kzz7V0Qr3Wq6ivheeSnWURNU69rbndme
cQ1stoEey7fTdfFwANEehtgpoB+PSOFkImQd1r499WNWkXYSyArp/tKeLed16mqNSWRO/aZhtt6K
qumQ3/ytT/zwn/gzfHiOru7x697wLd/y7d/1hS9/GYMDCBnAtl1dU+0CAmxR73Y0T3TegmAKBJY0
CoBIv0frXo91TH0LDeQjIELal+u4k23j53trXxriUUJBrWu16TuEZZeI+FjK7TjOALGl54iG3UAA
/1Nooq+i2o4Irehp6wWR1Y1IL5bp1rNb2VXfQbI3/sxMRCLSbxLfJhS6V81ga8Z709dfnLdxfkh/
KtU2BFZ/o/HPLmf3ibYeyBTNqxn3vw5mzmYtevYAeausa7uN7OeGiBYYDJtl6BTvMrK0iWQjoLvz
k8tMK6mgs4Y5WxMq6Dq7vSpbWU+sp2odiC4dQWstz6s46FHF/a7Vuu9pdiuB7tvz3eJA5/17K0hR
yhMHrS/v3WJrUCnu+bqggQvtv9Ll7xhds99YuXNq+zjQ2cZ7t8u2V+1aYHAhDa3FI23gQftXw777
arTHIayYnm+nstbvdgbe5vdNCRylz/vfPktE88W7q9kKJu1a+AB/0FYm1GMgL770AvH2Ld/6u55+
/Tu2933PP331Olw9c/9qPns8np66fuY73/+dr7z69c9+5jdOx1vi9k1UbdJJu86NsmoZvMU+Ee1L
U8BhiEGTxjixRhbxbJ/doCpC4IREuFVfRQE2UChqRksM5Eap91iOFNYTAUCpdXY25FAxiDdWtxqZ
VVE3jJd8dGzfaDJYSQIEVbSbNb9oQgE2lCRHw0VFOdpElWlnhB1K1t6N+m2nWej9PcV2NkQEx154
LDiS7y+tmfWv1Z44cjDfy2/s7x0q9rudSdRw+XYpaqKVvZPEDMouFZOBqtCpomqAei+jhrh5Bbev
xoHUKnJx1Hav5K2vuYnwjW0Va6lBP9WoE9XVUZvI7eAIn09lTaMAvLM1qBZl+XVFn+vFwTyyiCe4
/4RFP7cjua7sqz8KZ13gtrV5rG1o9uJq1547QlvlEm0UV+tgDHfz72u/rLuPXjf3emlN0jMMp875
7n3QUIv+moYGexNnry8kZ996B8YigZL7sxaz/QYi+Snl6ur6l+Lo/AI67GtVbtPBvNttqIH+/WlS
rRF3llawz18S089uZ9t4ow/9o1//oz/yB375l96y/fEfeNPzRG9/z/d+4/5z3/2d73vnW579qZ/7
6c986iOkN4FqQds4Pm4sqM3NG0hZ62pNXImKZNK3hKxG9VB/fJzVY3UH62Ibj3TO23tX3kDDwkB2
6J3P42PnzShcJd+9TcV1Bf8Vnb9A+82mj4qyqXFA3cuucUGWTWSOZxbQqU2mSUWczMM2I1IwSE+S
UG+We2a2fw3SizIzqSBLv8EsIqoCVa7VdFmpEb1D7gI7gBkIJ5HkNVwAKPt1EWN3+NRSaw9HznQx
Xo0VdwnOUxwKW3FH7stqf6aiYAyG0Vt8xY3tpaLwdN9PiY8l98C3j52oRhe908qWxSeGxh6qkmEn
gHKPkHdp7+8Cy2OQEs2Gt+sCErU2CcgT2pvHO8p9AJYXMJzznxVKlA3QHqzA5aa/Vea2UW6tscbz
ptYErXBDLsa9Mdd+oAii3dnGmXortZzYtYle+nr1gfD5MdiT2Yqpd9DeJ7XT4lNfrgOIF2hCPdan
16mIEeHF62UVZXAu9bFL4uhZURMZqF+c0RhN3BaHhaTUUWsCj2efe8u73v1+nYdPfuYzt7evPfW6
1917+pk3PEV/+A+/b/tjRL9G9Mzve/uR3v6LH/r0T/303zy+9gLopDlroZggc3Cz+rrX75K8DDZa
jqH2bvpqtEBd5kIo9MYIkXbTt+1JthJ253lDhdxDXAYuY20o5A4wgqIaxQA+bupbfOLCFxs+GdsG
RGtdsznKau59L2WJ9K+foJMm+UzEyq6uz7NKzHM47jAkkcBXo7jnavGHQcvsCwMZcL5Crn76RBRw
ruLgQhKsdVDxVSc4r/0FBCaZXv3ye6lIqxJOuwrIMZ8daM1raoF0EhogNYvqy2Sba4jT1hDrke2C
sgRpQl3iB685aNW8o6pYyVpylWry4zMutBVxZQM3FK71WTG7VOrDKdK7MYtYkyT66P4pl1t43c9s
aYXLYmsDrJ0lLlfzhsrU+Ap9o4yVFrMgJ8WsAZ+9Z9Ug6wjtj/bNwYU9gLenOcPcgQdY2J879APr
+tRGAvkarNiOBq4drEdv7Ji1DRIMq9EFaOI2+SzygvaDKV5Q0YF0ToIaGT3uafVKlm9m2BE7nkO5
2LRHUkUx6iaQOV/82vMvv3Tzrd/2PX/ij/937j39xq8/uOF7128k+kGi7T1E94m+TvS3f+XlT33m
V6e8BEwnUzJXk6rFDEpcHBiNc0uUVKZsFta/xOROCw/su1le58VtfFyjUu8auCG0TK3c6tpNL0h3
61iTNZ1PJerya01pXDIgebdGv5tbVs2tAAAv3LYHUlIVJCWVCDyiN1HHPQzrj1rBUdHQ7ldmNna8
9x1568cCYFVMREjEd/HUF4PaP5HIsOOqb1odiTdbtgKSMjvcRHH2VBlrRzUGsm7a6gtCzGKsC/FP
ExE9q6fGFCQ7W9PfZ7Cj3DPvNc3XE0FHLjmxpdBG/ZAagjigYavIlECR1VeBPsNcBvYr+b3txNZB
ilZ/qsVb9PtazooyOj64UAX6rbpWuktdS0KSeoa7NAZQQzhwV39/GQeK1buj2VhbV7SlX+PG7fsY
6bQczapdaAl62ej8n+oiCyZoC0OW8raQ7E7F2RVUGgO0dC3r0Dt2r00HULiQLhv2+hUOiQfaPGMP
iBlQM5ZZtEZxH6OvbmAoisdWRaBNDjBGXJ92EfNXZJ6OX//4b/yD3/rkr7/+uff8rt/7Q3/4265/
kOhbrQs+ED1NdP/pp3k8DToY+abuaJsat9FrwrP9fPqArEhajRbZZxqdLALk6zU/zAk8iYj30YNo
b147yzNQlpx/FhWnmhsnC/VxqcaguLUJbZjamW+aDX6ohoyLbRT5lYiB/G6I2SEzdjP63Surt2B7
uX3GnFNkSpBa+l92/DkbyeZz7USU6D2TFphbwEZAvEz6iLc1br1KEVaWASC7RMX3lyPmXj5RY/tC
/sNOLTXiDSe9lBFTNO20qB3uErBQjeuoI3y1S/DbYMZ92J9KXgeEjVSFNuxa2JC6ZzG2aaUu/9RZ
ZdhNfS/jL6R9vhY35W4PcJFYmST9S1DcDot/FNy/Do51ZXP1qSD2KNjFpeIu4mM+E+3Z9//5LcKU
5F+vDJRb2I7JLjd/MEywo82sp++c4KSNIqltGV6As6S6m8Aq2Sw4HwLXkDZZZbSSTasiJV8830dJ
p+gsYgvarzT8SvtqV2x6fzxuRF6+uf3KF77w6c+cvNvYXiT6NaJPE733Xfzet/7Q5z/7gQ//43/4
4tc/Q/pa1rSo4NxZ1dHbNkDbFmwVY+mnbCGq9h4xt3mhiTJTWUMNnewXwDcTqW2rxaNmRYQdOqkX
9rpJlxKtu8fH3zbLbJo4UmvP+7vsnlcgsRSEllWTGxO0ZL8DRITU56u2z9U5TVkSx6M5+yGRFKUZ
KuQddyfLUy1NVCM4biNBCrJT9JDaXxyyxGTng5gZbAosqa4NBawaKIUAoFxiZNJQ14EgFzVKBayW
PK5z3mIaT9JKCUBQa+NATuskBsR0A6RoTTEYoTgq+DfOTDGW+srdGd7xDVVSTeSnYkEorUMP+RMR
+0RaV8xBc/TahSCXUY/l5jzvSVVV1+lgv3C9jUVjHeT0t82Ady0zFSAe8NQZzF8qdZ+fqGJXB4tM
qqnsCJ4x73mBRcUnV7ZFaWsbqpJj5XKds5aO7C9sZpd219jvTGmjvfOnTjhbaeap0+4Ei7j2okYj
FFlmDCng6k1AYg2DfR+aN6sm9tsuQzb4roAUZ0dEHdfd4Kd3AIaD1VVn0sP19tz3fNd3v3Oj3yR6
HdH2V4jeQPSL/98XvvDpDz985cGbnn3D933/97/yyrs/8fFfe+mlF4Sk1jhd6LJonKokK3jJYxtr
uFcBNUpjFQo7ZbW5Q00vqTEZ/Bzy+Y4WSSqwI8HZyp36D2H/qLY3gMEmGCoCEizTmuVT0JaflHuh
UYdKgh33TT5+WloGyQXZqDV+uuzvEnN8BcmMEQKYoRIaZAdSGm5jc05zIDCZLrPPHUUaqwILi8nY
LdNAfN9C5glkBgNqxPngwseACBR0UvggQJMY5p1+Md80NgqufBINGL0LG8inlM63MdSLYfeFrzYp
Ky18ue8UC9n3CzBLY7WSo3UHiGdJ8GUqOtlchBcSN8CAT1+xlGxtgg5zOGjz3Cb66jCZ6sX2t1UD
TSeQ82ntWomXirHzXLi0nvC6JjVe9sJ432Pm2tQo6PRE2qmrUMzLcFZYiTEanLlGvFl2U1jHHtjB
a8UKMqhKjIiGppLZa9AWxGYRQF2YmqReM8DBesCTBhPIe9NMxYAXZ/hSDdUMgDJgNjjLSSQrJApQ
kWUrkO0iQCJIqa3tUn1aiHv33vwH/tAPv+s93/ZrH/34R39Lv+MD33F8K20/9Quf/b7vf8/plRdf
fvFztzffePAN+exnP8y8bUMJoFm71ngc+Az+ChnuMkV3pkwtjDvqi/Y9V0zbJbeAgVhqDkbisS0l
YrsqvEifrMVKIlOSfbLzRzTH0Zggcbdqh9iectepYpiwfdJOdaSkJKgrH+ILY3jn3JBIVTkoWQ6y
a1xIJgbszcGsc64is6bXaLYTRj+3FcK3EY4N2fnXomwyu+YrZG4iCtrPorBsUEDE2jAacf8DEiHO
U7ZA/8G0EckTKVHiNbdcVFA4m8OMqsnbEzibKknk0NpyUecO5pRFYg9RfidVhosx1XHTxrsr3Zkj
XR3+EP9PqTnNhY0/WmPZQMxFDot4Z22aiK6z9o6ZdNev9Q1H9wXKO2Eld5wD+iC6819zoLVU2qYT
WLdXe56M7j7gjOWDM4XeUnkbLE7nWNhusBeAPvpSp8vesDkc0III9Q0Q8+7jvHfmdfHze0vCDYA7
g3bn0FUKVUPPS4zv3Qo1EnOAHLzHuWIwqR2RdwoTop3VTqL3f/IBGD33lnf/7u///Z/57Od+7ud+
ija59/o3v/ud7/qZh/e3z3z873/ti2/7kR/5od/4tZ+leQsi1Smnm9sTtQExrDfsZMqGW6G4FNyJ
ZW0fZNsKEd0RucK+o5Y9Y4czVsrihfm+c3MuNRR9OIk+xSZqBHY2a5csIoUq+NQ0dicUnbiDIQoJ
C7PwjwooXAxYKBxcZ5QzDnrrAqRA3fYrGkRpsIgftl9iVlKRKYyYyoomp70sLtZzZaRM0A6l0WXO
Fw2zFRRRM1Yj52U2OZ+5DcU8OfxfokUHIMW9K0EmM8w8LLiwEFGOHZitCrG8J9aP9O3SeMiMmJjK
WqUCr5biC9BCqGnc2zD7ktyU936bVj74qiLWBqLncosciOqeFLj07L0/Txe0hgXrapLQTMGCJXZB
PUfNe6LjXedMnEX7/dgJ7B0KqqWvUaCjsLonZepep93pGL2hSBENdmtaZycvN6uS2wkE9rFbRTrR
T5HsDN/OU5+/FMeGzmCcrgWL9oQSSY69m9NvdhAklnFrPfWiCi1xRcfJzD8u96N9whbrOjpr/mwG
c7i6Ph4f/uTf+5uqR9VJJ6hevfGZ65/6mb/DD77xhS9/6aNfff7L737P+0CsC5sV7uRw5nqRSoHk
bRdmvdAeFwBRV3GX9rloa7XLiKgpVuoqtLUlVYznN+JqBMILqEw1LF1tWKQr/nZ1pxS21Q6kVJRW
Pk9S9EyvP9DICbaW+HrA3A+A+gDWhje006xiqRhNtsnMzOzuYA247zYGXdWan4mF2RTgDfwcruMl
m8SaNruzZkpOkOOlFLvWBQiwfuVx67kNi8RHTNmbC+luZ79eGxejEA0z0mG26W7MeKssnSszlUja
rmnZG7ZbZBHyaClEijvU53hnw9Lz0okFYuiq6VwMeonfiaXP7ENocUy78Dl3uMKsytUdqHaR/KMl
MNsLExoNRPUuFxrXzwOP4Dg2Rs2FrQnO+vS1cJcP1CrWQUfh7hJq6ZnPTE2PW1Wkbsa5c4jJrcMy
S8DCDi85ovduy7dO1eR6sYmZUmAUn3s83rzy0ldIHwITrBC9Olyfbl/5+vMfZzrd0Onln/3pv/3+
b3uvKteiin2Fc/Ix56PvI9nynqTmutUYD2nrUw96HCKlpUvMFsP7tG2elrEWFb3uvNXQ/fO1Ps6g
Mx5xslMSDSzqaODm7UHVxCXsV+zFzCPqWFJNxhiDw5QraocEeCA4o090nxn2Wbez5rlpPfJl6bIQ
1VnO272uik9cIhdXLp+8hYOR/TEzJ+SytMyr+YEzcKJtX+//bmSG82LgVqSMYd+TcV7U6KwF9e1X
o2xw/t82jV774oYPugrpctup1Vmvn732BLIYvWjndC3Q/0qP2ZMfiXb9E6jzkNYVblll8vbWc2bU
ugneqwSX4nu55Cf//4JZAe7u80HYDYH2TLUd18jBlhXPufhlsFyf3TpHreHVTkrZQUMr32xPgNmR
YdKC5dzMIFue9deXWrHDK+0XmXs36xuFaGrSXqJvdAqvDReE3QReO82ru5ISv/fd7/7Yb3xETg82
jEGMh7df+fgnP/LU0/dfe/Ul/xDRRFxiwgg1n2wOSoIsKjWf0MGWCo51y8cTSgufFESmvSFh67VI
1+m+KW45cZlkenSL6nBdT4lEM6Avr6JAJUA76vOeQeu1SHHGMdPlrctAzkbvrtpFW6l9c7DfvhiI
X8CrQSLhlSD71qtZecucxs8x54O608q6TtIpzZiYWfyjtVEQWe3uB5aXyaUYzYMs9XfcWBZ5Yjns
adVNEcIEZXHOW334WqntTazEsFFUfNMQw5vgq4ZSn1l0z5zRYnu3kRhI4uFOcA/AXHcGusPTi3aS
zHctsnN7DIsA3gUaSYJawckyJCgTuyf1MMgR9HnT2YjdeATi0lW3unuXXORcCYWUw1AMrUFnhZiW
bmpR9qUYzI4/eWBdmBqTMruhdWHriTYzkvy50vkUoHr1HV1dL7kGAbgwG8g9ewCP2sTQOW+2OlmY
RGuJuL1hJwh0f7G6/9QVj/4p3KYrIkQzGmj0nW5btIxYsdQnmQIwtoFm6aOqT90bv/7RDxMdN5Nj
AfrZz3z06t796nSqpfXrqDW7aPd9Lfpxd4uEonTZeiCWIw3REigxqpgvNzCuXxKkY0NAPFoKZo0m
O2efVqcXUkYJpfyq7AmFfq+yjR+EE/eVadYIaPR8kYDmL+GbaaRVXNfW1+xdBNtosaOHtLhU2o7B
3PfN81zyJuYY5Lp0SAWku0ZWJDzlU99rM94QezORiCAWd6wKbVu50UAZIzX4GENcrQagmUVeMNFt
ZM5Gac1JlzHKku7JvdEGmKaoTGqMxzpv3YS9gXM+Y/cNFjCbF55V8BLxNQpEc61ZJqtKpfNSnJWs
hFvj0siKmmnjXPWxYf865517WurrysDRR1LUk1tJZ9sF6kzhnYZoNe+IrXSkPOxDNwKqSiU2pTur
jW64Jkxla+PrRkv86PuzBvc0FjXorMKb4nrhGvOqo8RdexzqfhZNFucA/So/u6C0ctCGnThexjWM
ND+QsFuwhmSxGUfdAJ0Q4PYKnsvkHJsdqgnsNtb55ntEEfrZz/3Ww4dfZaKtxnTzdPPay4vphBua
I+wAKH3pjAGHpohTUdqbmOliH7hSvVJCoGu/QwQ1HSQ7Om8wbzoVoKW0tAQZWvSI1AXq1BwhkZ5D
zSFAGrYPVUGzNgp7/nBtF+3ccmNOeO9MEfwUHuZZr5lZm3+kkVVqQyATi46KzQChrQro/B9DWuxM
Ba1Fus+qXbWxOv/Xv4oydzdjvWsSJ6IVqrBU7aC2NKciIppTm+bcQXzLY+q9nn2iFGxdTdrMVQLL
7FPSzGJVKseytWp56YxSuOrj644Jys/Oi0m7retaeQP78SVN92UI5UIRRjcas2VV3T0CncHdy/pi
WrCwMGk1M9gPWHcA/ULkz5vTR4K0a1IukRzOeK9UCsMLDMUUKZz70iQRhRvSUUs6FkzVHro0mVk0
I31HTQve0q0oDF1pxtn+rPW7Wc8imWixbysmbphH0hj7SUAebVdRwSn2lOT9pTyhUDHGCiOcfam2
YqlI5vSZhknDQDSpOEGpVIC+9rUvWgXbcklchlIFHbQUkrxOsYbGFLsJtletnXqxUwpXAqXlPnbh
vskr6/blSN5qbV4Xp1av5lR6B3ZIyrNFBdFWVURIOuOgxalpGZEF4ZLdD5KSSVEucuWL3w1CGley
ex7knsAuCafxIEBVmpNCUpoQ4z4m6RMYUFlg3AAfE1DK9tzoTKKLj1PJuBuJXoPiHtGE/Vu0fae2
yYKqio5leJu16BIjokHskj5ovkyoJ2hBc/hpJ00t5qm1wFbo2an0ENX+dDNoRjsfg7a0wAsD8BXq
FC1vyixVEuZ0vjfs3wqp1l+YNztLL91xDfUMOiHsCDk7+L4rjLp9+9LI65MAPn2jmNyhsDrDwqzc
l070lh47THOVHWrFGu249WcoSrsPog0/R8YX74EG9Vg0lcZ4LISZxS3OQrkaSFBzIsJijtvQVF05
nQi73KTn2f4tVg4VIppO7mw8TjWnGi6Ujai5jEVLguGKIurhByVklXUEvZ9YuIbTzRBzw2m/Sw3B
PdkbbgDOwekzk/9YnmNJRPfvL1wFulMQdZ2rNmuv6kEEGFUKRJNGGiZw3TGDwsiMSl+30rW6tK6J
lZd5T2VorrAXUl5i0/+Wk8Pmx5jUJlJaMfomBiQXuNquSR38SeU61t45cfmmcFFV89FkDSJm+Zkn
89qQE1HsLVmcZmP/SqIjtvv2w8GmETMDS7svVVTYVEhTlsFDjiPFXoBmPY7mHLDoVmzzOqVsVKaF
VCk8yClckVbr4AaLk2buXVo1dCNPJCmyBh60ZG453ktKK46zw08aLNB3D1g8asIUdb2NsN8dFNqW
xJ2AgXSxRlnWemkoPN3lhXDuI3/GiNVLngK6z5lqJhC53isVWyibTup9B+EcwVgy1Rrtj6gZMZ1b
BF/EmZCWgrTEz3USS/JYFlyiP+Boq4LW9TXoIyL0FvCgk6QaX95hujRwb5s81If2EX/Vxt3AfadZ
7YOp7OhTwk0m/1RqfJtVi5AU7Vg/EtfwpihXJgZ42L25FaLP7ehL2prW3XYAZVGkSskVbQWoGHzL
Y0kWlpmDULv/ud1+Ujt1KLLl6dO6Ji1Lam5pX4PY2JJJwlC6Izu0iFtQQ9sSw6NWpibcWIJmfD6S
5bKPKMI8KHBmYjpnv2RL6bZlwYGzKNc+mw2jDmgNXty1plwF0gLbxbA2fZ3z1IYcSkr5WYjwYhfl
tRBBrkksRnAnRWAIIDMkkX1yzVfM35bnGslQNrFICKAYJVrJIYwuiL6GCAYETNQ8z5QHi5VAo99I
u/GpY8eenprSLH89+wF4lQoh8S5hqME4Z7rSbnF0TpGUhemCxSVjd0vgHHNv8r8nMpynbk2W09+e
cLlWZz3LfkFf6Fa16toLVsSq7qGPZIt3gHZNaU9BKc7yQfZv0rMoO+H47pXDMdispAabEJGVuLPh
9oJ/qfax505MtorHtKwiGsR57mxjbbXrjQNDU1Ub9qooRrjQCFlQbjefRDT4EbsUM/mFXhwGCirm
5eiwQyA8Gy0Jv0SLP7B2QrqqSYnrIqX2yc+7zV0tzVlEUzXThcnW8rTogeUfkU7Bu2SAvOssWtu1
Sn0a05ElFyysNKekHvfg2pysroN142d0i11pHJu9G2DzIEM6JObpFFGm2iRiIZ8XISebR2T4Scw2
VEWVjTmLMMwJGwPlyGZidy1lDY8Eu6kiBLV6c6vZA4WyKq3ZqKpGe2qjB+r2ZEwEFTDUswwgbUZ0
ltuo6wMOswFIs0IXVbObAO0o2Giv1E7IgeOBGXJtM9tswG1KK3oetKY72shiTdoiHZc61XcNWq2u
P6AEOuOx7wiZHVKXdX+A3UZh+fq4RFxf69SqlqXaqT5C8HQpYjC7cVoZ4rmSN0/u+CcsIiA0ztsO
tNlLXgl78eOZ3VizjC9dLqh8RLoFjV6IKqHUEzGrKK0BUnTm2amqPIZLXkuhWpZCzQDOIXjw6GEL
oOVsYHA2Enoe8hX2SbbVUIP+M53lLCUYi3QpFx9tS7VS4jnR9W4k4gwhLL4r6XCrkRrTZxO+mFj/
z5zncZ0I9/erW6SbDgck21V14ciRt2xTAyXXvgXMY6E00YXtqcUBqM4mAswU6eyqhffiQGnkyTjt
kSCYMR3ZCOwMvNsNdx7akWpbX2YkjGh2uw3QjripTSe2l7O6wZ7SGEygeTzVJF+TiyKLUzOJu6SZ
haSzDBQklVgoQkRj2DKTHj6OVxrJUkTTb6s3olaGbOwChuVeSbjCM/vaoLF1671nBrO7erax2pd8
iNbRhKC5OQws5m4+BzLnnm7CrjkkJ1ID/4UyJby3/0qNWigxAe6tDLCro1XU6tjcea3R2aFrE616
J2hz5kQfDDNUn7mkWF9YG2i1UNvLYhdbwJb2surALqudaoWBNlWwnlMeU3EcqBEW+5fdHDIet9hw
V5TSwqjZ7dtzBtZo9dSjNHtRWFVyi8XCzq1sx8UM4loIxVE24zzcv16a2mNBcoguDpNRjpi+6iQp
iLkvTuHfjdYyO2pti9MWcFXJapc+ugl18txV/Z7iVgQBS0XQhrX2vhnRPaOuslqhlWoWsXtl/t52
b30AnZzjhObTlVMrOlSBc9IA0ql+31pVxda2BnABYWh5ydYgilYtAyHlngZUIT0M4jb2fYwkh9s8
3Kl5zWv/hskaBy+C5l7c3TGGqCS2NZBBm0KlRVpqV2rmZpwfDoOkXMBkqpKQ6DYYiwlvzgMc8GDm
QEVoTt37ZjYkUpFtl6/RBgHZLrHXATMuTtZNoivxCKQ/ZZfxUGBltLe7iMkOnxnM9jVYuvNRwHhY
1EXOvU/pOdoUeA/jqNLZbbhD+DU3IPT4OMC0z9MLHf0FFr4trnQh/70UmNqEMUnpOpMptWdlaTCx
G3hgqbaLXcRuRBDG9GdzCF3qj94B6rieyE2AXbCyiAD6caYcqfkQqJt1a5Lxk0kZV007ILxAT2cs
A8LeYUWNZR+sA2rTb53S61M90bpiUBpGOusMVufs+4wMllInp6OIMKoE3tKpwRyz2mlqRGDVVsGx
eA10BgDKhirFiJWZsptKrSk2njrITBQERG+euW1XtSseNB7pNoWNJ4vL454WfGbpiVD0Mvbq7sC3
xgQJpefU1pq4l+ky1JUlpYQ60yaiMjxM0qbUBYJfwha58vkUzU6rovuCarl0barO4LQlJHMAJP05
196/ZEQuYSXSLOldFGruZl1rhxKxB0RXUF9yB3MporRCCitJW2A0iEgaMyAiomkE/xzFl+JJ0z7M
rJFzuMo93HhlnWu47ZN/qHfy0kbsotWUobW7RXbEha6YKZzqcqOr1HkPu95Qz6yEdmwFNEnBXrZ3
jj/veCKXIIFHqq+6A8DKpTmfksZGLShJ5daqXeV/xlxtCOxC69yrvHCGs/cZqbZtWesZqO/trDfq
KNAeL1rlvnuaJpaZ5yLUUlhYnhaBxZueiFvz/jqtEdBo74ydHbp2Wkk7dbuQpIVpYyaULT2bII0B
HGvJzhpSlVQ2QvccuqB7LnIS1qwWlejfE05xl/Q0oulp9uiBoS3izmPfoIWAx/rp0BQnSpGG32gh
t95NtHzENm+89HCsI6EG4DTjqVKBpe+NKDQiZCsyyqsY8sJonUy2ep6iagJ4pO3wilR4nt+u6TGC
Y/marXaMngmi8VkVXNMmnKszQY3EY3HI6WszS3Azd+Zy88rCJaJdNpVlt5RpCwnCoUsDe3Ze6TJn
4u1WZ8XRsIx7di9ia55E2rhBM3inlJZ5v9mJP8sd8vqZ3pO6q672WhFpeF/Tc5F2KjUt9vGLTYJe
gO1yZbpgNHWXbGd334L614+m60LQVedGLr5be8Yklkyxlkmnq2Rp9WRY9iHuutTsC2kZTyBnPxcs
0s4XhoBclITOsZFdv8/rItENNVdw/M6OO6a1CJ43ut0CJ86EorTvOAbaNir9XHeYLk56WeEnP5Hj
BWzet1rbxYTBcSlLK/p04mHjQ08x1CAupk0k8VbYJGMZdSbAj+b8rmnBqLucClpzqlSFiEkX0UdW
U/t6mYzZBYodTQwWDhabt/1NopEpKtgfT1nv0iLohyZJhqhczxo62RWbDiqzOU7MZLD4s7BP6dMQ
BFHoH/1txAjvunBczOHRefuudivSuvFYAiSnPsLN2EKvxXlqoyk1cwPfzIsis/Tarl3cht6LPQd1
s2ilDXri5sXNAFJNptRw9QTiXQAscZkcsGraguYOoqK67o58p5uFk30M4zIDVGKc1fswDY4Knt4M
IuEb3GKVurOP+aPpjlgSG872YJd3sDaNzR6yP6vQqo+M0MZZ0TlDV+yTRPW84jbCzBk4tE+nI/QM
LizZEH2WsGYyrz1/qC70zMbrEXlUegaCE6UmqLXYaW+F5pxwDp3nxVJcLAsXGvldil7040gsmhYd
bK1iHrvqFJbEbuvyTK+EKlIpUaWf2LklkQ1abQJkFbkokgxdU1HDhxIrcYCSdhmr4GhS6oUfaOdw
C7ZNbFKZk/WRhpTw+GxenX7D6aQZEhR83+Me1mDV4ocGV6fzzBI2B49kOFJGB9U2GrvbklZWZWNO
S1vWKLSvkjOQlKoiZD+oIM1Q83OpqC1jrrWHpQvrAeIIzQIqEMcvW8YSuXUbkcQr0eK58njSARiZ
pNzWlcRS3FK/MfFVBQqdEo25iugIGDe3E4jVwvjBDEUb9mYPPKdw9VsgRaP2W221ZtxBm5Avg4lE
4d+lYReOuqhOlb3TOpWvRi7/GUTllgaeKejc2bSLkoZ4dFMBQ+V6UGVfzJbAozyHdsuhGYs3iJJa
DpG0iTS191e95Afdx4baDc92I9YLNixmeNBiXWkH2lxykN/JO/e9+N4hRikziJcVgD3Tq4A0rREY
nTkw9wa8VteLgROa4ubmcnfmnBOzWudT1B5t9+JuHpAWY8GXp5XkvgqneBkiKxVYf5fwbD9T8KrC
+2DeWMItULAUwkjjs4X338T3uwEM2vz8Ep8oRispMRbh0oqnF2gYNXTTNV1SuDQtdbQPu85nR3Hu
LOJ29aIjs2gkrcF4iQvClb+05nTBfXf1eeCFi1I85iKYRxSArONm3Q9oAV0QfOneW2i6rfbjREU9
wnSNt0RjB/X0Tuycj3Z/yZTXLMnimSS1T2w5rmYILLsDMzgrPtENzLBa6HUrVlWaU0zG1FW6nS2y
anNIRGcFw2o4+knSHDvPkgPo77QTLOPxvS9xlYuIic4MzsUYGv0+8qdCKoawDmOPsbTgM4qFZHkZ
zs0Za/np+KAuwqzilF+ouWtyat8+Zq7AeV1h4vXdcFZR6TH28bp3P1z8oFWJhM4TbtNSpODN1bFa
u/Uy7fWru+Le757d2PaiNYL72pZ6vTe8XT+Fcw3tefDLDrnu6g0RnXNvRXnGW6XFqpZ2nnQk1URq
13MlO2D9ufZv0Tdr3eGytOakaU5JFf8WlZbBTFh8wDbfNYBpSqM3afePom79nttmz22xuQRrSrzP
2EL74F0HiGhBApGEdxB10VdQgnIvxBU7nvROAOd4Zji0ycoOll0Dke6SdpFbtneo7afuqI1wwSp8
5yOTMlahAeuWG2IH4Hz2AOWT8FSRDHuBhQR1xIEdnTOad/cgpQz9UO3OPBmcHTLwarq7K4OHWGnZ
sBiFIl11tbxYiG12LdWLxzPV/UOKtWL5sSGcyJ0KhNqNEkh9RJm7ZgpQJo6013qwmKHhV5bwtIhK
/+6+LFcFrST3cw+ZjCgxn6Uzl5giE9qeBlisUHSJhEpIo1EZ6TzPb5mv0pKzd3Fauqfhkl5gLgLt
zc9N1y9OU1dkvjOcU/oKpgUJ0kdwKHuflM52CBpZl0dfgF4pbsI+cGZ+FOSyev1jL21fdFiLNTyV
dXuH9avrwoJdq3HNd1sBPYP4++6BQDtzIevBo4tvA/k2CuU717n0KXNpC8Q97i1fOl1uPHm8jwpI
VTeVSWhmH+qZb0qEbaMQJbadSwDa3X+qorUruqh0AasPd0NaUL8IzitU0jjU2Cg0aUJSWn9trZmX
EoaI7tyod319nndOzGWpgC5tpQJzEIL20HkSE9SdJMJVI2H6nGevCqzIem1ST23JACCMscG80rxn
cb/JNI9Ms1/Kplgb08ZbKgd6PE5EqBpeJ8OICWB5tbxKIkmok1x/Nix71qffYhEoHYRAOMDYXcNY
EsgllkMvl47BYzCMIUMNHilniRzVNwaChPVNbu4k7ZGDhK4tXhjtJyKasHQDD6rmMiCo9Ur0HFrf
aavStabvA/qANommSMniOcVTl6YenS/fDSZI7wagz0a2Z6NYPYttWkxRVg0WmlQLyygnjUY6tRRn
5PSVhB98lbXFdhQ+WIBF2qmkeXrk7Dgl7ovrb8Nbz+1fFmpJE9NmA+69MNECs2Wb0HY8SksaVKft
7SLGKNNSVfsl96xXT+v0YL+FBHwW39SHwG24HYTZXTxvEiNVt7hVJeAXqZC/lZeiItSOto2xbHlp
OgLPBNFIU1x3NHlwTpTk7kZGzU7Lw8FXOyVtd0zWu2yOtZxC9lbe4d+GnUsfrXlytfAGuwbF3Kx9
ZgqaiJpMVCkiAI1TIu5SSRjMYjJrSuWOFUaDxWOOod06njITvPvGqOpYLBAsKZAWVmUWMpKClMRd
l5s0PQNEwy1fKfVZCfK4b1oQM3E3PtkIylBHh9JaY4GPfYtgDFUSqRlzV5qUmUynn4tqn8gkJyQj
Dyhe4wODxh1NPZSUs7xfVkYEcy/Rnt0jrNzEOKk1zb2SCAtPl9rTXQJpuszkO6NKa9OZXmSL9RRc
esI/55PgZhOli8cvGqrVhKyNol4Hd5bXsUdddhKk9vwSlo0wgPMwsPImS8N3TlFk2qWdz88XaEU7
O2Onk8qRS666QaWv4pO7JOYiNvGa99vEukYT9iUsZnKlh45drTPuxvBC38h+2aGnOVQbglBGzvQp
dMY7N58c3lqeh65OdMZa6VPjcLwKowW4BZp2Fz1yywj2j7QZXd5YjNUVQjN707xU2l0rUF5YlSU3
oCVtUpvfTUr2M2yQSSftbG/73K1PUDrFRVU5w1TjIkliWU2/qiJEElFFJkGTzCH02SbYdiJr/jAb
RQfEPhCOadbqIOfewjsA15vnhVK8OAM6hcCsEdA87JZTsYhF0HRPeZeLKFQHm3pLQUkrssjRAtkN
cjRgsJd1EXflbBrRsO5xiSnScIZDkRL2xrSqqW3zi72dQCbVrFYBTfIq3bqAmXuqocdt9z60GxyW
YbVv7DqermErv0vUqoSsO6d30ItOLOFpWIZiF7g35+NWXAjwi5Gd7uCNNWpqWa2xd5VB1OKKT6HG
jFiRE02wt5r9Bnek17QKVj0BiCNynpbEpVpddHHMx8poTDxgNwNp4X+a/u+d9t5F1bK3maTm1qVh
sb0QEYshsodckhTf4yUIrNmUGXZNFKpxmDZ7WVTWHWTxfMKVrLODQHv/ZCLawsOkj0RQRdQ/KcKQ
wZoRUEDPglmwzvKtRJ/e9EjVuvW0j9609e1R7iVyw1vpCg8yPRcTokg7Rb6grolfshOgCyq9DKM6
EZkXSqiHxDqI5CROo+6Z+ElA6V6exKpAyhyn0uIlVjU0kY0OoLtz5GA8AB+pHiUSoTjkuxxs//xq
LWpvRm4eNdVVoDppn1mZrbvu0sRNC8Erz6dhsOmp3jhWbolB2qDIeJRUKgeH2vptUI80eLtH3U4z
e6JcNvZ1kJPh3sjwBZ7rgsVJb+IuEQGJmrXwDvChLhvf5+2GFKDvDrWPHt1WofFr1ujEc83qnrah
+1hYCnsBbWE7CymNVnJ4e2fcYQUMunh6cAFnR8t5al7HlAFJek6Xj71kqGOakLitnNpylGjBGUFc
3WJv59NWa+njzr0el2WvFL9uczZ4D8GHDGAZGIQF5lKsxlhTpxQLa9PmkQmfhJtCOvXnkLbV9MBG
GQCxv7/O6QtqT4dXJU8RUVq+W1uZdVEchCI00RGtvX9WFCzqpBjxgWNBE3JT+O5g00x2lIjEluUK
nw7iauZ0azuGRV270kubQZhSs/CNarXgorignOrSFo7VQppIOzCZXDxDFBcmPYJkvob1nDco4V2T
GWxVy9xx11KfELTIvWCtp1Kcp0HaTTinQCW9iHPYYcc0GDJr9wB252HbA/HyYHebeeUWf6bJegxn
AtvIKjIHQpVoWuFHRQVJWNq5Hadb5jRRWHcADiux3GILCYVvZSRWNT576pWKA1LXWrobEPUUEoJq
lSdqcD/R3OlyqtNsPh6t60NzspSzGlmzpcjD6mPY0IPfpVklvUMK1XOQ7mbnx3B1gWRwpk4qgGPt
/XHG2kmyBPb5IfGLO58AMCtKHl1D0cJXlVY/GewXnnWjlzxR0R1MlN76pehm3tue9MSPRokpjvjO
SVTSGqEtPGWp5lqnpbCIxAZVcbaCduvn5XpV30TgUTTu+taqOQIKZUrLHaKtSO5UTDpP9XN/P2p+
4tURo3soOGqP5NXuRj6ujC3j6a4vaEVZbQFojKgctGaiN9YxQ/X9dB622RtkdE7efv/rrTq6Bj8Y
qSi7ZUpbXA3bL7b0r87fdLIjmEHmBSeii9mW1m7IwBFRUuGd2Vlzro8zxpYloos26m4JfFSEOcU9
t1U5LBDKLkYqytx94EDzpM1gv2QHVdwlUtm0yfnSkZCbL3wJq3WJakxSYxljtjgGJ8ij8T6dMq+h
oKCdMe+q9ZXOjaeMhYLdodK4A0tGLfaZZ9L279wl9bSbhjXdxGK4p+dgSkdynhBTr40dPdL2YDXn
6YFud9JUyp0HjwT0sWMxXnzcdGX/9DrgnfV+DdDqIozQ0sabTc62Bls3kncmFThijrb1b7NWnBnC
LAomujzfdriiOzlGOG3gBMh92WKf0GcPaogluT9A3j5hnLBTGZzjUdbIl7mrpVZ1hi2JbwtAiTRY
u7D1weaCRu1BT+dadxP9+IDE3bEkq1W9X3i1NNqA1aNvO4yGxmxZbQZCmVV7T0ZnH2B1oMZKNYu9
iUhwXfYD4RV2yhmApiBEhUTSgbxZGnS9qKJVDk56lipS/lqsmymOy7t5AFNNApCIvOjgzpNUowJA
1QG+sy2IISEtTllFdGPeLTPhK8kM4oiHzTw/22cwkdqMxIbKU0d4TqSQShVMrlSebjmggM+ftIX8
ZbJSMv0lPZrCUnlnUkKrGa1Zx7TtEmpxiKDB7rtAET4VxBjsDM1iCS4EULxXkxzciC6hlxUEGKuU
Nqymdj+XWI20kD5xEanPZU/XifQd75eu5Zfa+SbzAu7wGGjzKDRU94yq03yTKBL7wHcqTpvQ0SWW
GuK93ci+Xe+iVOQAc5Uj4Bz77mosczxte4sznmc35upCH48hbV9f07kLPZmPmjkacKZViBhCxu6C
mQsxGOYN3iwWlEQJktTVqqolyCRLBelMAB/2qhAPr4S5U4klk1S3B5/5bCTdiaXrLfTPxpA1YMGE
strm44lzFf0id/HMWqP5YJJyQOelbi18qjbqPPzS8gq3cktXwMJLTctDD4hJ67Qg/VgvZBlC9q4c
aw830QeUYIthGEzaK+GGXuqjDCUiZRMb29xBJXd9JArSYRCTiE/SfYHRivhVoSlOISWFPwIgt4tR
mWYY6XPrEUYB4TkpZkFjcSLWvjIIKjqVB3Q61YfZGVJIU1gLALGEWFMWiH01M2FW3/nambQuXEjm
HByfbkcbJEuZYXYQsNgMsuSUphtdkSZPtWouvvZNT1GqEytVqu28hlYAqz2ZkGl6/FfFy36liDBY
VDp9XsgugpRfmtkHVY5T7SFS2CLRXyQkJYFtUPOIpZKdkw97F2mJ43hlpta69Uo+aatCoVLUPW3q
LzXJCx+3JojMDpHTaCqwixDFOAV1dGeTznGshbfBfy0ioqVOmgHiuRUwxwF0FAlt3xizozQ7sJ0X
OCIyHdFqwRiR7g1T/3Brcpsnn7m37zAs1Nze49Dc8L0UA7X00Y4o2tmc3Mtg7CeEiLsJmlClksID
OTwFyKT1ZS+KMFcHs4pgjAwjQ7ihkfU2GLaBDn4qB9WF8MT0q//2/uxW/t/58zt/fufP7/z5nT//
RIvun/23/2IQJJhKdeKMo7JzaKFRnN0BuXmZrvxaHjnnTVc37y7u3X9aRI4PH5pky5qGHXUr8jJz
2UTnTKagXxKo52LQ+OjLEGGbjKucx3tRBc7ojgWkO91Zidn28UGUIMNq1YSdHCv9OPPn4oqjBRWj
5qjnPmKBZWbb1fQBYezsdvexy0+ubnTKEsIoE1HlvDrBN8o9cZwTdPkjqc40f9ZMN2t9mISqqMC9
cM9vLeq5TNxbuuaPWTwZNlKmSCiI024jvemz37HdvWTDy5m3amfe/FnVI5p4daqp7Flz4hxohhpd
C9V4q9gFZ1cMePDu3XapfaM01zQF70KW1fXe7OehS99trD1njmrVfPNyeNspKwjRd9KmaBGbI5ga
xEHJcnq3365MDTkUkdScS4/E7nRynDE+ESMfxmIv35/4GIVT+ZdRuiJ6xHaRnkE79y/08Pk4BrHb
pc0wdMHoggxWOiuxEyiqjZmXGAbl6LECfpPCkHUw/LtNb6/EY+zGFiLawsoKtor9ACRhHEcHe8qx
srG0ZzL3cqu1z4f3Gaz487698d3fUhiQkoSo3c9KidHVbZKIBkBMpvtPZ+Beg4IT13K/4iw89dQb
3/LWd3zm079u7DIQ8eB7T7/u4asv+ZlOK7qEvMtTUkSUgza7eMtEye66VzNv6Va6jYXh3nArZUto
nwRwNo/RJTiorGA4hUVKSiMcpW0zzoGAubsvuf9Mn9HlHQAYviG5UWTmtMz1gX/65MYy2kAQs5jX
BuOH3Q24DY99WRhMwOh81DJRARHh5FpZTDs/ICJWVZmRMEXNzMv3oGyonqlkg98CIs/zsmLh6oJ4
DFtmcmBsSm2JCutd0qRISFkShc4EJS32p0LMNMO+OzhFaaqARZCHJx25gCEzaDRE16SlcTFUoOda
gpCCk7SXYCb10ugPql3iJtNBH//2f20+w9Ry6EC8iypx+wzLjtAkxfZuLDVizR/WPmROvze2wdqm
FIPBI6VKpvBTcOjrIj1XKiOaO184+jBELqNycY7igXLXQIQ1E6XVkiqpznTiTFsuNERrYV17Wa8p
qpg/VwjlshNtHKj6u4gC4c+lCsJ0KR9CadEsp1ZbUBdoRlqgouao4l6EjEXHROkyhR4G4x5cJehN
ApfDaRIZeuZ/no0soyWommYjFJUR1KGim6lWvREg5dAfaHAaA1kjp0RSMDI5v6LT5qKV9DfPtAFX
wJOS0sNbed+3v+8zn/640o2RfN7xru+8vX3w2oOXOGEmLid6MCj0YDKV2J0QHcMXAnH6MqB1maaq
8ss54OoDBYhlTjK83VgdGRSxFHnVJpdP2qDlzmZP4KJL15+qGV+K6pSgLZp9EHxNG5aVrV1P6qVi
RDI3KRhCOgJUxDIfbkwt0hhEanVtYEutUu8Zy1ABYK3WO4QHNd0MEliy6YkYrHVZKspGsKjHdTfa
yxI2GGaZ2U1vysEjDsM+NiX0IJoynU4FVWK1EN54gijEpssgtfEUPEXGhx0++w5Go2Ob7pAcX0BJ
J1E0JEXASOGZVAaPx8/n6cpJaqVtACe/g6zMpYeza6g4JvaVPRCO4i2mijKqLFlMDswylccssTZT
HCtryDkBVQekoBprVYyVG0Us9vhmhJ3BWS6M7xwHSvKsVYZW3NdBbEhTl/HyFMSKxbmPzKXDTZi0
xbhQkqxSprKQPaQ6fWiRgabWBi5aIB/Je5dg7aj4ignQIM6pPnVbQ6NdpApJwUhfcA2LAZfMcbLq
4xKkeD9vxnDlIuq6jvTqSLELWCMCitiBfrgAJrN7vH+SgvXFvzDT1jsXcLpnsA0PBOXIagYPsVdV
jOKtB5yTBoMlUsw7AXHdXv8cjetnRb6uE294w3u/7/ve/xN/6+9aLJwNM8uyLJqjafdXNikeB7ZQ
I3OIIZH/EE72plQizW31sPjsFrnp47gsska2s0Xep9lsl9GSqSWNoH1yjfBwI4pLWJkzvv1C1jJX
NJBq8++HJx/lZ6oqKVO6pTBI0+m6U4+cy5SOOrkG6CQU1d9HY25Zb1MgSaI9uthHfLF3lUJM3Myd
2cuxlcsICRFdZm8xEAa1oOAZs0iECTSqlSWfO8WdAI2H1Rp2ESUSDn2K9WstNBy+NSS2XVo+oZaL
Hg0Mibc8UKIZjGCLrjTjs+yFpyrDVynnU0d6XE7qwxc0U02itY9UYW9vuyWCz9KbqlMUwIgZIBix
//BVWiP51ii/HoGu4psrp6BqlcZivmTPmFKDbhii5emXk0UmgkUk+whWZjpZad5yrEU146BI9IQI
DxVAxUX4RDAc/GK+WgqMpjK2Lbt1TpRUi7D0iRKp6jmsXfWgoFgIo5FDIQtQEIukHbq54sVjomoq
BbSNBZVkDlCCuH4lt8ocU2BtbZs7QaGABHehdlJAnCtB2iVYTJQ2dytbXQfUDUNaELG3dNTEo2kg
qE1BLSDSLfMubI1i5OVzX3lNjRxKG0sEc2rB4he/JjMTDd7e+Ka3H66e/tIXv0B0o4ztcNBBz731
vQ8eXJHc+1N/6gM/8RO/QXprHibsoicSVUhyz/2qu7qNItwX7mIIJq7cQ5grSt4NlUkS66qnHQ0O
0bNvPmx3hKQqsJtPNFZPIkixpIdTgUfXsIbogZO2mTt0Tb5/7tjRhZpaxk1cLihuIhBk1SwEwfWw
qzndWCFNZRXtwfB1C+5NYGthEotB6oT+DkUCgRdGMzuUBlhilxbPdipyHZSiqETlk62VpV4BEUqW
rJJ3lzan9J7r1likzILG0gYXy5+DN2fvmyc8BDdMrJgmSGGYj2Xj5cZOVCoUJdE5iXMObVKPlESH
ADlN0yjEB0GOQmXDi93MOMv8Mew1BMKI8YYvwyb4CIg/2kyB9pxmVP/pqTRmA2ohozpi+4/uza2y
uPI1tRtZk0fCC+3TIThSjB4WDZcJZcvHq0DXuSYOLBDT3sKhJ2uFlJ85eprQSDOFEIlgawAqAc0f
qK2EmcbDUa2MZiJSZm8d1L0qtMRACMIZacSHFK16eG1tT7Ofh70NUTVvMSBgJ1IDTKzdgZyDhSe+
Cqtv9LyFCJ66kLb8yCV/NuyasnlwwMCewI2o22Q6rIZKyoYnDlEBhXbqNAY0qZwxiBON6i5zfuX5
L7/vO37gz/0zH/z7H/rcSy+9cP8Nb3hI9MEfePsXP//2b/9W+tSX6NXbr+pmMkYo7PI7qpX7Sieu
1fNfhE83pXJ0WPpIYyY04apabaBzUL4VmSMfW57km6In54TkwhcT0datMJe2HDB9mksfzAoUWH3r
GktMSqLZ5Hb5pGnBJQxa7DZTyuv1sSWX+9lzvresikFIFMhgEvouV9kAeO6GXZpegarmBZAFSGhH
EQ5rGp9DKKZImAjZ7gU+MzDcBpnfpj1BxVZkdgzHQk10mJGKAJKaApvMkrvlme0BfJlUNKtOp0ba
U2qPkO8PbETMpeUNinY4aNrKFE6FPtSgUoohscmIqoY2KFa0CaAsFgxh3w5PXMFmCZ7aHdz9/h6u
gl42EIV+yU4UJ2VXqsnYs74z+e6c8aTWQaOH5jZ9SRoNqaruADpJcIZzHFl+rg0UEoq+KmnXdmWb
yqpJLQszmmbyR64CrBwFl/QR1E5OdRLxDOVswwIlVJUGZXKcQ4VK9YCwUf+b4MwcyB2SRSnrUHxV
ujDFB5dkJxMhvCeTTmit1i8cT4y0okvkAO1Vfz7acoG9NnzNLbScPSGazyMR0YYRgXeeS6shTgHX
pCI145rz36LJBxRYT4EH7oEGkZ4++cl//MLXv/4nf/S7X3rt3V/6Gr3xWfo2os+/lV5H9OO/JYen
758e3NLplpQUk9AyUZf06kAXXVFZA6Wux7MgJjRPY/XulXYcj5jzSEJk2TurbxRDvxrZ1tgJyQP3
TxKrelISujefKjHcEd2WqLSAc8dQTzRNF2UVLfM5TYMEQY5bXNfp2IwYmjTN5wtlUcIEFXdRWBVA
PXgLmchoCK+m+9jo91jlkIsnF6YqNahNIQ8TiwtUFYWGxttHLC4bzP2mO9VAiQmqYI0nk9LV1+aW
tjzEZDs13g0r4GZLhcTN1X0sc24j7lEF67DStcNw/8E9EMo3gS7Gd0mhE3liDBUS6crfCr8trzXc
akOOLDXnyTWsa1WkeyVk2dq5AmLxDW3Jo6IA2/6PCS10OSwMQ9PhLfBAxS7k9jwKNKczjTYqfOpI
wJaTzmhiGU2uUark2Jx1wwKREnoMXb3YqkHkYlNTQ2tctQg+IX+fSpUJShlTe5Y9hTKlbNMb/8UY
1Cw9fHjMHFw124t74gZny4WKpD+TCaO2f0DmbJczNqmUZSMVHmVXLojtEs5OEdPZ3ArqdGmAnfG0
R5qsW0YF9m7TFBBtyuW/Q9PBLG+TXdZYppxaghxvpNPPA3F1g+BGyvEY4PalVz/3//kJ/sF/+gM/
+n56B9EbiT5I9I+I3vYe3sb3P3uP3vYWevUBffozn/rylz/98OEr6A5Q5agZyVYgBvvQg1gqxcl5
ONGwuF4xU0D7Zqob3XPzaQuwpnkuERG6P09sJEuXnXRJbhYsxR0MqT9i6k5t5r/T6Gl8DnqqRMOg
Y1lJFE6YGJnww6kojVXedl+qxMPNLJKMCLBBvWOwqg9LVcW9aEyIpGpRkGDXJSkiC9K6oTgbSdPz
hxOkXF75s+AAtnXXaSfOknQs01YmDkMFv5pWBx019k33ngrbTCTSV6c5c1mHaL6HKHBHk/YjiCse
sSRlB55eoW5e1ABR12MvPWktPGjx5ab1ptI01cYbhsiGXloLnGlDRR9vFAmz8oDFkZzm/SVcx6M+
HdXFQVAjAwFtJFMQtnrPOwbKLTeaRAnDH1WJkVMVb9VaEBTiSIDVBHZUrPiF6v+n0J2kBlDFqWUm
RtqAa48SDTQbQSRLFXdu/VUKRCfPlfTJksNCSLvcePzd9dc/XZxy4xt3a2XTAE2Dk8UjOScWT2ed
jSTzz3i5LmAEEYkD794M5ga6be697xHwQBgZw7WJkSGFxlsLtylR3Ugr7GsJ+ULhi6SLY23ePIKQ
1pWK10TviqA0u0kMEw/9ytfowVvojfEm30/Eb6NPvY0+8RH6+b//Gy9940ukD4hmKRJ1FxxWX157
Ps/6rK+KY18mOVFDQ2w0OlOf6KQ7OAxyT3ZDrFusssTTYtm4hdjYscLgYBk+IjaiIJtqweMCJTj/
1jQPXbeMmU+S5AoOm1873TGFh9iIKfmrxv+I2Ykb9kVKuAsfkWSMrirOIVVs0SQGA84Xpoqwbpi1
5T9FsJT65tdnkEpVeyhZ6AiKSFgPhxYyclnBJKIDKdnWlIeC2owR5GMTqCoiXGp3acpXm8ttgQ3w
EUonuWQcgUnya6ZBno2dGftg0k7frsGPg58GO8VlBjftYkvb3OMVGgNDjlmueC6bMUNEQmwelpzc
s/qo3dOqyV7JVsas69itDw1CcQpp4AiG2olFugPsnUotfRwKWMc5pXYDNttDQO/wHiSawwjd6f74
pSPxN3TX2awikegbBODAJ50HJaJNBgMmleAgwP7eXE8qckNRLn/NC1DLPV+0AnOajyn6S5tTnfcG
kqEUgyqZwraagJIOdkGDeMvvLAY7eFTsMZJUzcMcxkgQttfF6IDz3J22kZiEdwSbNHe0jHkq9nPs
xG31QHNOpByjM7pySpNn5Pvg68PVs297x3u/87ve8W3vone3svIK0a+f6Jf/wYOvfunXbh98FXrC
qlhBMPQ94DP/v56pppJPc44Qc3eplWBlyUG+609AgEPf7AYzvkUCNT17Y+2nbWD2LFRsJy3Tp/Lh
aWm8RQdGz6Hyvt4pUEhRRfFyKOzwgjxGNdBHy68eiQ6GYpuTSFuVOdtSYp9jaxNGqT8gzfkkRsbW
gDOxNV8udfF4KSoWZGhufAseRmFw6wJtFAnbB0iMDWN8zB4yrmUWKsRBVA/OpUM27Fi8ceK0ZtRN
2oAIwEryVwLxpTFSleR6s4mK0ATi2Fm9d1PthVuX7QiIXdBe7OgmQNNd5Kk5mFawcjd658V3S5sd
a8iHmgVODAkipjOSYuKmZYMkE0kyvKV5bmjFvQmpz7KpcdL9ZhUTGTTAczWh8p1BeGEHBSzRwnKh
R94mlDoSly+l60NuNJrJoSYRutxPRS1Q0voYNeECfAAckk8eFQrfZByj2KMcj5ozKhTN9F6K0ErN
rrWive1UzG5AFCa9VAitFWVRgnVUjsn55tgS32yiVBn1SXgIZzaEtMnw4oweLNO3jVaX0iR95rtK
0wJIX9MoGThoy18RDHhsb3j2be97//e88x1PvfYqff7L8/NfHV/9PvoxomsiInqR6M0b0ZwqR8SG
3kZhcVNYA4yBAYXzXqMfN6RFxDf1JMre+1DfMnoXYM6pM+3j4nbRkpf6pDc73rIi0fSpTKfPguK1
KXuUVhGEaQuz9iX2BXV7RSM7O6pYGxKESWRYemTsXItji8AQNHcmhth4L9mdmq6/sZtD7hoWOaK1
z8afaxGsyBzNdFJhhgitCtkM78vQ4Cy50VBLVayIAPfD53IX1lSNOheDbfzo9sLZ2aVbKIPhGwF/
flZzqlT1dalOuFMG0c03YjGACn1DmWwb7qxUZHu7RwbSEKaJnLk9JjHHz5rlttIz3XK00hyIF6ZL
EzS5pGvU4LS5oGPajBJGC6Ceo0bRKhVRArw0BNarDZN6BfyQrQb14MdYXcIrD9oKsSQZX3OEDs2d
AUQUaZljvOFyMg17pjYD7gb6tZW02IFADZIiqGLgtPk+anKTnI3ZQxpNvkSZqxx2d9RcetQFBy1q
LImklVQcd2Ol6KQG0J3cgsdsb8koaY4SDR4SFKfKvw4vQYklf5UaSPNnTARCgiPmdKK00vNf/Jf+
0t8oxWB6KNqEqq1AdW9Fl+Ghyqq9PLlAnJSYxuHAOMzpNw0OV888+67f/QPv+9430w3Rs0Q//zzp
Lb3/3fTzf//FT33ylyGvOgjLrC7nRSWGwefe+05KQlgcM2weMesM1h7tEhggrU/1u1gy1TJ1KOFr
2AZcNbdGGQ5qCdxCN5KR6n7Q3HcCvo+V4uxr4jzlSSWZVMOqaic2ff7jeqXBQOV49EyJXAlCRA40
vebqPRAWAkoyxcPLOJlkFIxsCyTBAlB0u4XIFm8uCEvaajeaNslik3rWmD2x8o4q2QMes2uES3lK
EyVLdmG4beXsoazZVfe5NzvfyGRZ+wBV5pFrRgpuEZKeME90Fm+bmhrlX+1IRRdXYmScdARRdc8y
7Lw00LXcZfBApFPUd1Sq04WgGred0joqQuPY+F2rlL4Lw1MpXJVqKcrIDPRCPWJNd/dO7yuYhxP4
nJ8jC52Skiam/TtWkLpIEpcdNw/PbZsYxUSHs5PNGXULN+9G0FgCJeN0+G2TBvSxvZBQhgcYWNei
YTXLJ+6cPv2+ZuxFcx0LqKMt+CEzJFA5Oak1o3ox6QxrirW4aTjc1T/Zv255V3FQLfoxWefCg1Ex
3yqixJVIgz66RvN6EZn6kCIoR0+3ctR3vpn+i1987fr6qT/0ffQbH/vyKy998R//0vj9P/i73vq2
H/nFX/y7dHrgIx52wpkDjJ5J4W4TvWq42AVGb7deNEZ/geAM5iXqoaY+gdk7XJh734gvCBaULcWG
F0dSIBu6L6nwAxHYCUhprZ2uFBHgrn5CXEHsTOHydncGi3Ds+9i6AGhcXTBqwBJrTLN6tF2euymE
ZA4pXY4BrK5hCS4gA6VpgW9JQYF72s53SJJZdZauL8fCPBb+e+19M47PjkuoG4GjBSA0Q4/RXV6s
oodAGGDiuGvTmpLKklEXUjrp6u5bbgqpXVDdGb5ra4A8UTMTyKL0NZwQYTru/WI84VLCDIQExAqr
BKAVjO0atLY9tObuxabfEhGeYffsXeWMPVkmJmlqlrWZSbjla7NqT+Ka81IocMTsG1zQH18ndlvO
pgUHKSi+Xaf1SEachw+Rj3qEWtqvm+sGNSExPN+7S+hUbBMnpcKMeOHm7cHN5sT2+Zlc7Bt4r+M8
yucfyRTguMZpGeA3dNtl5Uq5IlQBNZszhzZHpKCxlsimuh5d8hrXMOoS3NVekbXTNzWlPkTMJE3b
YP/PViwaJ5uUHYpUbJtSM/k0/FHCdsapGHFGnL4fWxE4sQA07/3hP/D+n/uZF770/Ed5PPPwe/+p
V7/+wsNXv4ApP/2TX3rDs29557ve/YXPfXzOk8lGlNThMncjC//yGOtXHx2gfDHC4RsLV7Vxk8lo
bgZzkWTNSLKMEKPk7/tdb+VKKZ3lxYfjKU4HoDQhJO7ck3I7s5Ri/3V1bC0HUMQtKoRTFYqoHBlm
w1AEvyW+u23TPLms+X23SCgijoUyKmmQexf7J+OiZzggIstPaSiHACjN9GPw4qJzhzKYQguqWI24
vK9JMQrH4B+uLmT2GWDBC33T0QCycgLRZiGAyOPqCeOV/WIJvUZ0s/EXl2RfTbFBI3yJBzv2gZrQ
afLINPgBdrOXQp1RzrFRlP1t3DZH1kjunBAF+c/uOFVhJQUP6qXZu2Tu0d8S/mxJenDUNGbp4Ymk
lbwxRYd2/hEiVg+efhtqZ/VxEPVpVo62agxFpcEJZXKxJGx1Huge1DWQ9USX5ktDgUeBGrnUqE2x
ewpZkzKbSplViDQn9soJ8QFjWMFKTwiTpnMN+CqLEX2+rmKIqz3BfiYHMAaIIJCMmghYswq0KyB0
8vAHXGZ6WRurzZtqFRsQasSTLKMg52fHXiI2rDW0bggHGtwQyaOgDWV/IdxsC33liURmCnVS2n1l
FghJEhRqzuaNH4GBgaFKb3/Ht776En3uU78KPJi4+dqX6A33nr75hgJKuHn5xc+99I3M3QqdS4kJ
rTMr9V81YY5jhTW+Es2CZ/z7SFFuHIXsYgb3FSrHkhZtk+pSKrf6uu005MFgwFyXOJbTRJDdVsRv
IBWtAVQM0pDol5kY+N67Hm9yHoV3wXUrkgnffZrqdTNUOjUWlKCHEycgQIOJQFNm4Q/kjMcMD7Du
hhdCU/cYhWq6PMJg9LKrI0xn+TT6ZiJdvuyG+MKM/0Woi4PJ2WtNXB0PE4jY9F0acD6pSXrDO1WS
jua0SalTzkQQ76MYUItUVsGU2DBxeLpJEXpjcN3i5NMVnxq9PXa14mqeyCwM27U04MiJWtJsJLVV
TsULkM3oT5mqWTNkbUNvSnuPIO1bwx17TjYSuqiEtoKjyykRYg++Q4Zm58eVA6oWCKYLr5RIYCGu
BJR4uKbVHKfAYZQK1dMyDMrixUboKxuG2L06Pu76xA53pq1VInW+hyiLW53U67loznG2LAiWyco9
NKbQ0MFOXpdA20WUIw0qZRJpYMMxvLKHtTxRIjQuI2ussIQ/CLS2CyVGdz17SXPLE7O5OZESbcNd
vbhi0oJd23KVCaoMFrg0lFQqIzoM/DXMsxqXVeN7bG99w+v+4c/9zLU8AKB0/MxHP/+O5970tc9X
lkhMyQYynsAXbTP6cDBQrLXwSZhmXi3WyXAmi4CXwHuGUxkTG2Fmu9EJnhVRLiO2Z+PRQL2UaIg/
u3YiPfyPtEkOFxZHa3cogw1t7Rah1FKnGUcbi5ZkoVgZrgsbCHffCumGqvFkgppGJL4tqhxzsUH3
0NDZUshlVAKaGBRbC5fyet+K4GdAmaLKiycbmiFJcIoYLu7NHiMD6Cnbca0sZZdLVopsc+5tFqlG
4Z+aR2sHwdo9NbsLW8YfancHLPUaaY4My1VRW9Bxpfs66WKxgpAkTGEwK5EZdobAickEnOJCFZmR
iesrTmOd09CyuwoSc94YdgTB1IRCVMkIC0zNftslyiaaD3lHk1Kp2R84cy7mRukLKB2YIK8Pdlo9
GrII6tTUKmaLQMwDhJGtDHVsOilGgblTJZ1k3U8XB64oSq4Gwdqbushu7WOVyFniaeiriR02iQya
bCRoKlWR4aN17+yQiS9u3AILyEkqY8JQnrtpD4xktxI2XFJU/dy8DcMn3UdPAAsE8XiQBUFJ5524
IdzdyJLuoaiBlq8BtvvbBiurBhvH1M6IHJ716cJ0Hiq0SAHRZxqVMCxvEcxEh6avDtsnPv4r8/gK
x3T+hS9/6v5T7x8YSVdoIFUauRKzG5EkhxItJzk3FmUL4wiPn1YRIalripgxtohpbL4N8EG1Brwa
nNxs4ZrNfmlBw1kgL451r361c7xuaxMSDUmVLMj7awTjTqlSEhmQqc456nxV490T0VTH9RPDUiLy
LxUqCxOVOnYwmA32VRKDckPMkTGtjgJpzCNiUK2VR1ZEnUpYDXaju/2GUjGoO81sPbeE6BIH0R5N
6vdAElTZN25oBdyUaMxL8HR0RgXcelK2tDzYBPfLllZdMF2/xC1p0O8e9kFrJttntrm0GEK4bcsS
guiv40j6JjQruvR4KVJjbgsqP8r8kVtmgS9FvolEhfBqbYBK6xkInhhqbCBcJNsSIOEZmu4GKBIj
ysbARz6cfM4ljb3vAYRUdOaZR6YzhudhWJJ59FOfOacHQdhr+yYpjDsZXRjfiO6gxgXI3j0Nita0
wqBqUzgq7QJ6l4zGliNY2AqSgOBXJjTp0ML0PTJBzMYg7nfpsRJsKphyxcd6TjM3z9sWBgZjEMx8
V2ZLCQs2gUGgG6e43RB5dxpcG/nqSoycLynzHSMZnBKMOwN/tQWG4ShH0ltl1hBf3Ny+/KUXPpdh
Gunc2hhzWp72JuvSRchGZRuxpwBp+aIgYDgWHxWG2ZCldGXwXRdKpspIQ26vUgOAKlEovZ1bu6Qv
juMMScxGswiQJF4lWgIP6AhoLG5b34ioySvBFIOmtFVAhsSFLtnOwuha0PBMKVMrspxwFTM2RRLa
mn8Nh1V2jeKLH6Y2jdRiIqV2AU3LT+AAl1UqfjqcbTLYwhBzLrlGTvXszidp9oqRemkyBTFehi1U
klM6H6JzAUzuogCQRg6zWo6NhPE3E8Q8CZgy+Tyn0I6bc4a9h4FDywXxeACgU5Oj1uSWwhhhlipC
sw0SYc70JDLDQbi4LMFIEfvIQkjtpE2t4VMiMBXn06M1IT2npKu4E3jpql2CIJM0qAVia0/x49QP
MICR4ZgtqDr1OBS3jkp7EfUQwjoc8Q180nVywm1DA+4jHEnPKsperXbiVVbR0trNtz1N663Va4fM
DnulC3TKdChsGdyhzRwBA36hdU4LcFi6xka3JLRd6o9UJ8pURvp0NU8bhZNfY5/poT1QNANNe4S3
xApllnEKmjR6CU5K5XfMRBsMkNvKTICMvbPf00YO4VwPH7z0lUpJyl7c0RvhMFwlQHXGNBnqplqt
VfGJLy1ccuPdMNIMNJtykVPSsDJVSQtYJDBEZng6et3kUujEVXabeweA4DZyvs7bN3GOsI89g7vG
1h2qWCQLVb6E6fjdRwAImlAaFGsPwI5HJvJ6oWHDSkIz72hpXBGCTjrZd8ZwoRON1IoHwYuhojOW
X+Y0WIag3IQW7XWALNozTalMhFBmqVTc0pI4snd/UnJ203X5pqViVoJxYrjYZnJQ57v3cAmOSKRg
Ivr0deNw9XZGNYbD6k6w4JI6Y5j1KWnAccquQM7T6mkhmWrCjeEXd57PMO0pNoJgxCSA2vXUWAvd
I6dWBieAIUy5TZRUHq7LfjjddpsRf29QR9PvOic6fT3VO+7i+ToQh2713UpCJLeIpss82sAiUtiS
F5RtOhq0Wl1BOQ/6lltECO4BpeXNkMu4dyNgrlTV5uYXY3+0dKsEeb3OZF1LFpQ590XMiO9QAzDL
PaVbK1Yf33aUaK4kO0JObIgtGXdnOeGufzO2mm3T1gTXrGK5US1kN6HvODSdClLaUDMCwCCO6B3W
g0MSlSIr3AcH6Y8Mt/laLZUY0g0JUG4IJ3OzrRQ5uKqFQRWZptTdj00czCIzGhZkzraGBNwRR3BK
L43DlNv+WJ9VFyJKqLYlSTVIPapicOD06iKaCBHy+5LSUjxwMa3IYMrkH+svlQdaolqAgVzWVDTt
NhioLGgK7keNZv2xd3keNyPYiNGpFio2bLYM2bi5mzFQ5O+xFtWNOAw8iaC0JaXP3QKbAXIMqH3D
gSKCo0d0o/p96Ort14RgMmsV6anveZ7jq3Aa5qRfMTcVpgYnz+o+RySOUIghm7yAoxPjksGrKA3f
yXTJoONSWuWENh4xa3MbRk2m7shbx8cWrghjTisSI0Ip5X3KmRuiaokO7ixPSQZJE+aIYeewf2hk
7aKoaj0m1VyhxRkG3uMxUX5bUktG1B2g1DEQp95TVsMyke3eguUO1NnMpuoQbbQaPwYqjUbLCkXz
KM4wOUOzo92QYiCFntFFIUtTXwwPn05rbK2dJhyPrVnCuzlP5u6oBNQSNvUBG5R3fxGWEwIKWggn
ZxK1GZNsmCQsuzlsSxqKHpgehHb2pFn8wZsrR9i5i/ZwhH9bmSGhhBshkQkGr6i4dDSOrCV7spfI
aFRFJxhSbuOVuk5F2spw1Kj+Q0nUI5/Ud+XMOVyTlICaP4xtCIPPScN9e0M6FmgzNRs/ju0WlUJH
UB71bPGhxtw6hSudnTXpRQpcyVXF5ClH3FiNKkhXRJHPolOlfFvoW3tvr1iMksKR1iFTqMxWuRmc
5fTShkjuTxCULA7+tlN8IlgMwXCoeNhoTyw9USTlK+WiZa0Nt+aFg+4N4uEWMM0dQhJWchIjg4Pn
qy0HA6X3C80mRRvlhlmkIMm42sbBwGihiVlbmTjOtV1ubRIkdEYswWjpld1TAJDh1VJ5DQOcFpkp
EjCYP4CyfAQ1vO/SosN2CZoKnOaTotRMoF0MVXpnaHdYQNmNNH9cd8akprkMUShyd+6KzRYFFYw/
hBO1ytSwI+PFkFXUzUUq/oLL9koSOxUK03TfbkKoqQsYZo7Djo4iQVSUX7cGJUKMgxKmL9F4csta
9MGXSweb4tryG6ajC+RRkIH2mOFXQRmVSdooo9poeIDHjyHiZN3/XDR511IvpjR+UBMzqxbr2ExP
0810174nnCMJAC6WmLEX1Hy+SAXKuvn3lhl5qhkbmDtvpCYMpXMmPWkYzDdDVksSq95NfTBEkQ8S
9b0ow5qAYXXfAX/3FF/2bTJqjFIhDBGIldRmLRaTKntsUsXOmayrcOtyTdXErpMJ2eiriUaxPR4x
C0SGP0jFWy9quIDmJQb7lIm9gCJDGiMB2qjnGm2+Gn+j5pTsw7KqHqm/1yC6N6TNzjFTiw5CihQ9
UFz78Cnpo1C/fRFTDG2JDSBiGu6YFu28iKKsU1CeI7l/Jx9Wo7kkcMgdkSXJqQ7en4X5ms8NOdOG
xasSl87Yd53NpsIDKFzJhWoGJajmSmUakVHyxU2KlFAtHm0Gaksy/2uzGOtfyf3Tsjxa0pqpZtJL
cj/8USoVBSUlpB5tLRs7anPGsvMtg8zcK4ObZVDyIFsRCfwiVCoMMZZrYPTU0go1hDVIliLSRNK2
GNrs65Oo4ryY5qbsNETXPBltFGm9K22ODSVxcZamY2KJXjggJAqzT9FsBN3zKzOJ0M+dNSiSgnrE
PjzEW1hYdHnfaks9806m3M9WM7O2N00BisgaSB2JeAm7BcM4Yt965cqOCwWjpKufNfpbknzLd9eJ
QOXv7oZl2pq4DIqMcM5QBjshywOp7Rx5M6Claw8/vdaYqBaen2ZxTXehkvGN7uYtLaLd1vc+QJDy
YNTuCetNmSRrO7skRMCTIdHeOtncKlAFC27l5FypMI8K64lqnztcSc8DShZe08wUsiXR8OmqP9bB
3OIcc+RbnIkIiaJQqwd/h9LmjdpoOhWmliXU/BKMdjm4ZNpBmVK3Y/QpU7DqwtaYiB2Dzo8Z7mAd
bDf7CBNtj8wkFgWsqVLPGVcSKomH2/q3KB9Om1B7UMNY1DblZvap4cBlJ4qHhZb6OdSIqkymYpgG
Zlix9EjHZG85XBfSlXy9iLQwReoqBw4WjScGpO602TUnNz3VLsyg7k+sKiQ+2ir2bszaqXuvF80q
CEHdzs8cDAKjir2LpOkj133cdx45i6qo61hAbVyR3BjnAy5S7lg/yS1KmuFjxFaEwo9L7FGO9oFS
aoUGdBaayT7WqYObZCYdu+CW4L0lnx2+58uJqLPjtSzdnUGqpXMUVeNESoN8EMXNXjair5CAUuwx
BmOUs4XvTNDI3+mT27I6A5cO5/wGsvtp5ECIe2Pn3huq26FSGiSEoNqdRTUld7HYDCcsxJLCUHGC
9Bjhb+OCN26ujhnPnE9q3gu5jlEluyLyK1XL8VbdxTGVAlSkWW4gqzuVw3tnTdf8nIDlG7M1BOIS
8TZrtl5A/BMrPVUH0gOp7CVLFmixsLE34mU+ZifYK6/BsJAiTpuVOmo4rL4lBmVXEz6XyjQjKcIX
b7M8NQM0u5+HjRylBY9K9pqxRfOo3wygQMH9HutzavmHxFbnCdImT2E3lEfunKvBEA9X09y0dYsY
5MYscB0Lf2y+3kKkW+UCakQbcA82MnKKxz3GXF1jUmyOFy3WUTJHFGH6XRlBqu4ES5hS6S7F2RtV
bNKzB5X/Fc1XsH5N9pnETM3ms2w809uxj68rew4jgeU08sTKOvWm3pXAIsGOLkIvCeUGjha4ONVO
fgGcV5pcS81Gjppsg5iJHZPL/7njmqNPhaTnchITywjks5t5OsUqozUq0XICktFm4kF9uWmd0Sdy
FFuJB0zUGTCqOtE2jsOrBi94TKyRLiTWwDA15SlureqPtiYSFuIvR0fdWMVcA9lbIqYyVhrsC0ck
x9atlflpHcrgHolhK1PELCK9sEPMlsqJaG5oGyBSGez2kzChUJrQagvhLIs4Kqff1KFyutwGvSGG
0JlKXLt3l9E6BDwcOtWs4HbVUoWraTOOtIErWyLnJaYBC6mIGseOwzhTPTo5WVzEaRQlhFn6Bqfn
wx6rZjkb2vBGlw4YjoujxgRRmlNGmhT61isILZGEAYr22aiMfVPn8jlbRCMbb6GXmR5IvMrEY8Vd
2wGCWOoXFNLElmmOmHRsl3ZIG4ULiGhSeMGDaIq14REMDRPwtBa4cifDWG9kvDkpKTkNN6akkqzM
UHzGxWX2+mLXx4w1jYGcF9Ki7R2LtEEAWN1ydhr9TMokFhElHPM0dYtdMZmwVDBkaotaTuTUbLxS
wNj0UI6HihKz6nQhBNxOQFEekYiEpkToIaEF07S6K7gQBKZZbKbYiGa77UNb8e5+kG8dQs0C1WmL
vZtYa2Z3lBZBM5tOw8J2F/eYDv9IByToJEwJ6WE2WGZ8S1qKObH13m67GXGaaTGA2jGTWrR4sKjC
ykqduWRIurWhWlHmHJJED1oanf0boOVAMyQl9CFlqSRKQeUPZTgwggr1oao8TlKNpq2wE+vYu/qh
U5Ay47mHOtaQoYhHuYqUFp3cfTcoOqbHyVl6ok8heNpAPQXJu4cgcurAskFziCO8gUakCdoZm43q
SqqYfmpG9DlMLDa3EoeFwotnIhwYIkpJbKrRrUxS7RLKEd/zuvc2U0bLxHMa96JfOyfRqAocuwv/
hrA+TDFNNbyIYNSYVbHv4CrVuZZ0ghINKBNDgs/iunotTMaHUklMlhgiqeMETuFwlzJb9d0bxOMv
YLw61cqRLJva2r7qnJNa5LqVN2PNpkouZh3MSw56WKIEn8ozQ0Jd6FWjRB+2p4xcDv+HCL323afk
PAveES+xWEFpIQ3/gTKP9LmuXyijBqvbh/utJCRgYrBMJY7NMpJElA1vukSHJktMzguxrSgXw2ck
7GHohJ2a2SjFvtHilgeYRSt6d/Jw6wTaAPPpd3ieM70lUF/J29iqCYqiEMnh/lxavEQxIIBmokAx
TJlYMuxykq0ZU1WGAFoOC2H9VAbX0LTK8xiBcI3wIJpIIm4DLaUOJW+K/OhKpnRhrSbe4umZsVOM
cGOmfGl200l5sn9W0MlUJmxohn+VSTEJi+A9pgxXqt65a6ioAfctc4S6ZC/sjrgFChlZEfXr5UDA
CwBgbQz1lHZmBmjOEFhRnftk5qWAt81D0+e/fGrsudt6jgE0t2iSLjRwIEMR2UNeiwwG5YyXltHD
YLviDhlmrQef5BTeF/dHkSkTT0cdrxrxfICtyiikJSIJpeCSYi5j8BXHWiDqpmfiEI2Puy3IaWsj
NadJc49BDPq/c+RJHBEigrCWOyhZH2KPzSTXZZa7enbjhmYKFJgxFKUpAqdB56zfAbSB1CdIE9l1
ZUJJUJSk/Goi/MG9ivw5sSkK0jkzrRiI16k+Mn4wDRllpkod7tZR2voq6Ba1kxS12tIh3Hpq5p2R
bDPpNKSqjqiL5KRLnHmlKatOonMmJzuAGwBxPnlmB+pECJ/FJ38UFjzhMzmrNW4MIeZh6O2BrzSx
qopGUFb6JklXKtupdkoIA23oz8OkhcqeBJmcax6DMCsqweizttcSipwMYrBRp3x+lOsWCYlp2hN3
1XDtk8wb5+RxSOOIxQw/MonDPw4U05iwiGNbYkNw1pcVF3/4MuYFkZvStRHlOfv19A6csYkB57be
NfBJTCKtzABSmWreABx3sg1flUdZ/dRiVVGqBrKnKZE7U4ks6S68z1HMkV557+QMHMAUD/VTlEx5
ROKP2ThOzcYooT2H2DkkpcxsD6CHTsZNmbi36SsNU2Gwc7pYm+8llHSLAhTQgUqos7ja5vZbgIox
DGHjOw6LDGlnKogGXFqbZIEBOuGJ04qMdTTrIdd/Ivn4onFnWEtSwgTxditaSUaYu9rBuyrGWvVG
3fb5MEKw41ZlslBl07MbjZulic0NrmxmN4BRCr+9aLW8YtvTxVwOBaGdQTkgBUPX/wkcKtTJ2Um4
O7k5gpl0LKAS3xdHwh6aLV4t60JukOH4NDiDtyTbPwf6mT1xMIwJm9EUpezdnYBFEtPyiCL1UPUy
4LV1sQlbtbK0MnxsUbRwtAxB2iZXzEtEdTU3HORczKBBIYuTDVFHnDulaWLC7rXnUzczflEzpPS5
WYYEcRcoBPGUI8CzLIrC+MXCPWTXr8gSoBnjtrg8lFYNQlCG0Zsl9DyVSenGa2Y5FlfGBDCZ3Tld
5O15sAYOoFltJQXFaRsOxYSGjDhcoUV1aMvYCnU2OxeOUvjr4BMtUU7UYlEBKJc1gNlSOfDNTUem
ZbBhP2ebhmWkR4D+QaxmXswxkwKZ/IfuJy1LGFwZhJMXQva01zbKlcxeVjQJDKlT5c2g0ENhEsqv
8amWsDP7KpmefIM+LEWorjTxcXVFZUw8fKmdtnYyxuAZDKgyVOBAYYCtqViRrpwUBOwE0FTFvmTd
0xHYJq7RKJsVw1vsyRCRaJfS0zy1GsX4ZeZIRwibGAIxZvgfdydfCsp4WlMpdERCUWtg/C50AWxm
/jo+gZxsmCkhsusQMTsfdmKX5vpv/jQ26ZApBCW7bYOSFbNRaoIDnb7NCL45tO5/OMg0o1Xx3UyG
LeQloeyivH8Wd55VNFcfbaq8llyoVOc2o79sYsohpvZ4Mpfk+Ng6TKK6q6qF55GyMoJU7s/EcO+J
HpVpPpxxuQNxFvHoY+Y0CG/xVUC6iItTu5TFFuwkvaWnjY0NTJQHYChUYfpf1cSXDIFWzx5AjXgN
eVNkYmJTYvc80DYXs6eInckuTnoTFc3ZmrguOflRk7KJVZFd0oFN67zREXGHHdfESxE3ncLFJTUK
oQWKw1g3TVpUZDuECJpfKJDsw9rhsLuHTYfqWS2qOGzM/e21Qv9ia9CsspLO1Nxx1Qe77kDUVfsS
lGFgeG9SKLYWZJp/ycy43GnX9ictd1SATDfqHvtlo6QBFJFL0UgyB6bTnuNmMkRFTGLA6O5LGnaw
5Kx+SlaaZ09zDYoj81ibAVGNYA2cEfKuTqXUrxqrTgQZK6N5ffbtOMBE29TJnhLFlRKnZHs7bTl5
2qarHuupqmAtBLVF0xGLnqiMcilNjKWR7kXjTisip3jjZbiHFW2z4wm2WA4+w5fF6IKztnKWRyxE
oOFScds526CGlDGK7BXkSJfO2GDWyVcVJ5wU6UqMt735DIK7VrgyAS38pfjFif0hxUxJY/UNdz4t
oWixB0zTWztdY6w+DfPKkrKFjkfMH3EEvkXO7Uumtt1EwhpCd8IAWAkzYqxjE6PewLiHDNjS4JQ0
IjSXWZaPXq2PEqrzTFT7msxi6wSqjEV1tCxMnLkAQLVdaUBsquaDbSnympC7+dJQfvvUjlO2iinO
mGqkVXQyoeaYQ7uwiT3qS4bNSNIo3dkD6oHrVA9kpfU2u6swvDWRvX0PTTg8O2CXmNisPmmRWuFi
ihmQSiDjMTqOpapShFEToHDnbjbezu4X70si2Nw3te42oRGH4s7MDoFOH9tECE8eerj/YwECS3Jm
m7ykoYo0vxibLEb3ryUZLmNsDwBy4MA41WE8Bs7cJmsWvArFLiFgt9ZXZUBJpRWq1HJlL5gOThp+
EJ27JJcvc2D8HpjlqYV009VGdHZoPkiI1E5YmEJA0yzM3z/V4FKuqqG35tzDiOrGYwbtyb6LRsYm
tOmKGmohdW4YHIHiFVcWPD+iZfWMI+yRmNnfkXifU3loYRUHgnkjp5ELJSptxJ5uO0c1msw7zkFL
ADqCqeloQyXgBpBdyQO2YgwummfICN09zZV8lXCmPpkqNbM0Ux9DU0mJOGRjKoThVjO+fkSsZcaz
hlEysoKzW20hyEfqKgRNEmEL0C6rY4o4JoQfmoiYr3aZF+ZOMwFtRLRFsCpNg2Z6GTc3KGFquLG7
CHYgRZSRDK5hpFEJw6o5XkOLrqZww4VteG1Ybg9b5TZJSdekbE6aGxk0i5cBtbHdqg2o+/lDuz2f
NFFc4Ffq9sbFijB2ycw7zhZ/bTmwAQlqKdhUbL5iTIFgUQpcjh89kEy08DWnmsR6aTt+F+akptH7
3zQQBZEOoAURsfhrOJ40pAeCl1F2Kk6Pq0VIAK2AeVlmY0AVUu7mzqqdC+ymDOYfzKQ0Ehc1jmGO
lFteBkWgNroBdU5BtWL+xOMAyrJAo/Y5NUKQS4ukMWPmuCCYKeEZrBzvZ4/zFtmEajNFSCOlMy/e
onVvsLO+M0BbqEemMbi4V5lIKppR62GKj4Vz7Fm7ZfoDJg7yaYvutU2roRcbi+Yvp3t92Bx7fB2p
pstYOLCTZxZ1Fj6pqo7wlddcSlz2wNmlIqOTnfSpcGKpf+0B1G9rOSyVTt5RUcRVSd4xbJUrKgLc
C8OoG2MMdmNCTjVJMskqroucUTbcsQCadSBE9wP1sVlqrbZyAHvVmGueNJaYgCoppk34UjxVikRT
aQ5fCsPuFWXL3AYNMjg2hrlyRtaYmrlHGDfb6IPdaE3DFtPom+QAZwYeOeVwBoIiSPcif3LUTUhU
VJSHz7cp90mkHJNqxxJUzdSiElPNm0KXNOncnjOaRkf9Ngg7h3RYo+Fu3N7XCpz9nl5LAG9m767S
PH19hyRuz0ORRGvy6LhPLeOJ2YF8pwTYnaTsen0tZX+xh6ncBMNbySZ6RnJNSNMLHzPnFU7CREat
mMzChXIRTOPAhTsPiM0WyvqpZdVSWf7kChgjcg3guSK/khFLuWyaibR65BZIR+ojxEq0YLXvtdKT
oJ7HQ6DYgLEh6ApzG1z10ilJlCKdxllTFSHjjCqHD2iK7gOrFISCx93vWzcTqfV5gn2xEhIoi4ba
qGJSpgeFImncszmZFPcvk11GYKo+uQyidhJ5g4elCw2OLLzMBoecbdto8ogI35hJxDKqxaCIHleL
5aFtzMQQwPatqPADTSGLSLI5PU0m2Xta7C4KB8GwDzRVg4UoaXkVUbgHWpxp+LkEIdcfAASUPHLp
VYWHgXlvwS4BLpMDUkVFH7oI3DkM1t7OjF5jDWKpajrGNCsHz5Sg6Bk0TWe3RYa4EmyzUQ9Py3Tm
iZZNMSPdlCZN1N41VOPsDpbEIt6sZfVXkdr6VQAL0yzNaxpSSm0BU1SdwjoxJB3h2z9spB8oc6CT
Yg+HIhVGNnJ2xzcRJ1dy0sUC02eP2eGgytg7DFXmoRFphI4W9kz22JOXq6gvB0ESj+8Z+jLNIFjz
xbFRrD2jG2i4vSWJTk5is56MrpKCWGunxGXMAOjkoJRU9p87R4lp4CgznAJM0zQFa0YCjYjhd+jG
EPIIMfc5KZdPr0At1DElExFl4unhk0OblTuzdBbSSk9IlWt6zkjx+GuNcjxXm9e2NFokuwI88iAj
eN54EcysPvXI/AfjsWSARkZTKQ+fRCDDv4u8H0Y3ZoVezjrptewk+vQfj6XNSfM5xmHX1dYS3h3T
yLe1sXeBm1Olab3r6Yo0kJAp0i1eIhAxfIN8ty1FgEfZvFNJpheFICoMw96BW4iB7QsGs418jXzl
l2iKaxslWd6erkGgjRzeSV8LTmliCoMz/swdGzwJlRith69jqaAJn6UwxhpzbjuDDHMYOZRi1KJk
FOZaekn6RtmJNB7CkylZ7DmY5WidVgdhRa2pY+FIlFHzXYmldeokzzIMCZ2XNnFpjTFdyj/SIb8w
mdO0wqokneDM5+5bYwYdpMwYlFXCCLayyI9VV1Th+RSeQpBhjESi5bDGET4dCSomwEFuMihvx2ID
wqRLFa1FPEUCAA4ZdfQ2LAFWWyK5ZSJyiOaCx55tM2JbCnbyGBziUxXh9LVjX/Sjx+HyYEhPMS1P
RHayu2Fi5UIDIpKZ9jyDWeeE0maF66Quo5PpqTNBz7ETELtShWIjnZq29s3GSpXDlCIyzMVns1L2
Txyea9ImMhl/aGCmGdKVgDYm5gE6+gKQUXqufommccppgNn0v0kBcZ4BtLy1Z5OgnKfJ1XjFdbKj
qCKOCXBFdYZEzpOKJUbd2UyonQIpkiXKh6Gyzsvf0Mb+FomisNbKd91cbplB9OY+3wirNC6v1yZo
8NBj61fY5nYh/tImZUgNbfpLOCYWJ0G0BW64uDKh38xPQDRWxVfNLJVYq7m9IPEAnzEEKkC6nLEw
JvMpoky1YHViTXmGg3XW37BaGanMDVWIzvSlAsOE4ExhvZRISLdztLbAlndnO8T0mDmpYrkddHaU
0CCI0Ew3ldjmjQpKFk53jNKRJ88++RCSkLqLQ5wPbtZFXGrFYNR0j6L0/nFATNMJpALopvqMOY2e
uC4JAV4ZOax1vQXRoiLEQD+vcfF/jS9HEfcVqqDJ6amRoxF15nk2UwCLaopI3TvKJm/GsfVwwLwN
s2FJ41MsUhoT0LsnlXvdcNkpUaJJqiqMLYYEFMF3iDLCZoaR9E71clPImDP57BFVjt2WdS0G1vGA
ihF2hTwJPRNjKPtbyXQLosYrglSSn0sx3Q9QfKPDTAS2WiN1Air53aOd3GcwZcO+OeNy2qhRiZMG
QsrfzBp898cuFPeZkdELNafzaMGQTCrioBbFOtlieLv1mMJNOSrhyO4Gu108ryxlu6mIQxFm0oM8
9tycqtvcOSjRnCrC6U6agkIjxeesM0WLYa1KPatRNTCH5jBg+EYFNdfDmFZOiw9K8GhPU1C3ZuWD
5m3P8GvHIf4KNB0nEZ+7h1+IRJKVLR4AsQRc2b0IilkRxTrSqdJeWAcLSVnLMNLN0TMpo45XRZLm
aQM0xyVVocRYR0VUWkPjiRTJ1kxx3JZKh1rf7YoO57KEP5vvSpQWMl70CBK+M7YTEbSqxs416P5B
UlHLZQpWYH5Y9fqMzmT1UyZIWWCifvMlUOvF2ki6J7/bk56pkCP2BuGkl7BJ7lfUM2wpJqx2/0nQ
TNxm3rb1yt0yyktTGS1u8f7WYy40R7M8pGQ4O3QbtuKxG5e6qyqQwhgBbi4SYuspueQDbmTTOgUT
Z2JZMDKSxMfpQVXwZVSY4CzsYKAa6YgDkeeePqzKOQmIMCBiMMMMkpfxuapMSeVLNIMW6pvOWpR5
S0pajv8VZp0jVW0peY6SJcfA0CSpTiik/GA4mpiCZD8FmTo6TTKaFPg+CGy+eekqozsHsjVmNJmH
6mYmfUVaODmiEZoh8dWrxkRrWU5kWmYVzazV+ZEiKjOtlZnKLySrsG01OLZAbBbNOe7UwlicYenT
+GAxIT1pymerqmTLzKJytKsIutVrwN3ZsSb3EQIP0HpsVRyCU6UtPWmctccJsdjsDwoXk/te34iv
qqTDkrC8xhGYh9V6yagZAWOksaiGezCXiNflmYyYisfcPtlX7WgCslA3Lw+nCgpgQNEt35GZ6Rrd
paoMJKesx45rf9Dszt8gs4wn3f013GF1qg9dY0bPFFmP0pfbbqBgQ/zmdEBlSe6jcOpQBnHL0Uic
38NTXagYUxdJvzx48o4ymIiTEj4Su7D2MPhVUXhFSwVTW07bvkF7/pd7mERQjgbQYal4rrydWqqX
pFZDm0mxMxy8+9YKBuLMEw1rBprm98GRnLR0LsGaA/vegmiENF3Vh14U7AjjfkQrWm6G0kNFJH3x
gl1tz8cIr+Lwx8jNr/vI9wQTo5F6hgm7lD+jdSNd0ccuPRe0lp9UJelIC3ql4ZRh7WkVKKIx6ZSg
itqmpzfBfoeyJ5UFfpUBHkrkobcTSIqbsjqRfIxhhv4oVsyixzH0imO7UF1tDJPYvW99lB9GXPb+
M1P0EGlEEmRYH7kLCDRFvBuIrCnXrSrnWoI44Zlq2u3zyDTYIbVrJTV2twQew6aIeQKtMwon59ZW
q1qmPA2IiNhIRlXIXJpFlAYyxkyEC7wtN4D05uQyaOrC1nyhahppVK4eozVxmRnXCFsot7RywPJP
FprwDMnmoaKV70HuUi6eJgR3GnPujnExJZwOM7tAKDspbk4sqIWdiphKZQ7flC6ITUBWTvYpHskU
DpeBEpUPEx446cuebat4rQtXiGxlb7yEx8QIyHcHvsjEYyaooXUjjWXsb6XrcVmS12gI6XfqtE1m
gwtzMh9VtbKcPPDLhBUaFKYYK3FmeesMGV7a+0puIzh2olpDJEvtc1o6CHNG8JFNrJ3olbXGNxxh
TuLayJw+94hnDiE5D2WOeUuIeGz/xsnfcP5Tytdyb+HLm4HRxl1kzeyBNCFzabr9cANrszqpmZ1L
qaPUWQSCtnx0x3sQSVFa2mW3l0i3BlCmoDqGI0jzDtXkA7mx8GYyfUpF6PDVX5wH2PG/DOmMq8Hs
28pUJozoPNRdLsr8OXT/PkWt/DaxOAnDFyEkcNGDg0oEVkIIzbj5+bqvzTCJXaWZK2tF8Zpw0ofS
sLhUygDDGMmi8aml1g5DZsK/yyoRqWTcMWoSGBpMZIknkemGcczd1BpJblEXBFcqdcaNyil3AhGS
ZbJnYlZmdt4OGa/I9bT5iHl+oIr4v8IDe9nGvJGR07zBA/jNPCJFupuGLljbgLQyChBsypZ5SsUD
CRddyoHxdETd8yHJbDOCQBSjtT4kR42wSUlpUpoGNL1VNqQDLMQBmOU3BDuV27MbEMwlZ+bZfefL
ZDlRBfM0hgJoqFx3mCPPaCeaqI2sie9y6wySSarblz75yXAdQZBac+OTM+ixxGIAJVNopTkYhsnQ
Lpl97CJ5yZKqIIJ0vc9xfQvv9rGb979yms1o1CSyLWigDPvRpIVGYOCk5YmI0dAlY3fj5QlBV+Yu
EUVtGsxL4jnMfMZsSdiTu0Xy7Xrr2oJmYH5hHG7oEUpNdZ4zXrw4BLSYegXaKz6GTbcpWy24ecv0
dGlFcS2bVX3XpXmPSTO57imJY0bg+LZRQLnjKkDrkXuDICR15MktCE6SJaJwIrSN5qFaqQXM3KwC
IlypuRhzEFq0xdO17M1gybIrkJvevJ4QRgaZIbUebsmi/epQU8BV6LzhHeUV3lOowoOCyy07BeDu
V13hQKAWuFiyRok4Nm7Zlt6xeWZWKfSIljvGBYTWwKpP9InB4Q9ejw+lRYkxQ1i1FH8xF0AlPcWv
m9mAkzoXDXawFYPWruLuTwZ8hF9/0RArGHBvzRUW8aLJ9KD1GSsXwoooMi0L51CDy/NC0tGNOC1I
y/Oy3dU9OqKCXt1RQjSSnmrBSB5quk+nXDn9W5ggbniVaEaogWXmlq9PAXp0Yz41g2Mzh7BVJpVW
Ff//48/9p5+9/7rn6Hf+/M6f3/nzO39+588T/8GbfugPEnA13nC1vesZ/s7D9XOZ1S3TxWySbQZa
G44WK155Br4zHYF6s3krgq82bAPMzNBtY1YdjMMGHhjMG4NBY9TUxRbS4yQRPZ1EhN7x7u9+8OrD
z37uN0VlKp0mnUREaCrNmfp+NMEtLMwDRIcNg3EYfLXh+oBt8L1rvh4Yw+GdKXqc+ns/+Ma/98sv
TNGbW33tZh5Fb096Ol1aDpNi1Mbtvi/RZhuXgGnucjpwio6mNLSO0LdIIfZbQr2rBW8TtxgKNSeL
VaDSgqxpiabtb7i0xGEol9+3FMM9l6GbVweHQtaNaAlWNL1k83vFnIIyXcOIN/UtyqA9syRbJ45q
3mP/YkEqI/OTlehl/ejD4yfmzZdx+2C89tp49fb06um1h/N0K3JSNFkKrdTfs9P0RA/XN/PifyJP
92/rAHD2E/1mfvHyi59++nUPXnl5iTJa79Hf3h/dHSAecxj/bZzSR54T/Sa/TCseZ7+vl14QA/H2
wvUyAwy+2u5dX927f61PX8n9q2287j4BV4fXP3395tdv77331JvBkJNaQqZ74BLN6T4nIlr6hF7t
F3q/wQJstnbm+zg2txQ4bO7dykzjwBvjcMDVBgYOGxh0GHx46ikIybyxjd7xJFPG7/l9v+eTn3pN
xzjN00n09qRT6Dj1KHo8ztPU6Xqx8IPlksyMQQPMA9ggg/jA29UYB74+4MB0tVlsnH72RXrve5+7
PeprR3l4IzcnfeXhfHhzOs4VClgSUhssY+b4IlF60A7DXVG6Kkbz+Gp4EVIactd7xLY5vQSKW0xa
npPtxgCzvb7ukfJhkF2JBxWolnNOlUyV6usZLZYV2Fd3WhBLqk+pdNP9MlmuyNzMSwOAo6WL8HFR
bEZdsLjAJSG5MDKQWUiXoAd6Iy8cb75K9x7wazJYNyE6YZxYpkHxxt8iLNFqjy9hd5fXjon99qqZ
ru+JJ6sl+ObXpG/um/7BP/Xf/4W/9Zcft67USXj1tdfA21kVxhMXSL10eGWK0jHA9TD0jhpKdx/G
7vX9J484sXpHN3DXJ67R3Rd/RbvDZ33X3/NDf/aXf+qv9x+2rpAweNsO4/r6cO+ePn1vPn298WAF
H7Zx2LbtMA5jjG3wgVR1nuTkca4kQ2WyqE4mUpbQord03lKf5UmfBnqpA4oMYtbjJAZdbWzPH4MO
SjdHYui9A5jp+orma/I93/39n/n0p29vXmQ6XR9Y+em3vYWe//JT95+6Pt3ScepTBxJ+6v7rnnvh
hedfe+21k9KcOpVOoqfpLocuJhQ5nUgGTaHT1DEwJ92e5Oqgf+ADb/jIp1+5d5DrwzhszEz3QBvr
YeOrIQ+Pnmbw2q1MoSkZp1emBWk6QGmdQ0xtnmJTY0dPmzjVOWocY+Uwo0AlCCNVYU5hSrPc1hR3
yD+Uys16eFd0padD96cTNd0ncmcMzoBT0kqp7h17lWHUnkObgryZu6ZTAcfQMT0l3WSCIDUnMDX3
sqCaJNry6piVM6O1LTnhrAqwG/RphscLsPHGKsxs20qLObMpuB0DoLrf5SxPo36TTV/pNX9btR6r
FjC/7JMUxKU0PKpfX2qdlvHj3V/qF37ir+wiYpditCueigtvhUsn6jG1fqm5f/BP/g9+4Sf+8iNb
Y1ow7EzjOP9GF6+OYj1UIqL/1X/0s//7//Ef+V2//0/8yof+7t1LRbMfWt6Qvvv3/rFf/4c/c/b5
PYBpIeC296nS+ks/89fB3JgKtF8zkubEIMZ4/QffB8b97Zn71296+vCuq6v7V4MH82GABzbmbaPD
tm0bE4OZB4MHG8yCwcxwxxxX+1o0IIpeyxwpZiQK8QQsiNJR6DhJyYvvrJ/gJHJ7u/2JP/XuT3zm
6ub2Zlxt4/DMBz7whue/QjcPX8Ggw7h63TPv/KN/5DteeP7leXzpsA0eYDAGOLTdPlZP+RtYTG4k
JISTQgSfff5mgqeyCp1Oahzuw4EH82Fj+36mpBAhd1iG0RDY/brq/cOkvP+EOdYE1Osz6NtcKjwJ
PeyeEXm/+SnpJEuVnKARxOiFqtxm4bnFYDItpBd99t9iu1icghh7ZTtXLQTJASOjszPV1/cj9PY+
PyjpJMxkOZNsqeAI+xL29+H4vslF1whvDSvbkHzGcfKwQy1pf35fe+fQGxIR00AKkMOU+yG+NOVr
dHqJT7fj9nacTnqrx6PMU3BKKdPln6B2n/0dd/wv/n+crRn45haM887u7KWotb2VDGA9oLNqUv+O
drR5PnHh++7eE+v3xdlh7b8Tnuzcnn95/9/nfuvXuq8dtfu1e6nsu//LV+iRZzNpjkQ//+P/1+//
g3/iz/+v/29f+uSHn//8J/pduLxln5G2teSFL37aqwgeu/Cva1JbQdMHgUrjn2cdzIM3Htu4vt5w
tdHVNl73wfcR0f3t6WfuvfX+vXdcH+5fHXC98TawMcC0bdsH3nv/xQfzsPFh423jg1VSm84zWxqL
58q4sW/6A/sP7dF1vTagQuKhbphCR6XjNE4jnZROgqPoyw9efeFrb/6xH3vmk59+3dyurp5+6/s/
wF9/kaYcDtu9t77lW//5f+4NH/rF2xe/9pkxdDCuNz5sPAa24QOAsZWRreaxDFaik6gSptIknKae
TnQ79STV1DJosJ0BTIEftnsktWR15mIlcHh42SdF/W2PBCpx0T5mxALpLJ+0qPMFMlgOnD5qIVSM
hTqg/xaeiIaeZxxXasvrL/nLVEpIRDxHSu78aIOpEkmKiVShGofMhoxlJuMvOT+oPOEtyznETlTF
BqRlpRVLNuraxCv9eMdgW7dCHO2iD2Muc5xnBoEe0hdP8ys6X8a84Zsj357kVk5HmTNCTeP2vaMA
3Pmfd9SKXDgubaAe+edf+F/8n3/lF/7WnS35WZXEpb70kdDBxdZa7/iaeqn+6V3LEXZl8rxKK61D
HZyvY08Ahpwtgr2d1bWtx6NWxydYY+u7fPlzn/jyJz/8K//g74LuOnhUj3THmV/7lPN1B9VkYVm9
wpmE2xelbEyMxcUbDlfb1WHQ9UGvtvGG7/4OjPHM4XVPX7/p6at33rv3zNXGV9s4bGDwNvj6erz8
2hzMAI2Bq4154LBh23gMm51i20Y8azTYGmoGiAf3B9t3xxn/ZqTGKF6iNM0jjzCVRPXFB6++8LW3
/PEf3b7y8v03v43f9z304CEd6fotb3nmR3+U/+v/il748m9ufLsxDxAP2jY+bHw1+OrAY/DhMIYX
UozBzjIawWsDLExTlCbR7WlOoamYSjO0QE7eY8oE6imm4g+AI/t1W/RKbdX6e87vzmBiZis69ivM
tSSjxNOIlYIxQvLDWfxBtWGpAoKgrvt2hsseKq20Y4fg5wHV2sTHZz6WHeRorFQ7e7zsHxy78TUf
uZOKhQZgcLxJfiPbDjoZtoVBNo+COm9BnOUawfLyP6qD8ZNgPHIe7HqhwGZu9AtTvkrzFT49HLen
cTvnUW5PcjoRZX7v/sHrWzNqa/XSwd1dPHF3pw/c3f7/yi/8rfafil07jv2bPLKvx92flWWkd8N3
9KeP+18vxPfvP3M6Hs/b2/3/sE5k6QxyuYyHYDcSuuNKaJ0iPNFpf8Iu/8uf/6Q+wZq93DzrOb9j
76KXVkzs1ycQEf35f+P/8is//+MRAMGVQ8I8tnF1tV1fHfj6oFfbRtlXMQ3mbcNh48Ogw+DTSUWJ
GSehbdBVuHtO0duTitBJVKaeRMAQwfEkMlSBOUWURFkJMiPYQ8oWLz26p1oCFvEEEY1BQnwUJcK2
ydW4/fQLX/9HH33uj/1Zun2N3nlF2z9Fb/8avfON9Df+On3xq18SOjLzxsSDr5ROU6bScegUur6i
o+hrY96eeDvpSfQ0VAgGr0dmMKboBE5TGZiCW5GbE19t+tRp3Luie1cMUgZvG19fye083QynnjcA
egGoMxUlWh2k6LsmjZGkke42zVpfgSUL03r28CwLFV24jsR7rvzc2GnQbgwgWq53XLYVgcU3koxS
5WRGTGyypijlp9RMCEDLNHX91mktuTS16vSmmiLHr+kCjcapkxVy7mfe3M/KlohomHSHi47AUGJi
dscMhMlZEZUiK47PCRwg7KDjDOusUcOjZ3lnQzZ9sv4+IVpdG9kLszt9ROtI3yx35nEzXtyxdyEQ
4bVXH1zA23dj0UftlPSOPZJewNHDF3l/SvXSpgSP/F7/RLg5FwDA9EVIQ9vHffZ+bPt//z/8T0oj
huhMIwAj8xUUulleYZq1m0PFYGzD3X+J6KA0zZNaVYjmxLapEk5TiOj2xKo0Va9knKaK6vHE5lAg
qvNk3oTsGTr9ImX4gCVSqoroJAI2piF0zXhGrp75xi3Rgf7oFd0jehfRC2+kv/sJemnSEfzaiQ8q
G8tgYqbrwUp0GGrt+Un0aqPjpJuT3h7lOPWkNgDA8aQScn9iEqGpOufciE8qt4JbnQ8VT03dNuhU
M0vbNowjLBskjBvS6y4s7bbQNWg6u1qkU8zPMrAt6alRXjWOp2plzlXD4CaZMRCEw6HnZFbnu1io
aGXOMnqb3Pgr623XypmmsqpnpbJn4LahoOvO3NrQFgdeWZT9IUIol6ekb5lbbUoTbK3xBTEj4O7w
VNSd3iFlfxNYoiVE8GBv9sHMzYUjOaP29fSs0OBSPWOChgOnRd09UXUNwc3F930S5MBtNHa/DjrD
cb8JKtBSTfRuoObRI+iVhap3/9JavaF6B06jTwrf465p6u774jEnB09OidLHXi8NsPjCP1fOKHYU
GupEguVk9f8UD1ZU53GECXe+p8EpIGADQ4fhzmwEZSsd24Yt3O3NVCR9IU7TLVzmhAhtQ0VJVI3c
cpp6fSBbA0ToONQKgjX4UyJBWD3UI5tEIrp+6pm3vOVd73znW599lraNwHT9NL39W+mNoHtxdp4i
evat9IY30cMHb2V67nT7yrx95TRfAT28OtAAts3dvU6iVwMnovuC25McT/rwKCel40mOJz0KnabM
SWKBcgoVPU4VoqMqj3G80ePUw1QSetcbD5/9yq0CGMyjXZEIM4a0QpOZO7s9ZOHzcLGzokvT3GiN
W9yZFszesVPPxEvnVV18Qkg6jbFw/r4p7+YwzbyhuVaQhQ0iLdbQ9LfoRt3ZlXNQjLTgQ6QfSHfy
K2dRVHl08EqXpi/DNHLcMMrRX8P/2nNgZlk6qpn6uEsSi4U4uXiDP/h9P/gbf/8nW20ULLtm3Mkt
RLGK/ps0gE9c3/VircRjJrd4UtY8nnzCfE4MfeyseF1GoAsXdCUjn/Ny7ij0j9kCXKbMXzgHd3f0
T3Rl8Lhf1juus95N7zlf4XaHup5Gt3vUMg/Q9akP8flmEXECJeCkmAoRnIhPAmYFEQ9wOGqZtwlH
cPyc+kO/+01/55e/epo6Re4xn056OokQpug2xhQ9KNm083h0Nb+IiguCTevsVUaB4+nhV77y5Re/
8erV9evvXT3z1NNXb3wnPfUc3bSvf0t07xl6x7fT295GOB02fu7Vbzz3/JfphS994eWXvjpItkEb
MJjubUOFT6qidH3g26NcbSygV2/kNMkVT6LHo55ERSxZmSYIhG/cyABup4wjBug3n7+1fD8B3EvQ
S21vb9vlYMUOmkAjFHJ5PhBr2Wa4PjzsvZko49E5jeaDM1469PCp1+6Mno7HlFRFOoM7glDh/YZy
GtvF5iQQIf/cXHW4W5sGqGCmMRwnR9Ibu+0hwkiuJsCMRYXA6P4Q/vWxUD4XdIArNsUiPzwzZyMl
YLqlUVjzqBEsP/YrH9rCEg58/sjqnc+t4qxde/KZHr55oVLeHXq5aX0MY/1JPk+fjCaPJ3nDd7zn
27/42U/QXfxNnH2L9FKsuXewOS9U48cBT90/8Zy4v6c26jdb2r8ZZAdP9B5oNV3pkazQs1k3koS2
snbh3jD/w//lX/h//id/gUDbxmzUZBEVpRPhRpVOum0WG00slFveMcARBAjQHPSzv/L1qwMfNlId
SnQaMjeeNtIUUSEROqrOqdebnkRV6SQ0p0ggZFP0NCNVivR4enBzfPDqa19RbNuLz3zj9ltwdfVt
301f2ujtRK8QfYroF36RPvKP6Wtf+trtg68fMJmOBz4NnlcbPXXFG2EoHQisug0Mog04EG0DV1Mn
0WHj40mOQrdTH97qcchJ6eYWc6qY5c1gVT2JzqlDiZk4suZm7rQHllgTKjilXDwbFtngjjAqkTDh
8Fh7rQJqBVeI0nfNIAFPwkHBOzkX5VWWnPRqTS4czlHReuZMReX8fYDIss/KXUgLU2omn8ivE1bG
LsiykHtfi9jFX15OxsgcMV/KOPZD/QyI1kAiBt1N5qUZ1OPuKii1RmT7MQ01T2Z76QY+EViFCYOs
fSHWnrJ+x3Old9XSJ9Ef7QxpnriIZFWCPjFVX387MPPSOeIJYPo7l4RW4h8LsuvCdHzEoSqdU0MJ
j1zG/huNHJ5QwKr0KGLS3TfDTkl/YVHWVXbQzJIWfr3SLn0xmR9KDP3L/6d/a3v2Phib1f4j6S3p
kXQjIiEIjakj0poGK+dQ0SNc3Dd5jARwQVCejjFPoTnpOPV00o0wB03BcaqQbkJCw8KqTqJD6HBg
McTfU9VI9Ag9TuLjw9t3vePqxa/Sj5/o+95FH/sabSBm+urXTi+/8rzevnILGQwmujrg5oSHJ7m6
4o31njE+p24DV4MG4/qAq41OQgeW04AQ3U59+opePcrDG9mYTic9Ck2rb+J2f2afAA/cMXfEbEv3
LuI7BURH2DNvq2JMs6KhXq+6EnupiYnS1bA9G4u7WQZ1ppf3Im9FJcxn0l3HzXlt+bn9XXx7UUzd
gKTKWi2o1Yp00YL5l0ciaZ82RRDzFom7DGWt+UFyhQc8FzgiWak57BtQ0yYbFMFk6o7sZozKrpol
Ag2aJqUg8ZBz3+o6vBQXSPfPj16CwaFPUFZ+uxO9+Lgf/OE/94s/+V+WOdij9hC/DbUtFizlMXO/
u37yJN9ELyHf51pQvWP11DtQeOxH5bjUpj+qncc3D9no3SxVfWLN2iV17SO2LNhj/uvEmxpEEBKU
aG6AQUoy5xTFragITVIhORwAwQCZGIqITkTDmvoynfYW1iiHV1vkkU9lHmOQHtRmswbZmwbKsl5N
nTSnKOGkejqJAvOkJ/Pnw+DDG/7IH3rmdKS/8dfo2TfR/R+hn/85euVF+t3fQ+/7tu0Xnx8yZYBo
yhg4HmkM4qPeAw3gtaNsTE9d8UH0dmIwbUyHzTig4zRFFNuUCbo+8cOD3J7ktZMepx6nnqbeTp2S
vtqYIjPZLwJvSyMaLaGGC3fj4EBjIryJPbw3OS2+Vc3AEF6udbrmgaMWWbRLZGskqO0LiRRU3can
EbE2fCvi1jRcxgMxrCQLW6BMW5gWB+xx75pZJJVXEYUSLQ+Qg8CuFBmDbZmJYYDWkDTOAEfsVvkH
hg6Ew6CUAp2nzE1bSgCY6IScfsWaZFHxMkgH6QixVuyRUEwj3ElfW59WrLrEXqFwRom5m+C9DIGp
z77tr7/4U//lImXfM230MXPV+MD3vO+Dn/2tj1yoRJpJiE+C9SNjQ+8QCewgae18qQju7OVJ78aQ
ch3VxxRi3LHfOEfAgSct6HrX6kLBd3u0vEsbnfLuD8DjoP4L11ZrYpHxhAsqTxH5TsS0jcFq+kwe
kwZkqKGrEycrIQMbg5kOA6LASb3KI/jTFr/LnrlltWYMii6fTpOG6Db0NC0PS0/iCXwiqtiOU7/l
zVe/+cWHSrjd5CQkk3h79kd/7L1f/Sr97M8+j01fffC2b3yVPvNbdPPaVz7/6e3H/vSzL7/8HR/5
1V+d8hoRREiIT0TbxnNiEDHoauDmoW6DtkH3D3wYNJk3Bkj/e3/obX/zH3xl25iB200Pmx6n3p96
e9KHU46ChyeZU29PchISJRbWhKoHOTySyLXqyuqK21hsDfTMUu/K2aND4jp4beFRQQheH9hTOJRp
74kGJSj3NaMxYvszvvrexIOTizQTUZnl5oYRBrP4tLPCRZOH1lx4mp1NVuqBclGXchUvhzIPs04x
gm0daqbdSPpElXyCfQQTp4s6igxqQDwni1RJcVASmmOMbdvmYGJi5g04cpnkNMzr8Q3dP/uv/m/+
3//x/zaviRNJ27jbCwF2k7iL8AIuDxWxb/Y++AN/+CO//HNt3P+I+UDbIZIS4T3f/oF/4V//i/+P
/+P/9LOf+Oi+EiF7jUej9ruf8TIwuHM5xL701e3gqTNnP1+X0nNG5l2yqciuqVapL6iPgvj1wvYB
d7fqmd72qLsFT7o5eOzaekF/xo0OJz54jYAcZgzQIYWT3/Ev/ncJOFy9+d7hO57Zfu+4ejNYx2EM
Ij6AlA6Dx4A7jgWh/2rAar31l6JqMpcxQJpDLTA7a2yq6jQ39gxHdieDGcQeUTqKnqaq0sT1D/7g
d3ztG/ThD39S6VVh3rZ3/bl/9vV/9a++cHP8qpzkMJ7703/6HR/60Ktf/OLH3AjSQg8OGAwSGgxm
GqDrA0joMHC14bDheuMrpsEY0KuND8PmgXQSuTnqSfSkNIVePert1Juj3E69OcnxpOYIXy1soNUY
SIicg0rYB4bVLGMhz5TNDmlPP4scKurwfQTXO2NSRdEMZNQTp7AzAgnzmeoTU50U0DZUbZzuzbWc
pI/0d3B1ohq1jyuHyHSnoYyeS4y+OYbXs3r+3T1ex6ONK4IvYyHNMHshGZ8fJwNKosLJ9iHdRFXl
ZfnQze1H5sPP8itfO7z8yvbiw4cvnb7+4PTaQzkd/fgXu79vggujj0SunxC6RTVr3+wwUHXtB3e0
fxDRe779A5/95EdpZ9SjdInLsRzAn/2X//Uf/0v//qMmvQsk02an0Q5cxnjusKjcI977zQkuwSYL
/7ctkFjYSrhjKaTVtV13b4Wq+5qMTLmLi7r/OuWpZ8khF0s8LoA5d6Ji2sHYHejFzFf3tmeeuffs
65+SZ586PXO9bSBii5fRSaoHJpAwjkQHgRKdprIa9VkP4VZwUsNt/D4azCw6AJpqYvINTGpbbY8e
xQivEfIQBCVS5Sl0Eo9YmKrmafOGN731859+8PzzX3z66sac/uc4HZgGjtc4yaan01d/4m+fPvg9
73nxldffPHygEtlVjEmkoClEU3ngqCClg+JKMQSHE10Nujrg3uA56VZpAAfGGLg/fL25Fb13Tbcn
vZn6yo2MG7nZ6PboMQkkJZF0JASdpWqZRGFGwLB4p7rKeZUG7fwblziq2strgey5WePuW+WJc8lw
d1cbJZoRrGlx0kqR+ARk6yaa8UUGuYAtIVldkBV5DJGf4+lZQQeKah1eaTUVsOLOgSCdEyIkcrBj
3OpnqMUhouljCaQnoSBT+nw4aTY7nMO2BtNBLWsFeHqw2hg8PAXF4kckco8uER2wwyJWCAAXQNOz
Eo9HjjUfS7+7q+2rEqN76SfO5nf62U9+ZPfm3V7sEczQv/mf/fvYfwPVO7t4rItI7Gl2ZNDKRspM
UdpxFvaWP49yhKYzngr23xVKZ36+Z2+jWCvvJWUVGu5Ur3766dc9ePDy2VFi4ZXe5Ri8jEZi0Hq3
D+bCuuKGhboSyu/MDSDG9sN//Md+5mf+KzCNAdrG5M7R8/8wg8LBdFJAiMW/+2HzcsFETFClAToM
YsYNKYPGdJOVg/X+wEh3r6g2G+lBHGsVVRE6Ec2bF28e3jzzlAoNUToJ8aYsdP/qJANHgVyr0Muf
+K2P37//lJxenZKLa9wuqmZPdgwM4HQSVt4GXRPdQB8c5TBwAO4d6GoQSAfjeuDA2MzueNN7QhvT
YBonBeE4iaASuY7ONC+LgjbPnAGMJBLS+57CJ52QXlJVZxxW3IyD29IA3yC20C7ALOwxCxzRZhzX
A7GIknUOVgzkhtaJMOZ/6UaSaqHe0OZ2EE7uqKTdXEUCPWeQBfPCQRh3aZP0wY8j4/gW7voZuwFJ
kzfv7Xnk7rtCfivWyRB/oYwzEiiBWGmoErBhmwNithwMHsZr1Z2a7BJjHXfSnPVOAP4JsI/HDuj0
seR3vcA0x6VGEXQ3GRN3suMfzRzCHZOHlQSz33tFgOnjoYnHDLD10Ri95kBSaam1d/GgupVxZYyf
Lx7rcuS/++DBK3fMw4n2DfzZnkT7OGc33blQ5vv1Kr/YtiCCYbj6GNh+7if/Bo/hqafMhCGSMeB+
fIOGFS6d4g8UaIBOkwg6jCmnxn7hhycaUIYFtulh0ACdbHaoxIzBBKXBDtwD4A3B9DMKJoke+Roi
EHcWI+Dm1W/Qs/f1Zh6mWDWA0Onh6Rv3nt5k0vFkPGnMKSSUKdS2rB1FTwArnYROAI7EStdKhw0P
b2ljuR643iDAFjjE1QEHW4uGjuME+LVbeXhS7C5337SxR5XSCGU/JSm+uIy+89D2K1oeAAD1lsPv
TI5W0qpnAy1D/V9sxSLojx4kph6na8hM7jgZq6YUHmUbjkOU0YW1M0iOvQ0Hukd9lMRYLqhyeCl3
djQrYzhSfQGQnijHqkQhJM7RAhOZJYFE1FrSUrPxh92pvi1KCdpGIMggDMZgt1UeIfxC7aiTYvpI
pBUXcZZLfeITjNXweJb6oxid617jTjo9vmnW4GMt1M+P/PJChk5GogtEeIDe9W3f9flPfuwCPNKK
8Dvf+x1f+MxvXgAudnNSzezq80PTnXfO4xifjb+Sx+aPKujcu0LPZav7Lq/v7M5Y8nppQ/gIyxzt
qZ9snGWzuSLa2BWK2zaUmHjwNhiHTZl1+CMam4ahw0SKpAxSZ0xMX4IwhlsL3gqBaIBGIDYAnQSq
atjO1YahBCEe2BQDdPC6Q4ygLbMvANvBt/BTVAmqp6+/IPeu5zXxUaBKt1OE6GqyEm7FbRWmYirm
pCmVbI2AHSZoKh0nMZSZjpOYdGM6KMaka9UroXsbBtmmBFcDhwM9xSKgk8pknG7lNjNApCEGeetO
r8Ialo9+Grnl9lqquKd5xhNw8uupaw4rkqhKrket4pt0w2AfilKORBUL38F9fZeiH019hPKq0/bd
2/2MmRAziZFeAKj7cKDfd2jG+J1vAqvUrNA6JyhWi4eZeOvDDX6xtzGp8EDnFgNpKw+/k2ijaYHK
UKLBxFMJPMy3jpmZrjaMjW85zTdTc4vLDi0Li6aJzpuzAPoM+s7q+oQqpCfkJuIOlsYjtD/6TRLD
d7RFeSSrBEv92b99M0NHnYd3fdt3/Sv/9n/2n/67f/7zn/7Yulr1vle/8JnfXAcP+zOAZXDK/SPu
NkvQS1uAFfDWFf7hR+518GjB2t6RH5e5Uehw1+4KaEncUwWtfR8A2OjRnGt1GwxlZaZxGOMw6LBp
pqqn/sV9uPwzTqLI+T9DGRxsQgadCFAaYo8bSAjApnjPc9sXXzoxaBu8Ed0qHRS3ntStzMygA8ek
XJUZf+Z3v/4nfuWl4QNPfeXB8/cOrIp7gBLdnPgkpAcVpWuh00FvDVHR7Wbq6eSUUEOexctBSTWF
aBINMzomGqCbW1xteOWkB+Bq4D7hSESEE/F3vu361750M0mOxMYHRZZCjamF7FdjwxnQx4MznMUy
qT60/hhrgHcmNF3kKKO19qByjJHW1DD2fVdF+VEiTsQw/Vu9G1y1UHeV2YSxIvn7rCFS9UlyHhWv
21kevqQVq8I+TRoOmzd2usJImb1XVlXjNyJLQYfLbNGSTsSx4HWMQapzTGwDysqbxSfQcO8ySbSL
+UlimNBNf3SZOujynOs52QSXAHg8Qnl1iUl3YeQZn3Jey9a4r71jHOk3gdXosuyf/VO/MgvW7rjX
amgQ1+7zn/rYf/rv/Uuf//RvLFa92AFOuERc0XXijNY17E9CkX7vxE6WNSN9QwjnTJ/AVy+wlehC
vFQEVSYxA91ySM8u1znVarl+sPFbkCEkST9weYgLFsE6Bm+HjYWZN+KNMJivxqQYOYBUInWNoUwD
NJWItaNcCsxAcIWZRBk0w5br/oFfO+kg+vg3TgyQ0CA6gA4bH1WtmjDhSokHbsWxVhA2wo9/+GUO
13JmUj0eDqxEgzFFt62YOUokpKdJovRQ9HvfePj1L9+ehCbcX0GmHicRqyyGhzRBOvVo7R7jVogV
g+ke6LWj3lM2VPfDz99Ogg6GqnkSWHHvdIY9r9d69nxizJYdWrU736BJI4GOwvu/e8nLh7UR1fvf
cTFqBpXS55opJWO+px+798rqhR6wNL22PAgh71BG7759YyO5lSmluk90eSEjhPzV/ZA1sCaAMKBT
y4qHfLFR7saTulQpNB1ZaKkcu9pq+8IMw+WHjsNkuQUzDk461XTpJ+CJxamKMplSPIIscceQD4+i
3OkldL6PIJcBHh7xQVhhB72LFnjRvvF8SnnRUF7X310uUA0VQ89GZsGkPpfKzv0Ln/rY/hN0VRIA
j2Eapg+gXhiPXzDzvAAvYY+pFCqPffoX7loa9RGgXmMwZ0LxOUlUL2M4ej4VKdvhkn4Hx32DxQhh
OwxjDrttvB5gKv7wbnPahNGBZ/LtY5us1jtUBoXSsK/gFeClkzJImG6FAB2MwXRLNEQ3m2IKDdCN
0kGVxel5VxudoGb5PZg2BEgwmFQxcNgQNjh0FY/dcdJJ6Cmi51/TN75uu5k0ieaUk+IkenNy1skU
4+mbfAvECpjgV49CTATBzYk2pldVNxDDgq5IgBOryYcpqqT3LUx+dgpFjlxvTxmPR02CVC9F4dXi
SpJKY79wtN9TazuqvYw2WC77qA4zU808KS1a4SYNUSL96pGLrSIdKK+jZOj2yn6umT71+6VoGzbu
Z0pKj8ZdrlwkJZ2qIOZmzuxkW93F4dkAWBdroJjWpjBg4wFVhuOnikE6CKqyEdGAMg2mjYSJrth2
Mj60fSwfZi+SQTPVwh1+hlGqPvh7/uhHfulnGnahTVu1rhNKd3npZMf4vb/vh3/1Q3/vHC15FPf6
4h5Ds/w8MZi/e1cs1Up3USfQBdLqsTH5/FQdxYUOGxfHy3pxEcSus1a6RFXB2aqhqyitTVgWmrPu
BqJ/8p//137ir/zFO8JP1lMcrXO73iuoxWf3T9sU7Sm2DafBkvvs2TlWaceAqaJUmbBhHJivBg5D
WcVNQcQeP9+fSqU908oJUSp+oQrNth9xGI+dzjZBg8AgA/EtD4NEmekgBMLGBNCtYBBIlYkOigFi
IfbtOE5KIwCJsdGBHZO92hzcPgqJ4lpBpEfhqXRzkutpLml0KzqFTqQ6cXQswkeFRkcX1al0Mg8f
jsEhk0bOSfYlGL2F14ioTmmxJ0VbCYu9lnpbvIUSR1ZgNReAGGZGUNMKbljhTmVJF2xS0WNU80wR
KWF4KfOIqk7ZVKLh1OZdfwMtJ5Vat2p/UGF8OldPQC7CnEE0WCllTkMamtGvvuEI6uhiG66U0Vt+
RaS5OKSzg4IsBoBBLGr7M4CgQ6ACdYcm4uEONqhm8/G9/OIHqbhUIksR0GvRR3/pZ+5IF9rZJOhj
P/17f/8P/8v/5n/yl/7C/+hXP/STZ7GtZ828ttq3GxfGTAP6GJhez9xxsVyYPdCsuGMOHKxJ7d3y
buRxgb9/F7Ned5x07WASVm5iQ/surMW53Ux5nu8OznZmjNwY/e2/8hcfL6nQnhCYW3ajfzkXbLVF
Wkc+dw6IXQkZ+1mlljDFoA0YA9iwDYbCcHnwAXS1bSo2zBMy0hsRIES6+A9bC69q24XsAdWrSQfd
JHs6CyExJxiqdtdoDkcbGhgPWywEgjbGUBriAMmmtAEnBZMVejoAf+o7n/47v/nA1PVXTETYHJnF
FD0RTdHrAx+FrHxblT8KTdEbs79nI/Z4EoSYnbvSJDJPQzAG0zyRbl7WvTmNpj69vaLQVy/AgZJr
QhOGgXC4/nZcO+lpEo+WneSxVoNW3GkX8+sgj119JGmyJgeIj17h72KGa+Nay1qIbAWirqwOrrnV
3xErfL4+QZUWNBujn1gtevug7lFjJzkUVQ3yVic+Fk4ghc4GtV+MO8TMxMSgIUTMh2vGBG2MA40B
ZmPKMmi6mSWeqCc+A8krTutO6Q12hJQ79LA5N78M0/v98asf+nt/6d/7V371H/7UOTpzh5cwLvjH
+CqqZ9TyRzNwdIHzaNUpUONKBgiv67S1wG9d9Qh4AkaStplkz0jQNeHdPKF2NmfQO5vuvHCIBU/P
v+xqUbefeukljuSlQTjO3sAA09XWYvXnKcg+epEaxeYeoVkXwsacDMKg7bBBmPnAYxuHe0PuMU1n
vgkGKR2P0yEYoo3pVsjyWn03rEpEIrmhJ5nreUsYodENIyPJf46i22HG3TDIQ2SHOSiABtGmYCVW
I2jyAXQi/Bcfe2AVf4DMeMfDpQFW2kKW71Ve6KR0FBWhh1PvEx2FFHQz1Szpb6cGfJ7hhR5LQlt2
o025YNQORKdJYbTCrVLbuW+VOmwSkJh7n0z6dDgw+tqo6cqgHSHLKkAlSuqohVZzDMtUseG+0qhq
J+pEmyKa5Cyg0Ub4kj2XeH1X8UB1NYA+M1xbU6LFcW/IrB9PA5u0JoxNcGBirv3MUvmcymyGG0TK
LLoxNlUl3Xi4OcQAAwdz73D0XgCQDjeWwF0ciZWVUcBxmLctQrfEw859uDq+trb/OFe/nhFLQL/2
Sz+FnogE3M1sucTGe5SpS1YcrEiK3k3MaQfN+59kKSiUqymEms+WPpmhL3YYC/r+SpvhXbMC/dP/
4v/8v/7P/4NHgXDAnh+NcyXwcrD/3L/2v/t//Yf/1n7BPq/y3Q/5olearjUdj1ppm6QMvoMVVR+X
eRPAEXW8DfDgbWPSwTy27YrHttGBaSMmZeAoCpJtG4heXoSuNzpOSQTIle3iD7uKgiux2TfQXikT
tK1LYiUjWkyaTDkVPNmzr5UWzkoDeNM1vnGjmxKENm8QaWMybGcDDQIpHYSYaWPPSmKlQ1LOoeZO
87TSzVRROindJz0ppupx6lHopCpkeI7KVN11uNa/S4k8vXew067IYNu6pky7zJdwGmNnm9Q8FSSR
LZVQmIQlUcZxV/vvFgu6k+rYEzccw9gh6cE4ZOzIF1ZjoT0zatkcoxB2P4wRS44snTvWkCVEGYx8
sNIBxHhWW52M0EFbYC41Yar7YpWbVw9WISVSHkygoQAwhWmwDmDwGLqBN0fOYnn1UJOL/eQdzW6P
3gUH37TZWnSMaY8moyqp7rZUeKz/zaWpLu4Udu4JMe1b6vk51Tuzovgx8SkNkkFaUvPCB2oD351p
Lj9icaVl34B1MNCjM3aBdAQi+lv/+X+Aiw0yrZPpc1aqNh0xmkQO9Ff/w38TO7L85el2Ct/vkh0r
XWZQ0Ko0cLZ+wCIaLk1JoCMv8UQDfDV4A06gbRs8WQ8bb4dx2IYcBkgYGKCDEtGYosTD3EiI6Fb0
SuFlHSClqQrgJKrqCsdmRU6iKgIKkp6j/OukDuptIPXZG5Ew0XSo2kiJJ6Uv3pJp0gcwYnXclDbQ
pmy9P6kegKE0lKA0BFbi/8z7nvqJT7w2gHub15Z7QkclVTqRitCtkJDeTJpCE/rwRCe1oa5KNl75
6I06WjC5I7OiSCa6FtbaA4Sizor25plc1fjIeq01nofGXUE3GZZSIGmbWKLR9hMojw7d/1Hiyq6O
1qlxdZK7gfjqy9vaHWJp87HyvfKV5uBJ4uVFu2aVNSIRalftrPnQxPbil3nrvQMrjx0fOLiX2wBt
RAeoQFmVN6YNY2AwDqzsHq1o0zFdWExPRrmJ06aXatOZ7nkZAKzQdkoQGn2GQI8K4VtWDr0b0l1+
iEfYbe4pfXdT+0G/54/92V/66R+n/Zq27kT4zAeGLjoWdBAGdYGVHk/0xBkOvmBD67gZd0VknR1Q
vxNwiUD16K+zn9bfNZw/N9s5c3mj8gynGuNWifln/tV/56/9R/+OP0Lm4sXETGNgOwzigW2jDWO7
MgI9NtDVIINeTqqkfIpaYIVVSHNqeJxKRNeEaW4tsJqup+lYB5Ez8yT2lNrWSC9u0c9au1M421ao
QNoemSXOBMEyTdU7/Q3G3QCAAxE0EB6iP/TWq1964fjXPvEQiismW8YYdLXRVVyHk3g1vxVSohPp
zaSbqQ8n3Uw9uSGzKZta/5hySen2zhcCBnI5d7NGIzUiaeZYKDS96ZLe5SDoMG45oOk5WtV/2YOi
5a/2/tpQWbOebn1gM8QQ4i3KsS8nQe3PysM7740lcduTcZVUSBC5uD1Rw4VRGTCyetALudJhIPmg
qhfIh900zd9NoZxBrjSGkwzM0GCQjoEB2syVE2oeZ8hUl0eRa7BKGvWyQrWlq7d1qauKLq0EemmP
rrvXd1bKKkRaUkc6XlwWeroa6C4ryIVFiO42fCcl+qWf/vELmiiHxHWV52tQVxT9jquJA5YpArCX
R13k7d+5ZdFeuaPyaxwHzg57xyJrrmc5jxXRNI/au6fhjAu0v1J6TlDNbY7S5ZAZPcs41HgUmgWh
qv61//jfRWLopBtoAw0GBrZtAAceB96ucTiArnnC+Ox+To6iQnrtEQ900mQtExHdTr06kDg6RACd
lFTopHqwZKUcZoIAHCXGSyAVyn6/6j67ZdheGAyNzCE/bXNVgQzQkaCOGBGbCpdoMEjpb3/pOJg2
gEFXREx0ADHhKoAjZtoGNqKpdC+A+Kn06tTDSa+EHooelW6VTlPRmH7V244FPUhAo7SgcYOvyRWd
O4fe4TUBSbjYp7dMAuVIVVXv/YsdAAq5rLgUatmDxoy0HTPXoCD3Cj51hzkWdXlgByGwVsA+zu38
/WQl9VlCFMNKPSRFkUoXH/bQEjc8vLg5Gri8BYgwNtJros3u0Ml8PeYVxoHHRgPEZjQPVFQVPYJG
vWsG9YJwcp97hxgMXerc71TG0h2Jdo8FrLXNMZYPwiNo++cEcjyRXxp2io222GSmcHKQUGv/WajZ
fmlLYASXWU/oW8mCxzROtZ55/GPHAoJeGpXqIhmD7mFQvnQpHjHUXd87WfYXgPe2KAN37f8SDUCS
doIWVMvIZhpvxpWNYZm27QDeMDaMDdsV4Uo3po3cA4CUhpIQc6QnOfCidFQVNS4agVha1bhVIsVU
AeGYvoPASegefFaWua9EdJSY5ZrwxZfMIm8pGeyje/ZqZWzQKeL4vOQOOor3jgS9AW0MqAxr84kO
SgM0nJRJQ7FBN4S/AnAFEiI6EvH/r71v27XtOK6r0XOufXgVfchQggCLtGQcSbRFW7QAI84FcYwY
QS4PSZCfyE8kyFckfxAggQwYCZK8BDGCADIkWCbgCLogEhnLpkTxdnRIncvee82Rh3mr6q7q7rkP
DQQBF/jAs/faa83Zs7suo0aNkpEcmB6cKeT52qTRi6Ch5Loc+y6cCkTOtmRT8bXyMICLcItMktX1
EmWTOchCJtvtvOoEDOusL5UKb/YKaedfggsknmSdODsDO14imzY9PEXV38YI7m9mHoOjgH+RFsxj
bQ3b/AF2zTVLJR+SUuJcqxdJpfjDkAaRRC5DCNOUhmkYBQNHyJhknCUzVeWCmFKoT7snGq6ZNkiz
sgeQcoB1fUx2y6A7NHBLdnSkaTXsXuISPez4ouwj3ugRZB2yxZ4W2bG5bZguQi3POlKWUOjR20cH
XVB1VoAx2rLNW1D9XtjEl4gW61HyjlVazaG954UrmRKIpTahSEqKU8R1pgnXiCellBLHAcMoGGW8
GDGNHE9It3C6SHLCGTLMLJxVAmsfLD3/ZO4tnJafnWWrqs2dh7wQuV6GiM7zPZYk4Alg4jKkRIDr
SYRyFrlFOS8Pm+eZbUlg7rMVzCJpcxl5UgHEROruzm3p5ud4xsrbW2kk11iosPMGu0gyzLR1EVAG
cBSMlEFkTDKCI/APfvnWf/rzR0OSk8g0yXnA9TSXonepO6RiJA4Ntu7vdiiSAPPKT2b0t1rrDB7P
cLyaxmeC602cYB4IRWZN49TalJvADlbhe6yCm1QnhjSKvMZPYKWHrsPEFxXNbfqH0XgpDsEqh7OT
7hdUA7PkQ0lbSMrZbeMSl2+fVqaQbKD/hIkQGQUTZbxI6QSMQFqs/MWAU5qw9GbNf5tylazsETJE
q3MxM5ZCkBEHvP8VzR6CTp/E9EgvrIBthCON/LplhQNBU4/poVqty9ZOs4Mie2ldt1RstcOlEKNp
6Zlp65nPB0WAV1H5llWQeY12Qx733UzswUY4YmrnoMFppjITE1AfniXbyJyNo2FckwGBoMvMmseB
OZBdvCQ30BQin//ya29+708Fs3i8jANPJxkuMJ7SNKVhHJAS0pA4piFNs5VfRE3WSRSDHUwwkH/3
s0/+0U8fbUrIVwv8IhD89ounb7zzCIIz56opV2hh4Z8IZY6Jz9OSZ58nWS2onDfwh1zm4gATkYSX
044Pz3+72X37WBcbtwU9ExZ93PmYLK2gFEBGEZDpLCnhJHKaa7bC//AXj+Yh5tOEKUlKHM4yIqOl
LNaNNBX1NDgHJ6PHZSImq4U1cMoWZlkwhyn5xLNFpR0adjXN01goJeuHp73PY1qs/GIKtphw0Qgr
bgdqQmoCFE61qhq1en1McUsfkMEuF9QS2USXCwo1+781BAHnks0sdn0hMgrPwHg1ySBplOGU0glj
WsRDYWBuyQe80lRE6ETrpQ8vAlLDDM3CSXhGI8aiyZBit2dGeY1IUVhtY5ehnMdBM8oxHRZo2LAz
56b2lUmr58PWPNKsrIbcJinYh/tYYUAvs/bWm0FFwYKqUzdX/1H8Bs2P2bnMG5uI+fVvIlvrYdu8
EEwBhsPepGHStze/97qshLFBOIAnSEocT4NwAIZJMDFdS5IJuBSmfRukrb1Aq2cmkf/xzuUw7Jd6
4oLOi8if3r164jRM5EkwzbqvXA0BVuR91ohd122C/NZz45/cvRaR65VnPPc2vnQr/Z+H0zVxlum0
IhWbgs0MIE9CISala0JiUnjIhpLP/3PeqomQKy7QfBJ5uBh9GZKkiSNAkWlrfAUT02bW13ndey0k
65UjjdVGcXBM4muHgCZlixcgYv8Kn+u3pjJ7pgAYutmiSK+tvEIB56FgG6FzD6xTfmsrfoLtVGHr
ElslekjZpmsdem3eLtMvyZgvak7UXjyYpu0gU4ghSaIMIheCaRmTIsOANAhkBieZloYHgFzKDPAM
Nze6ZxPWsJJz5tPo4MGmSFKBLOD0B2XucUvlJnUXKK/NpamkBlazXXva4Zcl1E3WURVAzVKbg02M
HBEHr/7IUpQgajidNuGLXeNg4zhoSQUvMI9zBuMNXQMOd8IXKkUOj52ZF+S039SxFZDICSvzeUsV
lhBnphVcrI1R42nGbQEZExOuB7kUCGSAok6kJfTeLH9adIW1kOjiXZIq98ztRcMuyyhbL9WAJfbf
uvcnkR/cPz91sSdQ57UZ9b0znz7N5dZ0PYkm8l1OC5nivJB8cCZmvZp10KC2+/ugJ324FsezxqZX
lHV+KgaRJwY8mmaGHimY+2pEj3ayh0fjMPqLpskxyyg6S9a0YJebR8EN1wV5qL1EylzA0IDkElgn
z5hq560HIekWcSAVDeEL/KdzFOxRCFTwMYfYO3XSGrSNnEottppCN0kb/xn5mk0eYjf0c7kFJ5EL
kYnzJk8piQjHhHGQ07Aofsxzbktqt8V3hWsauB6rydETKLE5dbdYlbqUFWAA3bieHA7MbUg0K1Fk
7Yvc0p2VHWKzyjWI++f/4l9//d/8q0ogSkvj362eiWOVG6SmV1LTuMw0giLgD0c+tRiuqo0W1AOU
lMI9rBCTPxgxP8y7U1KY0JqvWoDVoC4hTs8tmeEu9aMRMa96qxhMUI3quvYz67enmVoicgG5Eo4D
hADTREzzXKh5Ys/DJVUXQtIyqk2GtBzei2SC030byXnYGy2XHhGsHe2QWUR+nV2hJEIn1Sh+vaPD
qjAgs4raguAvUgQiF2rXnxdLLZcTz8Jlxqws8wuXui5lnUe0slGoqVSbeswsPsYJchYjHrCX2Zdw
l9uc1hUlJpUDm9bbzEIlVvDYZQzZ7sqxjWlVTAYtLbyjPSmP9KlmWO13sde7uGFu2LVxLLJMqy9f
NmxaK78TkJBXm3TiQmZxktHUkU2iuDjaG5q/6oHQcJmWzTnb1Gmcx2FREogxnQcZEiaRQThQToIT
ZsXVVT2IXFtNHL0UAHHTkNR5cJaEbhjCB1j5mX0q+2g2Y4RCHct1IKvk8tf/7b9cWSZwkSiUMu6e
r3YVMbM2JmsIs9yFJqxFoBbQqs1icyL7xA81QJGUKFEqC8aFNsU8K3Pf08jbcUXHf9rwm3gtT8Q2
z0evXLFm50xIqzXYWWXLd62jjmd64YCJkPGJE89pmmQ6y8Qk18IJfERZIuYk09phD8hp3frX05yS
U4BhJoBw5izyau2un2kdtB2gM+lpAMQQt2VYw/w0606udnWz9bMBPa/hy3lvmpl/yPNSe6NQnhrk
cp0YPpubORG5pkzkXA+Y1jfMgf9GD50WXBubNdz79ZbQcVKDMqgz1OXNqzIvSR2opbX2sgabsq2s
pa9wpdVDdfqv9ov2PU5Rd+9IQAx3pLSHANw04rGUcrB0+UP57znB4BrFU5tjrkwJcHE+BqFQOs2b
T02Wy5zhXRuvkmtksCUECXn/aLJs44XqOVFEhnGag5pbItN0db4+T+OEYcIo44lDkhM4yCzJfZ4z
VNVxRS8iY61kSlUUKdknQNwsE9HCaZzxFv1ysh9IN4pcp7JsBi9C+qCUVHVWxyalklrvIyui7i3e
RNk65IU53BVGxUpKlKR87Aou0eq5UClsyQWFtTfp0X6ReijJVrnKH7CWSqaVt9nuVyuWl8qa4X5h
Bhopd7C1GS9D3gbICN5KvIAMwzTeSnI9cBpwNcg5TRh4FrleVAGXNv20li7OwnVc6NI+yUWee4mm
RkCEV1t8sA32wcxhnqeB4lZael2n1eIswo0qAZ6wQ71pVeU8QSA4cymT73t+DfPn65llwa4o15SZ
AzoH1JfTQs+bjfv1auXNP4eF/ThxH6mh0d+JS3KfdNspNiBr8WrT9lRSdlo38IQ2DVr+dumWSh4C
uGkZrJszwRYe1s+v8MLWIEN1oC4qmka5ZOFEbr9aTxWQU6RXPIpY9WO2G17mu67yamWtNYmOh5Yg
S09PgUpT0ppHcCLLuFCnu2fhKCJMIxM5QE7Emec0d+2BwNxOwQEzhk0xyrU57bGsrJZiuKoWT+wS
AhrJQFkqjVnza8qw0xxpWkvhTwvcsIAdS4FHaTQytqt0j+F+bWEZQsB6a8/ZhmDrja7QDAfHAHdm
gewaXCbJXKdj5FBdbrupWHbGM0G8wQumQO52CJvsKesN34JyCAPZC25ynyiaoeA99l3JhvTr3rbb
e9c40Lcx720hZmievJjFKQdSZDrz+nq6xELT4xlbfiCE6IbEabdNSLuVlREykderzZqhtWGJoPfW
mVGEIvcnmWcELj6A3GI0isxEdXIZHD1sCgEbw2Ht95kdwJbjKKlqocgTawi/IUKT4HKVfFmo+pSJ
CxY0S4RN65zq2VtcUs4zuA9u362BBUO7A/cRpyuL0RDZjefmjl0r3z/sBoIrE3wvdQyLp6FNJ/fR
qm7pyFww1r6RxVpSbEAtW0K6Q1N7vyLnkbpgPtVqRVPX50h9Dp1WEl1j2GPwXUaf6o5gCIScW/SY
AbfktCW5w9wcjEF4Ai5ETpiAiaAMM3Y3DZQRvMA0iowwxbm9o6cMq0ka1KJo7NEljYyHbryj9mKs
ddPshItiYJxaAargDjmZH2XAyezhQbP7yTrqLaWOpgawVQFx3X/QIKbFnxZEjquG4az5JxTInVd/
53//2Te2FMOl3luUaG/785dSt0zVK68KKaQjoLDyUbLKsCYTm0BkNc1chcTFRdwdVQw9hAK2AY2Z
C5m9tSCtk1lPiQIZ3/2LD66HdHlLHl3cmm4/f/n0C3eFj7aBP5RpV1HawKx9sw1pd15JpRZpbaEc
FAo2rg9z2JgeajQ0NmKJyMtPjm8+uE5r6782YYNK9pMtViTjuI3x2jiUXAUfh5lps27IuZP2lWfG
//XR1Qzxz1b+TLkir8hJ5Exu9H//VLIoomYDAMomFehVdWiXXDUl9Vab1J9oTq2W1Ssb75MdBLej
5xnZ0faZ6y4EXQPIiBrLmZh2283JzkLwhF1Q8M4zJo8/P8Lywh3+ykKxwQnTGekpYOLE8xUf/VB+
8ZfT3Xdx797w3v3xg0fvfXh97/704AGvrzhNYusMAXiSkahg6zZ7Z56mLtpWtNwGxBB/OSaJVZew
zYAokRatKgDzUfOd22kZzH7i5xzZ0tMSh8gcRoSC4lcXSKXrpKg+FJHv/ckf+fwl5XFh2EGssuw3
+lpU17QHT5lvmuBwHc0jtMoz4vcclEVjQChOTzVpNahKSWPIXrfeQbZVBZcUuZqu74/nDz86v39x
9dF4dfXogXzy+uT1yeuT1yev/49feOLFXy6jq5obBJxmTSkHGBYkDSnGgIn4yj7+P8WTe7b+kAyL
F5n6EqVbdBAudteSgq3n4HTitRJAdJU21AcO43C+vva/dxc7jeZb0glk3GC7zCIdUXILpWdB3ONu
UgQLnmnzxqqNZbQPNwvoebHYfXHU30EFiQ+aGJa6oqb2bt1e3YL4BvuFOfM97Ik7lsmaeFLJ+f6v
dpPW6pUf1ytQvQfyOkSmgeZozbPWfrabSuZ1Vn3E3J6HcBT8PBdkvHA07cRHjXKJxdIqmbnqLGrq
aBzmfDcUWC6kkd660+obRjlIjWumTfcfSjHH66B1c0YUZSYY460nzpdX3GfL4ulnn0eSj+69b5+0
5zD83VY9MIbhxrw90tmI9gmzx/j2WcBtGwQNxAX1ms4hVHOm/KfMwAE7RlNfe8U2Se+2zy+iHOUh
N5NBzk+oUyTI/blpyHE/xI3q3CGllfPFAmGvCAPUf1sBTnXEmX9UR0RbZb8UYYbpAzD/POBlI3fi
1UqieWJeGJfshKHKgtphVpL1qimrlEnN5XMf2LGqMLN18lXIpyFURZ/YekowYPOOQNP5qK2Dnt4n
bL/IYOz+jIHqNmms84DTyy+/sgsxy/DKl752+Uhfghpi4FOMqf6TxnWaaRJi8EfSKaYyCsh44PbD
bRulaMgmkebei1aEIT7F+cq4P9wo1xTTxOWaA3q3Vl9weqI4x0w8TaHK2QZwLBQlIGShHUqbBntU
W/yRd7fu/ajxFzU+00peiKPanW/C7Qi32x3gb4rSsMH+G/oYPraJ73nU0M9C/xvrUNLQvqPlbFd/
RRZ58bqnnUh8G83JYEp9ebQVuQ+xf2Arlwz9fqnY5zkw/XWQ1tT2ziTXtrTmzIi9Lvfo4YOXXrpz
+4XPC0ZJKY3PfeazL18+ulqLy8wvWG/Q3T/xwBHSzs/KThXn1uEbBlxEFGZavIlrxeeL6mET9wEx
ao7PF1nKkm49CCj0XgylD/6KuUkhWllCj0En40NfLlGEGQYBYH7lqIVj+3SIVixsQ2u1qSo7kOaM
kOb/62G2sRX0HEPz8DKamtLWUmN95eGsM1m7HLXIKtIsrpReUAvMsbyK/uDCW2j4PdO7gBpKkDF0
ymUlgyOBKmIOU74/sMWZexUE3cXZA6RUsaMeH+66CoX55Hbk/O3XX/87v/v7F09++vTU83/t059/
eDlh3DCEBAzDeGHmHUOKJUURpMachPwAw490/NiQ7tC12E7BsTIUfxy2tqRoLj4P/r5r8Gg1HpJu
qycK4sMRy8wgDDwUc3Qau0qdo2qbKme2htnCQ0to/h+WthVt0nJN9mZ3qljTtelwwQgbPInhyZDe
LSJf8I1NWJ4d9nhkuKhM/ZENp2ef94CqoH6Y3YlBcZDnUCiMgkjVndhYT0PM8NqtQ/vTs9cD64bS
sSFGCRFuZXSAMzhyEoCzyKc/+6VPvfC5dPH0r3/1b/zsnXfv3fvZxDSOn/r1X/utZz51++c/f2+a
xe/zkgbEThQVZHcqgUZ45jPgA+K5wVISOW3jmLnYgoit/wf1qmkE9NmPolT1CboxdEZVnBggCqOo
+IdurlA+iOyHgM1FmgB09C0IqnQwudFfyQs1ZEZiQWKzB7ywMVMQg1dl2Q57edazE+MOx6V0pETe
zXQMI1nWAsESlSVrYDg9c1s9KvTVharljlI2A8oBGMjPtbPwqTJw8SLVGIZcBvRwRIYiQ68/P7iV
xxbet28yeCCG8sDj6TQ+NfEkcoHx4uKpZ67x7O/9w3/27C+99MpXXnvn3fcvr/jS577493739370
xhs/+uGfTedH6qPonHl4NfMmluobHOwNPZpUk1VK2zsXcb5YSLUAYd1pv6To4Woc87iJzyvkOJw4
AoVBZ+vQHS26wiJsxd4GavqI7mKiAEWhjvDhAqO0j0aZsXmBrLojaYC9+WARBPNakZcNjPwY8u8V
Rx/Vn98d4TaV/oOwqmE/HOI/cfvVo2msCXcefITLAa4jhpAa7rXZcdoA0A3GnaqBO/4GuZhbG2Dq
23ZZQ22eErLvQKIYMsIYmtjeyNvPf/rOF3/zU8+9ePfeL955/96Ln7vz4mc+9zt/87fHQdJw69Wv
fvWN777+9T/8gwcf/lh4aQTDRHVFZ92akk1bZFeQt7WYM+Yp0DIuTJzuYiMKoaKXLGfNWnTALbO8
rFvAAgFw91s9/WNVdqbp8sMQj8cLrS2kJdT56jMt5bmGbn2iXRCp6DT0/rynKOpGyvBak2qZdSaw
Jyo6ySc51EJebcq0yAYqpVTEXIWe4qJRVlTgVTmCfL/OUT0/tLJOeHQCmIG+m7xhBnRYNc8jQdBm
HLfDz8aftnmTCDSnEMcX7IZ92MY3S6GWDBATEcE0nd9++823335rPN3+3K986dWv/a0vv/bXX3v1
s1+7I2cRwee//u9/8J3vvn59vityZXHSatGMzC1mxfnlLek06S2aC4NalraFn1l9JeOGAp6JUHgR
OyD1Q2yf3f9lzIKONGjb8OjL7Yzd6XE1nWV/xDEbOlYjs5o0wYEb56GSmrCcvOTzUOHOem1Rk5kZ
QCUK4tOKgooCnUITszmP7sSYUuASkc3h4VizYiFZGUez1q4hw+nZ25YkW2hDM5hEXAKvbpyFqiWp
fIhzA5WhZcj7d3oRQ5Sy0LVc8ob5aUSehc8hNAnaeZoe/OLhh/fuXz/7qc/8xm/cefl5gchPPpCf
3334wds//eCdd68ur4RXOTThZMHeRIINZnUSZFE4TL/zK94W+l04ciOlESuFDtDjWftx9oLkg5IN
3MOuKFNmHNkwcLZlCHPF2K2uS6PA09D8ig7gONQzjljUHn8c4rQIIfjYjH8ZoseBQk03TKUwvS1q
cmseEqdoxy3D49YvGqX74fTs7QIPYZVfvu0h9J+a/H8AZ4pKLi6egYCMXWUA3MMdt5qVlZgH5W7i
7BKE+5Nop6IIA6pUNg1FUhoufulLd1778ldeffAo8cln33pfvvmtH73+rT++GM5fvnPnC5//Ykq3
7n30wXS+Cg6vxqxtyyiKRhzASOFA8kJuWClBUISQouaRPY5s/aVoZbCJYF4oQ+ibcQOwO6OB4diz
hh0VF9rSysc+Xt8sMtC8cMzb88255XVbqAtXbOTAfhlQA+5RbSZCQY/Ue92qUMTLQmw0IX0GHXEJ
qlnyxDEvXyn2+DsZAox+I0bFadSpndl7mD1s7pOqfVNIp0ejPHIoQS7xC2KkH4zsjH63ZpJF3zE0
3xncQfL2AgS+SjOCl6sanr/9q7//9//Ru+9/+B//4N994c5X7v/ib7/x5p8/89St737nG+/99PuP
PvpowOm55569ffuF998/X189jLBMpbeVBVOxZ8oXXw8vhQ+/WOHNws0r6YX8CiCllCvKIwf/7npN
MTvC8B7QL/pA9EVqRXO67q0lD5p35JWMHWzYhmHaER1OBtyG59uoZ5bnZdPlQ8tYuBx3f+2Yj6cX
6XIrWWxoBhcPyf0ru3aZhxy5f1Nd7ewosDCnN8hR19eo0uq4EWDv2WUrPam22zXmCNPCc0G+1kTo
kIWldusjo+5VlXM2QV10L24oM0Kn/Ejd+uRgkcDwK1/4yssv3/kv//kPP3rwwcWTT7/4wgv/87/9
1x++8f3f/LVXnxrGn9y/y/NH1+R77/6sUXAyka93ht1fZWCLSajZe485XIAVO7UIIVwTQH+LNQiR
0fX0tB1VWOrdzFen3Z8hzkAPdelF0iEhA9PtyWwuhuZHd7DF3M57x2WiYxmjdhk6MVw2JrekX3t5
tMovy3I9+iKBo5IVqk7DVnKA0kWxiolJh1oDRwPHI+CGg/Y6GHfD9uSkHhbPjJxe4Pt5dhMUZHwO
BotkBY3RyTltA5ZgUI3tIwGjLt0lY/gunnjyJ2+9+cYPvyNyLZBH5+sXnnnij7/53z+6/9Z7f/mD
f/KP/+mPvv+tRixGcXXdfbkIKZu/6RhNHtr0aq2yIfGrULfzRdn6lBxNuEa+Ug4+EvzQu/j2X0VZ
WkfeHQYHaNliKmJCxS7BzD5p9nOsU27blFOUoiY2za4RCptJA2tIoIO4ZmhSIaJF2/yIcqh6ILZx
E/ScrWZA93Ez148SzzYKW950/13y1x1R6ba0HcXhJKt3BeeRU2GFDmwecD8YNNBXds+2FiiB+1gQ
BwWx3WlbLTX5aAZZhVItlS3CRw8+fPjgrsjVkkhNHHB9970fX93/4P69t7797W998c4rDvaX96zB
wGiQquXiwR2NOsandkVBGK/P2qOVWNH8ZZbgoxwsdTZWvhrMssNbl/lxLOPF8oC4OBWCWjrzTJ/Z
hVGPtQwetfcw0LNWTlTVwHXbSECHTHwODygNj2y8eBt+85BqSof5qh4fHnIOay8unUS4hQY3PGiK
3w2zcBpL3Xn4DFI9dDwgLZ6lIt+y99foqKjNutVStr1byhJVIhED/gRWD1WCc/bWUium3ut4iDAr
IiK3bj359ts/5vlDmc7Ch9//3jeBqzSc8vhRN3CbdcCNlNT6D2ccku/ONX40+3ATKiIjnTwkw5co
tmH9cVDMyOt3SF8YQhGthCo9YxFA0qXmGqXVEKDMyraA7LTRne6nlcfQlrvYudp4vOfFnH3OArfJ
sZ0YMJGdfbj/FhXkvXpHR9mSLJ0PKrlW0AHn/cVTn/3VAkz0HLsvOc3HCJ1YsCkqqrAlYFeckB7j
Bduwk+VrzOZ9Rr0tQRXFqQhVT5ELtlbVw5977jNAunv3J9tlnE5PALi8fJCL6/q7LOobcWFfHjts
xziLhZ4zmyA78seOKIim28Dmo5lkDU/rAuU9Gee8NNjdNHfgDTzmveCCYG55A0X9ow+tKlFjv5J3
A/tXl3GmW9UyA7Z9xf+Cxu6w6eiNx6hLdSK+9+ymGE9grJyDY/10Y82t5VuEtoIf7d7uA48iFKKH
ufr4IBsop2tZWGC+G+eHFVPIVnqerR56k9Zt1odhWTDqMnjw8N7VpaHQXF0+WAatlrrqvl3wrG3U
c9geWEEPIeoJV0o5KjYOc/YbRKpnLYHVdmSAwH/QqY469BKGBc+wiNrTo1QGGTjik9ZWIQdQhcPl
wFHAITAgKKYU3CQu1Nr39KnVLm9C25BG6hkEl77i0I2yXGcDMO+h7Q35eQgAHr3IOrh5/bRQcSBe
KRxNScjdTTn2xpXHMZvVG4cOa+yWO7NxCkuXIx7czyDq0TkQ/BS+7flKTN/fvpdmhCOXgc8+6Tno
radeB1ajK/TJRXTjp644BDuE+KID5jfT9hcM9onk3XdaRHy9QWhrEGjDa2b18B77zlpGHv6cQV27
w6ggznUMMdSrSR7rHTvUZdZdCXftr0MEkFqrBEuXn7WaZhNabg6FtOr8+/cmf+dQ/B4W9JiATJ1T
Ogr6jluIhd0lVsxwGbNiylY9bf0H1roKc7OS8lRaEzo1NYMZBxVNEVOIu/EyVFoG9f722mjNXyD2
EyhA9kJQO4QC+gJkLdONom2f3HV7btKskmUtZYEBVRNW1tzYTiVrpjBe6mgByVZM1nlHLnwcl69J
z4xke0ZifqH+Jw9sZmpHZ/7hjZZhMSRDtewgfhAo564cCJNUe6Cd+tDiQSUbDlfnQGW7kPUdpq0Y
2hsRcddoZknDRJI+7c8PXnjEkdJJ2IHC83VGN25G3DmKYZuo4L5FSV2zBy25WSBR6dGAnlDTaGuo
S0rseiPxZCvfxaIvJ0AuuJhZJbTSczRFCPSdaqLRDfxod3Je+7QILotPUO2IoUOCuz80L5rhS2WY
2sAOGsFRlOMTmkc7CwldpViGyB4z1l9RTmcxC6XrobMDW0Jzw6QwgyPN/+//rE7dlShkkxrl0UE5
6Wfoma+lBCKrwR3585Kq4XYjhhVPM4ft9akPR3RybauEl8UUR89/9of5efBMpw4fgDwjJm3Qqi64
4gjrcvCRkEZbsY6xnjMbcJPha2b+kg48GsUQ4Vd0cOOEAZcDHdYcrehHGpbLT/Gqg4J7A+duBIbs
sn3MAFs4KE1OM2vqKXlocznzLxrAQi+VZt+RbIrasBdezF7JO2zqSJf9L6XEc29UwiCWQ9BkvAlp
Jb8GUqpdi1YxRAtPRCtQavL9GfvIPq50+2KUoYnYh42AvWphUR0SnD1f3U4MGNmGni3hcGHo08zD
P2MLIivkKpv7EwH6h0pvhIRhbBmto4kLuzpoqyZBM8mrjc16nKg/qxBYNnqbj9sKPmrRCQsG8w1C
8nLodHMKdOR8W6YjH0gS1Fc7bgR5gFtRCOp3/Fssjx69J49gAOmbR1MJbZjHqk1lFSkaILcTmyvX
V453Zpj68VYekLEla3LSTVtIq5PHsp586DAou8YOhDdyUrQSQJq6m9+o8uWIAt7yoQT7pIcATn2R
zZMQTcVjkM23cEKUuU4zGWceqfRbZKD9ED+G+BpOeNeWEG/NZWysbSnyXqSbOqZ2pwlKMS+aQV5b
HR7sfE6UeaAcj8HenaPF4CSW72VPJGr+P/XahVCbhU65tY0MNlFOoFJugY0InC5oFitFB7x+HNCT
rKZ4WSSII0bezjX2OV6VqLkaHZtJ4ug6nFqduPQTxuiUp6I4e5SYnaUmA0sxwK8uIr9/XcbIjOTP
vKGP9dApA+u1aUbPg5CG1fMC+nYbFJtDvW+6mZtXDhdgcUey4IhNQNCDVkrdIg87MoR5s045hVih
5KgkxFa62Un+ykYi2HHkRWDUAaQxi+ghFqEtMyGvoLIfh4VJ+dhUk96dEauCFLVQZhuoIs6D7lAr
S3VvbOIrUWTGZnVmH7KdssBqKjnYcfUyDKc4Zn/6yTIUyRIeubbUQinlloJJEZQarV6PbHbSP4Rr
nom0dKW0fex+/cl0cfmPafApSxp4D2eXVddO/5ZL4i8Qj0BgazJt7L1QX2ccUFDwZ2creI1iJoL5
mkvii7u5knZZz3LZWsXK5mRNTjJfHychy2ZPScAub2xybtXXhsAkgvi9E1/G8aPlIoMFgqFNZxvs
Qq3ee2CKUDfKz8ik0mt5ZwsriZpx2MiKSnVWsnHLzYk82TagzZw2JwcLv2YaI422sgLt0ckNVRM/
0PDlOTiDQhtHYV9wATfxsYva/FjpRk635+OS3OFN9UMH9k0PN5N9mls06LV9/Uc1jj4mLwgJEAX4
C9WmsbCdZ6MZZ7j7OSZJZxyQgAiETEjat4X9PFGkqo2jPxewza6hYR+iR/MUAWJQcCgZSJVlxssn
O5e28pDySZ+Igovf0YuOd0ywu/sRFTRZgtZneE6llfE5QmzijLJHEKdvLRc6V0X3/olkkF0Jy6qD
3eNiX30QRaEOtTFPqKQFcTDRdb/skzrosaF1iaQOhb5G2NH55/hYrHuszt3yCn6k2hdr0hLBIWF1
N+Od66Z3oL0NzCBVqUKIMFTROklPMRHGIySZGLJs2pra0IHtbTASx1lNw+9x1VNhvTwd4gkbaMSt
X3eQR7av93gWB17gjOixC6j15de1MvxbRAACBKWCihIJbbsH65SvniIq8tOixzGLzaN9YSUEDsNV
MHfj6KDRkVFGx/hJ4bgxjTZARQqY+WPNgIUMbaiDMEbx6aZizjtqcQgTRku+otMFFvriGSS1D8ju
qQZX1I+tJAY6TUSMYfvEt4K+rKNwF8pbqlxIHR6Sx3ekmwyikRA4qnKlihlD6XPX5Pl8Z82T6dMe
iJ63lkIEatbW7eQEutWsdIyJqiJIT5GHxW4IomCuUUzJQisHVjArGlPCCSyoQUZmhhecRagvtYNm
aPK+jtM7ug+zNgt3iHxNC7PTwDUDJtagQogH42TYdJQGsYYjQTqyxgAtvKEAatz27PB22GVGIc58
UFFN2gFs0TFLy3VsTZHU4ObQmWLZSS+toCpV8Vn2wY6dCbj1qgwwjVJ5RjqJ1Z7ljccwFXbW/Zxi
Sl/mGHJrW81XQnL6IelHKhwM+Sq1Q4LCQqMFUlWkZmgtCOq5SHbHmqASaZMxbrWPdyPjW7Ze335z
pWkgyG+68jlWXZF7TPpuVitvR1+x788CGERPANvtEsodSHZHhP1j0+1WbLYUZHwrB7WTJtnFnNyG
CKByurAdPAfgqWLGRqTX7XTt+ZttrO2hRnZWgYdgtejcUI69mKpkJIpA9d/JHmIRLipSAYMkKmuL
RSBlp9O0TLSgobpTSUjVNZA1RNEdJ4a+RKQ9Och5gx2DG/0F1OIEylwIOPsoxBFDPfdKRNmRvgAe
sSub+U6nsNEVZ0nA+XGjA3oT6luQSANncCvMdsYFst1Szltu9hJWMo8CRMrToB6gRHPGit0LD/Kg
t82doRcomG+aN1W9J2SXF4UUzd0SD5Pyd01LHNCs1f7OsWtLuay4bRRZSNSrDOmmBwpH1pA5ytGV
N0ktoAOCCMINpo4XkSBWRVlsjFlVqS4BqNxRtrQGl0/WLBT37vrBBMR4UDHAvbIHjkXlFXd4JP2X
gKFPCsrhcXSCOF/m9jGhGBdWEH8KTf1guuiwy6P1tUk85VSWors96LxrpyI9ko7NT0/ZsZYB2KOC
smkGx21HMOCM7hRvBl6tXBPUZuEySG0llimma+iprTxutE3ZwkbF91Shd6JPCGFhwtjMHKtlVbKI
95nnXL1pFnwADtaloxlyMvRJjYPRpMP3VFZaxIPKDCwyT7aaH+tLt/dMJT2K8Pb7hUxMm6Ga3tGS
ak8cdwMTL4WJd6vBmWnogdSMUWZkqA5sGLkBfOHuDW8BuSpIo/h2KHrMnnMXFHTS0cEHDm4z+tF0
TVjQ2wrNURpkO0W3H5c6HnlZ7MKRndg/QqgiU9w/adc7pa6+4M2HUmYQuXjkBHEELLsA944nWn+P
llT0o7YqLb3xFez69jqTj9HXwabMjEHzm+VV0l5eBoCKFIKMN3c89BF5sr2Gh+MtFX7C7W6r7DSG
Kow3cWlyRBpEn6ZIRMgNmeMRToAHuuY2p1NJQxpGmfu0547jb0pG7FuWcr45izrZ+ko3SjNpRirf
ZP/FMhddwgOFsFreSe9WEeCsqh69vZez9C6PqlSwDTsS29b44eZydzgGTFWQaN5MhjA63vqWS4Qa
BUpedIQbxT02oors68ibmlVURxAHKT9VUJ+XvNgYXk82yq2sLnC0yTtPFiqGkoGcQ4dKc+6ipOYt
Hgu56nwnPZkdbQF1z5pVXWW8sXFQTqhZXLfYDlusAVSGk9QOu0sTM/KZqfqpsS78YwVZj5+St1qW
IAVtmUbsYrsMuCyag4gH0EsTqPfvOamX+O3sWjrY5fn4e+Zol29WEXF3lbKGmXSdYyhpsLJ6fE0X
wDkU5KLaOkSvt0X81ISMW/w8mK7m18sdUsyp77LC9s/pDYowNIH6Hj4E4lE+NliN4TaoEwTL64Si
nTA75j3hhViibTMJQxi4lsozHyMQuV0GEHsXIxs1mndTYkJ68YzZNznaIN0rxEZ0/NUWI5dt32In
0KLBIEQxEQao7eYDJDCbuVG69AWhrAZbZBWWyaHbNhINNaTTANXshNJLkQ/gtgK/zuc30RIGzWg0
giTi1QDdcYY3iLZcNDMvVNJJU2gLzv0E33aU4x6KvgJvXaeQNJTKhuxJJJXTzL26sIwDvMk+td4a
YW8XQdlCn+btb39b1MOh+o8a/F44nSXsAxJrGkXqAB6o6ss4XT3aa8TwGFCRQqxDgJPW0G0X+cmw
JBpQpYJdOBwVOIzGrEkqG6hd9vg1ConSqFRTAnKC7fBixYugIcydCbvrp9YzjLt/CEwPRkRpTIY7
NiS64CP5BSH2rpg/GxbhjcBtroYv5IAefKw/+N2qEQjP3c0SaLqkXuZj6Blk/TcM3lHts3M10Wx7
M9Ayh/SOdkm3cbtDO12ml7buHxsg6UANoWk+xvANzUQ4u9q/ahnKT16fvD55ffL65PX/wOv/AqOP
qR+A3vBDAAAAAElFTkSuQmCC""")))

image_hourscale = wx.ImageFromStream(cStringIO.StringIO(base64.decodestring(
"""iVBORw0KGgoAAAANSUhEUgAAAwEAAAAeCAIAAAD7FYWRAAASM0lEQVR42u2d+1NbR5bH9bds7exj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""")))

image_hourscale12 = wx.ImageFromStream(cStringIO.StringIO(base64.decodestring(
"""iVBORw0KGgoAAAANSUhEUgAAAwEAAAAeCAIAAAD7FYWRAAATiklEQVR42u2d+VObR5rH9bds7b1V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""")))


ClockApp().MainLoop()
